@@ -1,7 +1,7 @@
 /*
  * rtcollect.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -99,12 +99,12 @@ protected:
    /** Checks if a given array index is valid. If not, exits the application. 
      * This method should be used to check accesses which may modify the array.
      */
-   inline int check(int);
+   inline void check(int);
 
    /** Checks if a given array index is valid. If not, exits the application. 
      * This method should be used to check accesses which may not modify the array.
      */
-   inline int checkConst(int) const;
+   inline void checkConst(int) const;
 
    /** Copies some data between arrays very fastly.
      */
@@ -147,7 +147,7 @@ public:
 
 	/** Checks an array index for validity. If the index is too large, the array is resized appropriately.
 	  */
-	int check(int);
+	void check(int);
 
 	/** Appends an element to this array.
 	  * Most times, this method should be quite fast.
@@ -177,6 +177,10 @@ public:
 	void clear();
 
 protected:
+	using Array<T>::len; 
+	using Array<T>::data; 
+	using Array<T>::checkConst; 
+
 	/** The internal allocated memory size. */
 	int capacity;
 
