@@ -1,7 +1,7 @@
 /*
  * rtcollect.special.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -70,12 +70,14 @@ Array<void*>::Array(void** const ptr, int off, int len) : len(len), data(0)
 Array<void*>::~Array()
 {
 	delete [] data; 
+	data = 0; 
 }
 
 Array<void*>& Array<void*>::operator= (const Array<void*>& arr)
 {
-   copy(&arr, 0, this, 0, arr.len);
-   return *this;
+	if(&arr != this) 
+		copy(&arr, 0, this, 0, arr.len);
+	return *this;
 }
 
 int Array<void*>::indexOf(void* elem, int pos) const
@@ -97,47 +99,6 @@ void Array<void*>::reverse()
 		data[len_-i] = t;
 	}
 }
-/*
-void Array<void*>::sort()
-{
-	sort(stdCompare<void*>);
-}
-
-void Array<void*>::sort(int (*compareFun)(const void*&, const void*&), int l, 
-int r)
-{
-	if(r >= len) // for the default parameter
-		r = len - 1;
-
-	if(r <= l) return; // stop recursion, all done
-	
-	checkConst(l);
-	checkConst(r);
-
-	if(r - l > 5) // for large parts, use the middle-element as pivot to avoid deep 
-
-recursion for nearly sorted arrays
-		exchange((l + r) / 2, r);
-
-	void*& pivot = data[r]; // use rightest element as pivot
-
-	int i = l-1;
-	int j = r;
-
-	while(true)
-	{
-		while(compareFun(data[++i], pivot) < 0);
-		while((j > l) && (compareFun(data[--j], pivot) > 0));
-		if(i >= j)
-			break;
-		else
-			exchange(i, j);
-	}
-
-	exchange(i, r);
-	sort(compareFun, l, i-1);
-	sort(compareFun, i+1, r);
-}*/
 
 
 void Array<void*>::copy(const Array<void*> *source, int srcPos, Array<void*> 
@@ -160,8 +121,10 @@ void Array<void*>::copy(const Array<void*> *source, int srcPos, Array<void*>
 
 Vector<void*>& Vector<void*>::operator= (const Vector<void*>& arr)
 {
-	copy(&arr, 0, this, 0, arr.len);
-	len = arr.len;
+	if(&arr != this) {
+		copy(&arr, 0, this, 0, arr.len);
+		len = arr.len;
+	}
 	return *this;
 }
 
@@ -194,7 +157,7 @@ void Vector<void*>::clear()
 	len = 0;
 }
 
-int Vector<void*>::check(int i)
+void Vector<void*>::check(int i)
 {
 #ifndef __NOCHECK__
 	if(i < 0){
@@ -206,7 +169,7 @@ int Vector<void*>::check(int i)
 	}
 #endif
 	if(i < capacity) 
-		return i;
+		return;
 	// need growing
 	int newcap = up2pow(i+1);
 	void** newdata = new void*[newcap];
@@ -215,7 +178,6 @@ int Vector<void*>::check(int i)
 	delete [] data;
 	data = newdata;
 	capacity = newcap;
-	return i;
 }
 
 void Vector<void*>::copy(const Array<void*> *source, int srcPos, Vector<void*> 
@@ -275,12 +237,14 @@ Array<char>::Array(const char* ptr, int off, int len) : len(len), data(0)
 Array<char>::~Array()
 {
 	delete [] data;
+	data = 0; 
 }
 
 Array<char>& Array<char>::operator= (const Array<char>& arr)
 {
-   copy(&arr, 0, this, 0, arr.len);
-   return *this;
+	if(&arr != this) 
+		copy(&arr, 0, this, 0, arr.len);
+	return *this;
 }
 
 
@@ -368,8 +332,10 @@ void Array<char>::copy(const Array<char> *source, int srcPos, Array<char> *dest,
 
 Vector<char>& Vector<char>::operator= (const Vector<char>& arr)
 {
-	copy(&arr, 0, this, 0, arr.len);
-	len = arr.len;
+	if(&arr != this) {
+		copy(&arr, 0, this, 0, arr.len);
+		len = arr.len;
+	}
 	return *this;
 }
 
@@ -403,7 +369,7 @@ void Vector<char>::clear()
 }
 
 // Changed to use copyMemory() for faster operation
-int Vector<char>::check(int i)
+void Vector<char>::check(int i)
 {
 #ifndef __NOCHECK__
 	if(i < 0){
@@ -415,7 +381,7 @@ int Vector<char>::check(int i)
 	}
 #endif
 	if(i < capacity)
-		return i;
+		return;
 	// need growing
 	int newcap = up2pow(i+1);
 	char* newdata = new char[newcap];
@@ -423,7 +389,6 @@ int Vector<char>::check(int i)
 	delete [] data;
 	data = newdata;
 	capacity = newcap;
-	return i;
 }
 
 void Vector<char>::copy(const Array<char>* source, int srcPos,
