@@ -1,7 +1,7 @@
 /*
  * rtcollect.special.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -49,8 +49,8 @@ protected:
    int len;
    void**  data;
 
-   inline int check(int);
-   inline int checkConst(int) const;
+   inline void check(int);
+   inline void checkConst(int) const;
    static void copy(const Array<void*> *source, int srcPos, Array<void*> *dest, int destPos, int length);
 };
 
@@ -60,7 +60,7 @@ public:
 	explicit Vector(int length = 0);
 	Vector(const Vector<void*>&);
 	Vector<void*>& operator= (const Vector<void*>&);
-	int check(int);
+	void check(int);
 
 	inline void* const operator[](int index) const;
 	inline void*& operator[](int index);
@@ -98,14 +98,16 @@ public:
 
    int indexOf(const T& elem, int pos = 0) const;
    inline T** const getData() const { return (T**) Array<void*>::getData(); }
-   inline void exchange(int p1, int p2) { Array<void*>::exchange(p1, p2); }
+   using Array<void*>::exchange; 
+   using Array<void*>::reverse; 
+//   inline void exchange(int p1, int p2) { Array<void*>::exchange(p1, p2); }
 //   inline void sort() { Array<void*>::sort(p1, p2); }
-   inline void reverse() { Array<void*>::reverse(p1, p2); }
+//   inline void reverse() { Array<void*>::reverse(p1, p2); }
 //   inline void sort(int (*compareFun)(const T&, const T&), int l = 0, int r = Math::MAX_INT) { Array<void*>::sort((voidPtrCompareFunction)compareFun, l, r); }
 
 protected:
-   inline int check(int pos) { return Array<void*>::check(pos); }
-   inline int checkConst(int pos) const { return Array<void*>::checkConst(pos); }
+   inline void check(int pos) { Array<void*>::check(pos); }
+   inline void checkConst(int pos) const { Array<void*>::checkConst(pos); }
    inline static void copy(const Array<T*> *source, int srcPos, Array<T*> *dest, int destPos, int length)
    { Array<void*>::copy((const Array<void*>*) source, srcPos, (const Array<void*>*) dest, destPos, length); }
 };
@@ -116,7 +118,7 @@ public:
    inline explicit Vector(int length = 0) : Vector<void*>(length) {}
    inline Vector(const Vector<T*>& arr) : Vector<void*>((const Vector<void*>&)arr) {}
    inline Vector<T*>& operator= (const Vector<T*>& arr) { return ((Vector<T*>&)Vector<void*>::operator=((const Vector<void*>&)arr)); }
-   inline int check(int pos) { return Vector<void*>::check(pos); }
+   inline void check(int pos) { Vector<void*>::check(pos); }
 
    inline int length() const { return Vector<void*>::length(); }
    inline T* const operator[](int index) const { return ((T* const)Vector<void*>::operator[](index)); }
@@ -126,9 +128,11 @@ public:
    inline Vector<T*>& operator +=(const Array<T*>& arr) { return (Vector<T*>&) Vector<void*>::operator+=((const Array<void*>&) arr); }
 
    inline const T** getData() const { return (T**) Vector<void*>::getData(); }
-   inline void exchange(int p1, int p2) { Vector<void*>::exchange(p1, p2); }
+   using Array<void*>::exchange; 
+   using Array<void*>::reverse; 
+//   inline void exchange(int p1, int p2) { Vector<void*>::exchange(p1, p2); }
 //   inline void sort() { Vector<void*>::sort(p1, p2); }
-   inline void reverse() { Vector<void*>::reverse(p1, p2); }
+//   inline void reverse() { Vector<void*>::reverse(p1, p2); }
 //   inline void sort(int (*compareFun)(const T&, const T&), int l = 0, int r = Math::MAX_INT) { Vector<void*>::sort((voidPtrCompareFunction)compareFun, l, r); }
 
    inline void insert(T* elem, int before) { Vector<void*>::insert((void*) elem, before); }
@@ -140,7 +144,7 @@ public:
    inline void deleteAll() { lrt::deleteAll(*this); }
 
 protected:
-   inline int checkConst(int pos) const { return Vector<void*>::checkConst(pos); }
+   inline void checkConst(int pos) const { Vector<void*>::checkConst(pos); }
    inline static void copy(const Array<T*> *source, int srcPos, Vector<T*> *dest, int destPos, int length)
 	{ Vector<void*>::copy((const Array<void*>*) source, srcPos, (const Vector<void*>*) dest, destPos, length); }
 };
@@ -171,8 +175,8 @@ protected:
    int len;
    char* data;
 
-   inline int check(int);
-   inline int checkConst(int) const;
+   inline void check(int);
+   inline void checkConst(int) const;
    static void copy(const Array<char> *source, int srcPos, Array<char> *dest, int destPos, int length);
 };
 
@@ -182,7 +186,7 @@ public:
 	explicit Vector(int length = 0);
 	Vector(const Vector<char>&);
 	Vector<char>& operator= (const Vector<char>&);
-	int check(int);
+	void check(int);
 
 	inline char operator[](int index) const;
 	inline char& operator[](int index);
@@ -208,12 +212,14 @@ protected:
 //////////// Array<void*>
 inline void* const Array<void*>::operator[](int i) const
 {
-   return data[checkConst(i)];
+	checkConst(i); 
+    return data[i];
 }
 
 inline void*& Array<void*>::operator[](int i)
 {
-   return data[check(i)];
+	check(i); 
+    return data[i];
 }
 
 inline int Array<void*>::length() const
@@ -235,7 +241,7 @@ inline void Array<void*>::exchange(int p1, int p2)
 	data[p2] = temp;
 }
 
-inline int Array<void*>::check(int i)
+inline void Array<void*>::check(int i)
 {
 #ifndef __NOCHECK__
    if (i < 0 || i >= len){
@@ -243,10 +249,9 @@ inline int Array<void*>::check(int i)
 	   System::exit(-1, "Array index out of bounds!");
    }
 #endif
-   return i;
 }
 
-inline int Array<void*>::checkConst(int i) const
+inline void Array<void*>::checkConst(int i) const
 { 
 #ifndef __NOCHECK__
    if (i < 0 || i >= len){
@@ -254,22 +259,22 @@ inline int Array<void*>::checkConst(int i) const
 	   System::exit(-1, "Array Index out of bounds!");
    }
 #endif
-   return i; 
 }
 
 //////////////// Vector<void*>
 
 inline void* const Vector<void*>::operator[](int i) const 
 { 
-   return data[checkConst(i)]; 
+	checkConst(i); 
+    return data[i]; 
 }
 
 inline void*& Vector<void*>::operator[](int i)
 { 
-	void*& ret = data[check(i)];
+	check(i); 
 	if(len <= i)
 	  len = i+1;
-	return ret;
+	return data[i];
 }
 
 inline int Vector<void*>::up2pow(int val)
@@ -284,12 +289,14 @@ inline int Vector<void*>::up2pow(int val)
 //////////// Array<char>
 inline char Array<char>::operator[](int i) const
 {
-   return data[checkConst(i)];
+	checkConst(i); 
+    return data[i];
 }
 
 inline char& Array<char>::operator[](int i)
 {
-   return data[check(i)];
+	check(i); 
+    return data[i];
 }
 
 inline int Array<char>::length() const
@@ -311,7 +318,7 @@ inline void Array<char>::exchange(int p1, int p2)
 	data[p2] = temp;
 }
 
-inline int Array<char>::check(int i)
+inline void Array<char>::check(int i)
 {
 #ifndef __NOCHECK__
    if (i < 0 || i >= len){
@@ -319,10 +326,9 @@ inline int Array<char>::check(int i)
 	   System::exit(-1, "Array index out of bounds!");
    }
 #endif
-   return i; 
 }
 
-inline int Array<char>::checkConst(int i) const
+inline void Array<char>::checkConst(int i) const
 { 
 #ifndef __NOCHECK__
    if (i < 0 || i >= len){
@@ -330,22 +336,22 @@ inline int Array<char>::checkConst(int i) const
 	   System::exit(-1, "Array Index out of bounds!");
    }
 #endif
-   return i; 
 }
 
 //////////////// Vector<char>
 
 inline char Vector<char>::operator[](int i) const
 {
-   return data[checkConst(i)];
+	checkConst(i); 
+    return data[i];
 }
 
 inline char& Vector<char>::operator[](int i)
 {
-	char& ret = data[check(i)];
+	check(i); 
 	if(len <= i)
 	  len = i+1;
-	return ret;
+	return data[i];
 }
 
 inline int Vector<char>::up2pow(int val)
