@@ -1,7 +1,7 @@
 /*
  * rtcollect.templ.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -52,6 +52,7 @@ template<class T> Array<T>::Array(const T* ptr, int off, int len) : len(len), da
 template<class T> Array<T>::~Array()
 { 
 	delete [] data; 
+	data = 0; 
 }
 
 template<class T> int Array<T>::length() const 
@@ -61,18 +62,21 @@ template<class T> int Array<T>::length() const
 
 template<class T> const T& Array<T>::operator[](int i) const 
 { 
-   return data[checkConst(i)]; 
+	checkConst(i); 
+    return data[i]; 
 }
 
 template<class T> T& Array<T>::operator[](int i)
 { 
-   return data[check(i)];
+	check(i); 
+    return data[i];
 }
 
 template<class T> Array<T>& Array<T>::operator= (const Array<T>& arr)
 {
-   copy(&arr, 0, this, 0, arr.len);
-   return *this;
+	if(&arr != this)
+		copy(&arr, 0, this, 0, arr.len);
+	return *this;
 }
 
 template<class T> int Array<T>::indexOf(const T& elem, int pos) const
@@ -150,7 +154,7 @@ template<class T> void Array<T>::sort(int (*compareFun)(const T&, const T&), int
 }
 
 
-template<class T> int Array<T>::check(int i) 
+template<class T> void Array<T>::check(int i) 
 { 
 #ifndef __NOCHECK__
    if (i < 0 || i >= len){
@@ -161,10 +165,9 @@ template<class T> int Array<T>::check(int i)
 	   System::exit(-1, err);
    }
 #endif
-   return i; 
 }
 
-template<class T> int Array<T>::checkConst(int i) const
+template<class T> void Array<T>::checkConst(int i) const
 { 
 #ifndef __NOCHECK__
    if (i < 0 || i >= len){
@@ -175,7 +178,6 @@ template<class T> int Array<T>::checkConst(int i) const
 	   System::exit(-1, err);
    }
 #endif
-   return i; 
 }
 
 template<class T> void Array<T>::copy(const Array<T> *source, int srcPos, Array<T> *dest, int destPos, int length)
@@ -211,21 +213,24 @@ template<class T> Vector<T>::Vector(const Vector<T>& vect) : Array<T>(vect.capac
 
 template<class T> const T& Vector<T>::operator[](int i) const 
 { 
-   return data[checkConst(i)]; 
+	checkConst(i); 
+    return data[i]; 
 }
 
 template<class T> T& Vector<T>::operator[](int i)
 { 
-	T& ret = data[check(i)];
+	check(i); 
 	if(len <= i)
 	  len = i+1;
-	return ret;
+	return data[i];
 }
 
 template<class T> Vector<T>& Vector<T>::operator= (const Vector<T>& arr)
 {
-	copy(&arr, 0, this, 0, arr.len);
-	len = arr.len;
+	if(&arr != this) {
+		copy(&arr, 0, this, 0, arr.len);
+		len = arr.len;
+	}
 	return *this;
 }
 
@@ -273,7 +278,7 @@ template<class T> inline int Vector<T>::up2pow(int val)
 	return ret;
 }
 
-template<class T> int Vector<T>::check(int i)
+template<class T> void Vector<T>::check(int i)
 {
 #ifndef __NOCHECK__
 	if(i < 0){
@@ -285,7 +290,7 @@ template<class T> int Vector<T>::check(int i)
 	}
 #endif
 	if(i < capacity) 
-		return i;
+		return;
 	// need growing
 	int newcap = up2pow(i+1);
 	T* newdata = new T[newcap];
@@ -294,7 +299,6 @@ template<class T> int Vector<T>::check(int i)
 	delete [] data;
 	data = newdata;
 	capacity = newcap;
-	return i;
 }
 
 template<class T> void Vector<T>::copy(const Array<T> *source, int srcPos, Vector<T> *dest, int destPos, int length)
