@@ -1,7 +1,7 @@
 /*
  * rtnetwork.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -21,28 +21,20 @@
 #include "rtmap.h"
 #include "rtchar.h"
 
-#include "simpsock/sockets.h"
-#undef close
+#include "sockfunc.h"
 
 namespace lrt {
 
 Socket* Network::create(const String& server, int port)
 {
-	String xserver = "@";
-	xserver += server; 
-	String mode = "c";
-	mode += port;
-
-	::Socket* sk = ::Sopen((char*) xserver.cStr(), (char*) mode.cStr());
+	SFSocket* sk = ::Sopen_client((char*) server.cStr(), port);
 	if(!sk) return 0; // error
 	return new Socket(sk);
 }
 
 ServerSocket* Network::createServer(int port)
 {
-	String mode = "s";
-	mode += port;
-	::Socket* sk = ::Sopen("", (char*) mode.cStr());
+	SFSocket* sk = ::Sopen_server(port);
 	if(!sk) return 0; // error
 	return new ServerSocket(sk);
 }
@@ -114,6 +106,7 @@ bool Network::httpRequest(const String& server, int port, HttpMethod method, con
 
      GET /some-path/index.html HTTP/1.0
 	 User-Agent: libRT 0.1
+	 Host: server:port
 	 More Headers
 
     */
@@ -133,6 +126,9 @@ bool Network::httpRequest(const String& server, int port, HttpMethod method, con
 	// now process headers 
 	if(!page.headers.isSet("User-Agent"))
 		page.headers["User-Agent"] = "libRT/0.1";
+	if(!page.headers.isSet("Host"))
+		page.headers["Host"] = server + ":" + port; 
+
 	for(Iterator<Pair<String,String> > headers = page.headers.begin(); headers.hasElement(); ++headers)
 	{
 		Pair<String, String>& header = headers.get();
@@ -259,14 +255,14 @@ NetworkOutputStream* Socket::getOutput()
 
 String Socket::getPeerName()
 {
-	char* peer = ::Speername((::Socket*) sock);
+	char* peer = ::Speername((SFSocket*) sock);
 	return String(peer);
 }
 
 void Socket::close()
 {
 	if(sock)
-		::Sclose((::Socket*) sock);
+		::Sclose((SFSocket*) sock);
 	sock = 0;
 }
 
@@ -286,7 +282,7 @@ Socket* ServerSocket::accept()
 {
 	if(!sock)
 		return 0;
-	::Socket* client = ::Saccept((::Socket*) sock);
+	SFSocket* client = ::Saccept((SFSocket*) sock);
 	return new lrt::Socket(client);
 }
 
@@ -303,7 +299,7 @@ NetworkInputStream::~NetworkInputStream()
 
 int NetworkInputStream::read()
 {
-	::Socket* sk = (::Socket*) sock->sock;
+	SFSocket* sk = (SFSocket*) sock->sock;
 	if(!sk) { _fail = true; return -1; } // socket is closed
 
 	// process timeout
@@ -325,7 +321,7 @@ int NetworkInputStream::read()
 
 int NetworkInputStream::read(Array<char> &b, int off, int len)
 {
-	::Socket* sk = (::Socket*) sock->sock;
+	SFSocket* sk = (SFSocket*) sock->sock;
 	if(!sk) { _fail = true; return -1; } // socket is closed
 
 	// check array access
@@ -355,7 +351,7 @@ bool NetworkInputStream::eos()
 {
 	if(sock->isClosed())
 		return true;
-	int test = ::Stest((::Socket*) sock->sock);
+	int test = ::Stest((SFSocket*) sock->sock);
 	return (test < 0 || test == EOF);
 }
 // does nothing
@@ -370,7 +366,7 @@ NetworkOutputStream::~NetworkOutputStream()
 
 bool NetworkOutputStream::write(int b)
 {
-	::Socket* sk = (::Socket*) sock->sock;
+	SFSocket* sk = (SFSocket*) sock->sock;
 	if(!sk) return false; // socket is closed
 
 	unsigned char c = b;
@@ -381,7 +377,7 @@ bool NetworkOutputStream::write(int b)
 
 bool NetworkOutputStream::write(const Array<char> &b, int off, int len)
 {
-	::Socket* sk = (::Socket*) sock->sock;
+	SFSocket* sk = (SFSocket*) sock->sock;
 	if(!sk) return false; // socket is closed
 
 	const char* data = b.getData();
