@@ -1,7 +1,7 @@
 /*
  * rtstring.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -27,6 +27,13 @@
 #include <stdio.h>
 #endif
 
+#ifndef _MSC_VER
+#   define LrtVsnprintf vsnprintf
+#else // MSVC
+#   define LrtVsnprintf _vsnprintf
+#endif
+
+
 
 namespace lrt {
 
@@ -155,6 +162,46 @@ String& String::operator= (const String& str)
 	return *this;
 }
 
+#ifdef printf
+#undef printf
+#endif
+
+void String::printf(const char* message, ...)
+{
+	va_list args;
+	va_start(args, message); 
+	printfv(message, args); 
+}
+
+void String::printfv(const char* message, va_list args)
+{
+	int req = 0; 
+	do {
+		check(req);
+		req = LrtVsnprintf(data, capacity, message, args);
+		if(req < 0) // some versions of snprintf return -1 if it doesn't fit, then try again with larger capacity
+			req = capacity * 2 - 1; 
+	} while(req >= capacity);
+	// set length
+	len = cStrLength(data); 
+}
+
+String String::format(const char* message, ...)
+{
+	va_list args;
+	va_start(args, message); 
+	return formatv(message, args); 	
+}
+
+String String::formatv(const char* message, va_list args)
+{
+	String ret; 
+	ret.printfv(message, args);
+	return ret; 
+}
+
+
+
 /*
 const char& String::operator[](int index) const
 {
