@@ -1,7 +1,7 @@
 /*
  * rtstring.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -26,6 +26,13 @@
 #include "rtcollect.h"
 #include "rtmath.h"
 
+#include <stdarg.h>
+
+// In some buggy libc's printf is a macro. 
+#ifdef printf
+#undef printf
+#endif
+
 namespace lrt {
 
 /** A sequence of characters. 
@@ -91,6 +98,20 @@ public:
 	  * @return A reference to this string. */
 	String& operator= (const String&);
 
+	/** Clears the string, then fills it with the printf-formatted message, inserting 
+	  * all the variable arguments. */
+	void printf(const char* message, ...);
+	/** Clears the string, then fills it with the printf-formatted message, inserting 
+	  * all the variable arguments. */
+	void printfv(const char* message, va_list args);
+
+	/** Returns a string which contains the printf-formatted message with all variable
+	  * arguments inserted. */
+	static String format(const char* message, ...); 
+	/** Returns a string which contains the printf-formatted message with all variable
+	  * arguments inserted. */
+	static String formatv(const char* message, va_list args); 
+
     /** Returns a constant reference to the character at position <tt>index</tt>,
 	  * if <tt>index</tt> is not contained within this string, exits the application. */
 //	const char& operator[](int index) const;
