@@ -1,7 +1,7 @@
 /*
  * rtsystem.win32.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -85,6 +85,38 @@ void System::exit(int errnum)
 }
 
 
+void LrtSysWriteToConsole(const char* str, int len)
+{
+	// convert '\n' to '\r\n'
+	char* buf = new char[2 * len + 1]; 
+
+	int addlen = 0; 
+	char lastCh = 0; 
+	for(int i = 0; i < len; i++) {
+		char ch = str[i]; 
+		if(ch == '\n' && lastCh != '\r') {
+			buf[i + addlen] = '\r'; 
+			addlen++;
+		}
+		buf[i + addlen] = ch; 
+		lastCh = ch; 
+	}
+	len += addlen; 
+	buf[len] = 0; 
+
+	// ... and, if it's a console, also convert ANSI to OEM charset. 
+	if(GetFileType(SYSstdout) == FILE_TYPE_CHAR) {
+		// convert str to OEM charset if printing on console
+		CharToOem(buf, buf); // according to MSDN docs, this is safe in ANSI BUILD ONLY. 
+	}
+
+	unsigned long numb; 
+	WriteFile(SYSstdout, buf, len, &numb, 0); 
+	delete[] buf; 
+}
+
+
+
 void System::exit(int errnum, const String &errmsg)
 {
 	if(interactive) {
@@ -93,8 +125,7 @@ void System::exit(int errnum, const String &errmsg)
 		MessageBox(0, errmsg.cStr(), title.cStr(), MB_OK);
 	}
 	else {
-		unsigned long numb;
-		WriteFile(SYSstdout, errmsg.cStr(), errmsg.length(), &numb, 0);
+		LrtSysWriteToConsole(errmsg.cStr(), errmsg.length()); 
 	}
 	FlushFileBuffers(SYSstdout);
 	finalize();
@@ -137,15 +168,13 @@ void System::initialize()
 void System::print(const char *cStr)
 {
 	if(!init) initialize();
-	unsigned long numb;
-	WriteFile(SYSstdout, cStr, lstrlen(cStr), &numb, 0);
+	LrtSysWriteToConsole(cStr, lstrlen(cStr)); 
 }
 
 void System::print(const String &str)
 {
 	if(!init) initialize();
-	unsigned long numb;
-	WriteFile(SYSstdout, str.cStr(), str.length(), &numb, 0);
+	LrtSysWriteToConsole(str.cStr(), str.length()); 
 }
 
 void System::println()
@@ -153,14 +182,13 @@ void System::println()
 	if(!init) initialize();
 	unsigned long numb;
 	WriteFile(SYSstdout, "\r\n", 2, &numb, 0);
-//	FlushFileBuffers(SYSstdout);
 }
 
 void System::println(const String &str)
 {
 	if(!init) initialize();
 	unsigned long numb;
-	WriteFile(SYSstdout, str.cStr(), str.length(), &numb, 0);
+	LrtSysWriteToConsole(str.cStr(), str.length()); 
 	WriteFile(SYSstdout, "\r\n", 2, &numb, 0);
 }
 
