@@ -1,7 +1,7 @@
 /*
  * kickbot.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -21,6 +21,7 @@
 #include <rtini.h>
 
 #include "robvars.h"
+#include "robtrans.h"
 
 // always include this file as the last one
 #include <rtmain.h>
@@ -52,7 +53,7 @@ KickbotArgs parseArgs(const lrt::Array<lrt::String>& args)
 			{
 				i++;
 				if(i >= args.length())
-					lrt::System::exit(1, "Parameter missing for argument -" + arg);
+					lrt::System::exit(1, _("Parameter missing for argument -") + arg);
 				// ensure that a path was given
 				lrt::String temp = args[i];
 				if(!temp.endsWith("/") && !temp.endsWith(lrt::File::separator))
@@ -77,7 +78,7 @@ KickbotArgs parseArgs(const lrt::Array<lrt::String>& args)
 			{
 				i++; // look at next arg
 				if(i >= args.length())
-					lrt::System::exit(1, "Parameter missing for argument -" + arg);
+					lrt::System::exit(1, _("Parameter missing for argument -") + arg);
 				lrt::String newCurrentFolder = args[i];
 				// check that a path was given
 				char c = newCurrentFolder[newCurrentFolder.length() - 1];
@@ -97,7 +98,7 @@ KickbotArgs parseArgs(const lrt::Array<lrt::String>& args)
 #endif
 			else
 			{
-				lrt::System::println("Warning: unknown parameter " + args[i]);
+				lrt::System::println(_("Warning: unknown parameter ") + args[i]);
 			}
 		}
 		else // file or file pattern
@@ -119,24 +120,24 @@ KickbotArgs parseArgs(const lrt::Array<lrt::String>& args)
 
 void printHelp()
 {
-	lrt::System::println("Removes some robots from a tournament that was run");
-	lrt::System::println("using the top mode (-t) of RoboTour. ");
-	lrt::System::println("You will have to re-run makehtml after this operation.");
+	lrt::System::println(_("Removes some robots from a tournament that was run\n"
+						   "using the top mode (-t) of RoboTour. \n"
+						   "You will have to re-run makehtml after this operation."));
 	lrt::System::println();
 
-	lrt::System::println("Usage: kickbot [options] [prog1 [prog2 [...]]]");
-	lrt::System::println(lrt::String("Version ") + version);
+	lrt::System::println(_("Usage: kickbot [options] [prog1 [prog2 [...]]]"));
+	lrt::System::println(lrt::String(_("Version ")) + getVersion());
 	lrt::System::println();
-	lrt::System::println("Options:");
+	lrt::System::println(_("Options:"));
 #ifdef __SYMBIAN32__
-	lrt::System::println("  -cd F      Set current folder to F before running robotour.");
+	lrt::System::println(_("  -cd F      Set current folder to F before running robotour."));
 #endif
-	lrt::System::println("  -cf   F     Sets the competition folder to F (default: current)");
- 	lrt::System::println("  -h, -help   Print this help text."); 
-	lrt::System::println("  progn       Any robot file name, or file pattern.");
-	lrt::System::println("              These file names should be entered relative to the");
-	lrt::System::println("              competition folder (see -cf). If no files are given,");
-	lrt::System::println("              only the charts page, but no detailed pages is created.");
+	lrt::System::println(_("  -cf   F     Sets the competition folder to F (default: current)"));
+ 	lrt::System::println(_("  -h, -help   Print this help text.")); 
+	lrt::System::println(_("  progn       Any robot file name, or file pattern.\n"
+						   "              These file names should be entered relative to the\n"
+						   "              competition folder (see -cf). If no files are given,\n"
+						   "              only the charts page, but no detailed pages is created."));
 }
 
 lrt::String getInfoFileName(const lrt::File& compFolder, const lrt::String& botname)
@@ -158,10 +159,7 @@ lrt::String getInfoFileName(const lrt::File& compFolder, const lrt::String& botn
 
 
 
-/** Since rtmain.h includes system includes, we may not import any namespace in
-  * this file. Only in this file, really. */
-
-int rtMain(const lrt::Array<lrt::String>& args)
+int rtRun(const lrt::Array<lrt::String>& args)
 {
 	lrt::System::setAppName("Kickbot");
 	rt::KickbotArgs margs = rt::parseArgs(args);
@@ -198,3 +196,62 @@ int rtMain(const lrt::Array<lrt::String>& args)
 	return 0;
 }
 
+
+// WXWIN SUPPORT (TRANSLATION) /////////////////////////////////
+#ifdef __WXWIN__
+#	include "robuntrans.h"
+#	include "robwxutil.h"
+#	include <wx/wx.h>
+
+const lrt::Array<lrt::String>* theArgs;
+
+class KickbotWxApp : public wxApp {
+public:
+	virtual bool OnInit() {
+		bool locOk = myLocale.Init();
+
+#ifdef EXTRA_DATA_DIR
+		myLocale.AddCatalogLookupPathPrefix(wxString(wxT(EXTRA_DATA_DIR)) + wxFILE_SEP_PATH + wxT("locale")); 
+#endif
+		// look near the executable file also
+		myLocale.AddCatalogLookupPathPrefix(Wx::Conv(lrt::File(lrt::File::getExecutableFile().getParent(), "locale").getName()));
+
+		
+		locOk &= myLocale.AddCatalog(wxT("robotour"));
+		/*if(!locOk)
+			lrt::System::println("warning: Program translation for language "
+			+ Wx::Conv(myLocale.GetName()) + " could not be loaded. \nThe program will be in English.");
+		*/
+		// in some configurations, we bring out own version of the wxstd catalog
+		myLocale.AddCatalog(wxT("robotour-wxstd")); 
+
+		return true; 
+	}
+
+	virtual int OnRun() {
+		return rtRun(*theArgs); 
+	}
+
+private:
+	wxLocale myLocale;
+};
+
+IMPLEMENT_APP_NO_MAIN(KickbotWxApp)
+
+int rtMain(const lrt::Array<lrt::String>& args)
+{
+	theArgs = &args; 
+	return Wx::Startup();
+}
+
+
+#else // !WXWIN
+
+int rtMain(const lrt::Array<lrt::String>& args)
+{
+	return rtRun(args); 
+}
+
+
+#endif // WXWIN
+
