@@ -1,7 +1,7 @@
 /*
  * makehtml.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -23,6 +23,7 @@
 #include "robvars.h"
 #include "robmanage.h"
 #include "robhtml.h"
+#include "robtrans.h"
 
 // Have Resources => Have Fun!
 #include "resources.rh"
@@ -36,7 +37,7 @@ class MkHtmlArgs{
 public:
 	MkHtmlArgs() : links(true), downloadLinks(true),
 		compFolder(lrt::File::getCurrentFolder()), outFolder(lrt::File::getCurrentFolder()),
-		files(0), compName("New Competition"), recalc(false), printHelp(false) {}
+		files(0), compName(_("New Competition")), recalc(false), printHelp(false) {}
 
 	bool links, downloadLinks;
 	lrt::File compFolder, outFolder;
@@ -61,7 +62,7 @@ MkHtmlArgs parseArgs(const lrt::Array<lrt::String>& args)
 			{
 				i++;
 				if(i >= args.length())
-					System::exit(1, "Parameter missing for argument -" + arg);
+					lrt::System::exit(1, _("Parameter missing for argument -") + arg);
 				margs.compName = args[i];
 			}
 			// "c"ompetition "f"older
@@ -69,11 +70,11 @@ MkHtmlArgs parseArgs(const lrt::Array<lrt::String>& args)
 			{
 				i++;
 				if(i >= args.length())
-					System::exit(1, "Parameter missing for argument -" + arg);
+					lrt::System::exit(1, _("Parameter missing for argument -") + arg);
 				// ensure that a path was given
-				String temp = args[i];
-				if(!temp.endsWith("/") && !temp.endsWith(File::separator))
-					temp += File::separatorChar;
+				lrt::String temp = args[i];
+				if(!temp.endsWith("/") && !temp.endsWith(lrt::File::separator))
+					temp += lrt::File::separatorChar;
 
 				margs.compFolder = temp;
 			}
@@ -82,18 +83,18 @@ MkHtmlArgs parseArgs(const lrt::Array<lrt::String>& args)
 			{
 				i++;
 				if(i >= args.length())
-					System::exit(1, "Parameter missing for argument -" + arg);
+					lrt::System::exit(1, _("Parameter missing for argument -") + arg);
 				// ensure that a path was given
-				String temp = args[i];
-				if(!temp.endsWith("/") && !temp.endsWith(File::separator))
-					temp += File::separatorChar;
+				lrt::String temp = args[i];
+				if(!temp.endsWith("/") && !temp.endsWith(lrt::File::separator))
+					temp += lrt::File::separatorChar;
 
 				margs.outFolder = temp;
 			}
 			// "batch" mode (non-interactive)
 			else if(!arg.compareIgnoreCase("batch"))
 			{
-				System::setInteractive(false);
+				lrt::System::setInteractive(false);
 			}
 			// create "no links"
 			else if(!arg.compareIgnoreCase("nolinks"))
@@ -122,29 +123,29 @@ MkHtmlArgs parseArgs(const lrt::Array<lrt::String>& args)
 			{
 				i++; // look at next arg
 				if(i >= args.length())
-					System::exit(1, "Parameter missing for argument -" + arg);
-				String newCurrentFolder = args[i];
+					System::exit(1, _("Parameter missing for argument -") + arg);
+				lrt::String newCurrentFolder = args[i];
 				// check that a path was given
 				char c = newCurrentFolder[newCurrentFolder.length() - 1];
 				// no path => append slash
-				if(!(c == '/') && !(c == File::separatorChar))
-					newCurrentFolder += File::separatorChar;
+				if(!(c == '/') && !(c == lrt::File::separatorChar))
+					newCurrentFolder += lrt::File::separatorChar;
 
 				// get competition folders
-				String compFolder = margs.compFolder.getLocalName();
-				String outFolder = margs.outFolder.getLocalName();
+				lrt::String compFolder = margs.compFolder.getLocalName();
+				lrt::String outFolder = margs.outFolder.getLocalName();
 
 				// set current folder
-				File::setCurrentFolder(File(newCurrentFolder));
+				lrt::File::setCurrentFolder(File(newCurrentFolder));
 
 				// set competition folders
-				margs.compFolder = File(compFolder);
-				margs.outFolder = File(outFolder);
+				margs.compFolder = lrt::File(compFolder);
+				margs.outFolder = lrt::File(outFolder);
 			}
 #endif
 			else
 			{
-				System::println("Warning: unknown parameter " + args[i]);
+				lrt::System::println(_("Warning: unknown parameter ") + args[i]);
 			}
 		}
 		else // file or file pattern
@@ -166,28 +167,28 @@ MkHtmlArgs parseArgs(const lrt::Array<lrt::String>& args)
 
 void printHelp()
 {
-	lrt::System::println("Creates charts and detailed results for competitions");
-	lrt::System::println("that were run using the top mode (-t) of RoboTour. ");
+	lrt::System::println(_("Creates charts and detailed results for competitions\n"
+		 				   "that were run using the top mode (-t) of RoboTour. "));
 	lrt::System::println();
 
-	lrt::System::println("Usage: makehtml [options] [prog1 [prog2 [...]]]");
-	lrt::System::println(String("Version ") + version);
+	lrt::System::println(_("Usage: makehtml [options] [prog1 [prog2 [...]]]"));
+	lrt::System::println(lrt::String(_("Version ")) + getVersion());
 	lrt::System::println();
-	lrt::System::println("Options:");
+	lrt::System::println(_("Options:"));
 #ifdef __SYMBIAN32__
-	lrt::System::println("  -cd F      Set current folder to F before running robotour.");
+	lrt::System::println(_("  -cd F      Set current folder to F before running robotour."));
 #endif
-	lrt::System::println("  -name N     Sets the competition name to N (default: \"New Competition\")");
-	lrt::System::println("  -cf   F     Sets the competition folder to F (default: current)");
-	lrt::System::println("  -of   F     Sets the output folder to F (default: current)");
-	lrt::System::println("  -nolinks    Does not create links between the pages. ");
-	lrt::System::println("  -nodownload Does not create download links for the rob files.");
-	lrt::System::println("  -recalc     Recalculates the charts (useful after kickbot). ");
- 	lrt::System::println("  -h, -help   Print this help text."); 
-	lrt::System::println("  progn       Any robot file name, or file pattern.");
-	lrt::System::println("              These file names should be entered relative to the");
-	lrt::System::println("              competition folder (see -cf). If no files are given,");
-	lrt::System::println("              only the charts page, but no detailed pages is created.");
+	lrt::System::println(_("  -name N     Sets the competition name to N (default: \"New Competition\")"));
+	lrt::System::println(_("  -cf   F     Sets the competition folder to F (default: current)"));
+	lrt::System::println(_("  -of   F     Sets the output folder to F (default: current)"));
+	lrt::System::println(_("  -nolinks    Does not create links between the pages. "));
+	lrt::System::println(_("  -nodownload Does not create download links for the rob files."));
+	lrt::System::println(_("  -recalc     Recalculates the charts (useful after kickbot). "));
+ 	lrt::System::println(_("  -h, -help   Print this help text.")); 
+	lrt::System::println(_("  progn       Any robot file name, or file pattern.\n"
+						   "              These file names should be entered relative to the\n"
+						   "              competition folder (see -cf). If no files are given,\n"
+						   "              only the charts page, but no detailed pages is created."));
 }
 
 } // namespace
@@ -195,7 +196,7 @@ void printHelp()
 /** Since rtmain.h includes system includes, we may not import any namespace in
   * this file. Only in this file, really. */
 
-int rtMain(const lrt::Array<lrt::String>& args)
+int rtRun(const lrt::Array<lrt::String>& args)
 {
 	lrt::System::setAppName("MakeHTML");
 	initAllResources();
@@ -212,7 +213,7 @@ int rtMain(const lrt::Array<lrt::String>& args)
 		margs.links, margs.downloadLinks);
 	if(!html.createChartsHtml(margs.recalc)) 
 	{
-		lrt::System::println("warning: couldn't create charts html.");
+		lrt::System::println(_("warning: couldn't create charts html"));
 		if(!margs.files.length()) // probably, no args at all
 			rt::printHelp();
 	}
@@ -220,10 +221,69 @@ int rtMain(const lrt::Array<lrt::String>& args)
 	for(int f = 0; f < margs.files.length(); f++)
 	{
 		if(!html.createDetailedHtml(margs.files[f]))
-			lrt::System::println("warning: couldn't create detailed html for " + 
-				margs.files[f] + ".");
+			lrt::System::println(_("warning: couldn't create detailed html for robot ") + 
+				margs.files[f]);
 	}
 
 	return 0;
 }
 
+
+// WXWIN SUPPORT /////////////////////////////////
+#ifdef __WXWIN__
+#	include "robuntrans.h"
+#	include "robwxutil.h"
+#	include <wx/wx.h>
+
+const lrt::Array<lrt::String>* theArgs;
+
+class MakehtmlWxApp : public wxApp {
+public:
+	virtual bool OnInit() {
+		bool locOk = myLocale.Init();
+
+#ifdef EXTRA_DATA_DIR
+		myLocale.AddCatalogLookupPathPrefix(wxString(wxT(EXTRA_DATA_DIR)) + wxFILE_SEP_PATH + wxT("locale")); 
+#endif
+		// look near the executable file also
+		myLocale.AddCatalogLookupPathPrefix(Wx::Conv(lrt::File(lrt::File::getExecutableFile().getParent(), "locale").getName()));
+
+		
+		locOk &= myLocale.AddCatalog(wxT("robotour"));
+		/*if(!locOk)
+			lrt::System::println("warning: Program translation for language "
+			+ Wx::Conv(myLocale.GetName()) + " could not be loaded. \nThe program will be in English.");
+		*/
+		// in some configurations, we bring out own version of the wxstd catalog
+		myLocale.AddCatalog(wxT("robotour-wxstd")); 
+
+		return true; 
+	}
+
+	virtual int OnRun() {
+		return rtRun(*theArgs); 
+	}
+
+private:
+	wxLocale myLocale;
+};
+
+IMPLEMENT_APP_NO_MAIN(MakehtmlWxApp)
+
+int rtMain(const lrt::Array<lrt::String>& args)
+{
+	theArgs = &args; 
+	return Wx::Startup();
+}
+
+
+#else // !WXWIN
+
+int rtMain(const lrt::Array<lrt::String>& args)
+{
+	return rtRun(args); 
+}
+
+
+#endif // WXWIN
+
