@@ -1,7 +1,7 @@
 /*
  * robbase.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -20,6 +20,7 @@
 #include "robvars.h"
 #include "robstrings.h"
 #include "robglob.h"
+#include "robtrans.h"
 
 #include <rtsystem.h>
 #include <rtstring.h>
@@ -49,6 +50,7 @@ Simulation::Simulation(const Globals& glob, const ErrorHandler* errHandler) :
 	vars[simTimeout] = (rint)(glob.timeout / 1000);
 	vars[simElimTrigger] = (glob.enableElim ? (rint)glob.elim : (rint)-1);
 	vars[simMaxLifetime] = (glob.enableLifetime ? (rint)(glob.maxLifetime / 1000) : (rint)-1);
+	vars[simMaxFirstLifetime] = (glob.enableFirstLifetime ? (rint)(glob.firstMaxLifetime / 1000) : (rint)-1);
 
 	for(int f = 0; f < field.length(); f++)
 		field[f] = 0;
@@ -178,18 +180,21 @@ void Simulation::processBots()
 		  n = n->getNext();
 	}
 	// process age
-	if(glob.enableLifetime) 
+	if(glob.enableLifetime || glob.enableFirstLifetime) 
 	{
 		for(List<Bot*>::Node* n2 = bots.first(); n2; )
 		{
 			Bot* current = n2->accessElement();
-			if((curCycle - current->creationCycle) >= glob.maxLifetime)
+			long age = curCycle - current->creationCycle; 
+			bool isMotherbot = current->vars[botGeneration] == 0; 
+			if((isMotherbot && glob.enableFirstLifetime && age >= glob.firstMaxLifetime)
+				|| (!isMotherbot && glob.enableLifetime && age >= glob.maxLifetime))
 			{
-			  if(errHandler != 0) errHandler->handleBotError(current, failAge);
-			  deleteBotFromList(bots, n2);
+				if(errHandler != 0) errHandler->handleBotError(current, failAge);
+				deleteBotFromList(bots, n2);
 			}
 			else
-			  n2 = n2->getNext();
+				n2 = n2->getNext();
 		}
 	}
 }
@@ -281,12 +286,12 @@ Program::Program(ProgramLoader* loader) : sim(0), /*vars(progVarLength),*/
 	headers(false), programNum(-1), globalNum(-1), emptyBank(0), loader(loader), banks(0)
 {
 	loader->owner = this;
-	headers["Name"] = HeaderField("name", "Unnamed Bot", headerPublished);
-	headers["Author"] = HeaderField("author", "Unknown Author", headerPublished);
-	headers["Country"] = HeaderField("country", "Unknown Country", headerPublished);
+	headers["Name"] = HeaderField("name", _("Unnamed Bot"), headerPublished);
+	headers["Author"] = HeaderField("author", _("Unknown Author"), headerPublished);
+	headers["Country"] = HeaderField("country", _("Unknown Country"), headerPublished);
 	StringMap<HeaderField>* hp = loader->getHeaders();
 	if(hp != 0) headers.putAll(*hp);
-	emptyBank = new Bank(this, "Empty Bank");
+	emptyBank = new Bank(this, _("Empty Bank"));
 }
 
 void Program::init(rint num, Simulation* sim)
@@ -364,6 +369,31 @@ ExecReturnType Bot::exec()
 		ExecReturnType ret = tasks[curTask]->exec();
 		if(ret <= execOK)
 		{
+			// TEST: color change support
+			if(owner->sim->glob.colorChange) {
+				// check if a color change is required
+				if(tasks.length()) {
+					int curBank = tasks[0]->vars[taskCurBank]; 
+					if(curBank >= 0 && curBank < banks.length()) {
+						Bank* bank = banks[curBank]; 
+
+						// is the first running bank not from our program? 
+						if(bank && bank->owner != owner) {
+							// if so, change the color
+							// remove bot from old program
+							owner->vars[progMybots]--; 
+							owner->vars[progOtherbots]++; 
+							// assign to new program
+							owner = bank->owner; 
+							owner->vars[progMybots]++; 
+							owner->vars[progOtherbots]--; 
+
+						}
+					}
+				}
+			}
+			// END TEST: color change support
+			
 			if((ret == failQuit) || // quit when several tasks present
 				((ret == failData) && (tasks.length() > 1))) 
 			{ // special handling of data hunger in multitasking: just current task dies
@@ -373,10 +403,25 @@ ExecReturnType Bot::exec()
 			return ret;
 		}
 	}
+
 	// all tasks sleep
 	return execOK;
 }
 
+bool Bot::checkInstrDur()
+{
+	long sum = 0;
+	// sum up the durations of all running instructions
+	for(int t = 0; t < tasks.length(); t++) {
+		// only non-sleep instructions (with numExec timing) count!
+		if(tasks[t]->vars[taskTimingMode] == timingNumExec)
+			sum += tasks[t]->vars[taskNumCycles]; 
+	}
+
+	return sum <= owner->sim->glob.maxInstrDur; 
+}
+
+
 ////////////// Task //////////
 Task::Task(Bot* bot, Task* creator, rint dir) : 
 	bot(bot), sim(bot->owner->sim), /*vars(taskVarLength),*/ curInstr(0), seized(false)
@@ -455,13 +500,16 @@ ExecReturnType Task::exec()
           if(cycles < 0) // Bot killed in getNumCycles?
             return ExecReturnType(cycles);
 
-		  if(cycles > sim->glob.maxInstrDur) // Instruction takes too long
-			return failInstrDur;
+		  // detect FAT situation
+		  bool FATdetect = (vars[taskNumCycles] < cycles); 
+		  // now assign taskNumCycles and check... 
+		  vars[taskNumCycles] = cycles; 
+		  if(!bot->checkInstrDur()) // all instructions together take too long
+			  return failInstrDur;
 
           // instruction takes longer now then when it was begun (FAT!)
-		  if((!sim->glob.enableFAT) && (vars[taskNumCycles] < cycles))
+		  if((!sim->glob.enableFAT) && FATdetect)
           {
-              vars[taskNumCycles] = cycles;
 			  // wait longer
 			  return ExecReturnType(vars[taskTimingMode]);
           }
@@ -521,8 +569,10 @@ ExecReturnType Task::exec()
       if( ret2 < 0 ) // bot killed in getNumCycles?
         return ExecReturnType(ret2);
 
-	  if( ret2 > sim->glob.maxInstrDur ) // Instruction takes too long
-		return failInstrDur;
+	  // check instruction durations. 
+	  vars[taskNumCycles] = ret2; 
+	  if(!bot->checkInstrDur())
+		  return failInstrDur; // all instructions together take too long
 
       vars[taskNumCycles] = ret2;
       vars[taskCyclesDone] = 0;
@@ -590,7 +640,7 @@ String Bank::print()
 	String ret;
 	if(isSecret)
 	{
-		ret += "Secret Bank\n";
+		ret += _("Secret Bank\n");
 	}
 	else {
 		ret += name;
@@ -650,6 +700,13 @@ rint Instr::getValue(Task* task, int opNum, bool absolute)
 		}
 		case opTypeProgram:    return task->bot->owner->vars[op.ptr]; 
 		case opTypeGlobal:     return task->sim->vars[op.ptr];
+		case opTypeLifetime:
+		{
+			if(!task->bot->vars[botGeneration]) // this is a motherbot
+				return task->sim->vars[simMaxFirstLifetime]; 
+			else // this is a childbot
+				return task->sim->vars[simMaxLifetime]; 
+		}
 		case opTypeFields:
 		{
 			rint dir = task->vars[taskDir];
@@ -742,7 +799,7 @@ void Instr::setValue(Task* task, int opNum, rint value)
 		  break;					
 		default:
 		  task->sim->errHandler->handleSystemError(-17, 
-			  String("Attempt to set var of unsupported type ") + op.type);
+			  String(_("Attempt to set var of unsupported type ")) + op.type);
 		  break;
     }
 }
@@ -789,6 +846,7 @@ String Instr::printOp(int opNum, int instrPos)
 		case opTypeGlobal:     return simVarNames[op.ptr];
 		case opTypeFields:     return "$Fields";
 		case opTypeAge:        return (op.isRemote ? "%Age" : "$Age");
+		case opTypeLifetime:   return "$MaxLifetime"; 
 		case opTypeLabel:	   return String(op.ptr - instrPos - 1);
 		case opTypeAbsLabel:   return String(op.ptr);
 		case opTypeRandom:     return "$RandNum";
@@ -864,7 +922,7 @@ StringMap<Program::HeaderField>* ProgramLoader::getHeaders()
 			if(!isLanguageVersionSupported(headers->get("language").value))
 			{
 				ret.success = false;
-				ret.message = genLoadFailMsg[genFailLanguageVersion];
+				ret.message = getGenLoadFailMsg(genFailLanguageVersion);
 			}
 		}
 
@@ -915,7 +973,7 @@ bool ProgramLoader::isLanguageVersionSupported(const String& language)
 	int lv = lang.intValue(-1);
 	if(lv < 0) // incorrect format
 		return false;
-	if(lv > languageVersion) // too high
+	if(lv > getLanguageVersion()) // too high
 		return false;
 	return true;
 }
