@@ -1,7 +1,7 @@
 /*
  * robbase.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -28,8 +28,6 @@
 #include "robvars.h"
 #include "robglob.h"
 
-//using namespace lrt;
-
 namespace rt {
 
 // forward declares
@@ -160,6 +158,12 @@ public:
 	~Bot();
 
 	ExecReturnType exec();
+
+	/// checks if the sum of the durations of all non-SLEEP instructions
+	/// in the bot's tasks is less or equal then MaxInstrDur. 
+	/// If yes, then everything is OK (true is returned),
+	/// If no (false is returned), the bot should be destroyed. 
+	bool checkInstrDur(); 
 };
 
 /** One task in a robot. Each robot always has at least one task running, but
@@ -243,7 +247,7 @@ public:
 
 	/** Return the instruction name here. */
 	virtual lrt::String getName() = 0;
-	/** Returns a String representation of this instruction. 
+	/** Returns a lrt::String representation of this instruction. 
 	  * @param instrPos Position (in its bank) of the instruction.
 	  */
 	virtual lrt::String print(int instrPos = 0);
