@@ -1,7 +1,7 @@
 /*
  * robconsole.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -25,13 +25,38 @@
 #include "robbase.h"
 #include "robvars.h"
 #include "robstrings.h"
+#include "robtrans.h"
 
 #include <rtsystem.h>
 #include <rtstring.h>
 #include <rtfile.h>
 
+using namespace lrt; 
+
 namespace rt {
 
+Array<int> getColWidths(const lrt::String& header, int numCols)
+{
+	Array<int> ret(numCols); 
+	int i = 0, pos = header.indexOf('+'), oldPos = 0; 
+	while(i < numCols && pos < header.length()) {
+		oldPos = pos; 
+		pos = header.indexOf('+', pos + 1);
+		if(pos < 0) 
+			pos = header.length();
+		ret[i] = pos - oldPos; 
+		i++; 
+	}
+
+	// default assignment if plusses are missing
+	for(; i < numCols; i++)
+		ret[i] = 5; 
+
+	return ret; 
+}
+
+
+
 ////////////// ConsoleFrontend
 
 
@@ -43,10 +68,10 @@ ConsoleFrontend::~ConsoleFrontend()
 void ConsoleFrontend::handleLoadError(const String& affectedFile, const String& message) const
 {
 	if(verbose >= 0) {
-		System::println(String("load error: ") + affectedFile + ": " + message);
+		System::println(String(_("load error: ")) + affectedFile + ": " + message);
 #ifndef __UNIX__
 		if(System::isInteractive())
-			System::message(String("load error: ") + affectedFile + ": " + message);
+			System::message(String(_("load error: ")) + affectedFile + ": " + message);
 #endif
 	}
 }
@@ -54,36 +79,36 @@ void ConsoleFrontend::handleLoadError(const String& affectedFile, const String&
 void ConsoleFrontend::handleBotError(const Bot* affectedBot, ExecReturnType type) const
 {
 	if((verbose >= 7) && (type != failDie)) {
-		System::println(String("robot killed: ") +
+		System::println(String(_("robot killed: ")) +
 			affectedBot->vars[botPosX] + "/" + affectedBot->vars[botPosY] + ": " +
-			failMsg[-type]);
+			getFailMsg(type));
 	}
 }
 
 void ConsoleFrontend::handleSystemError(int num, const String& message) const
 {
 #ifdef __SYMBIAN32__
-	System::println("fatal error: " + message);
-	System::println("     [press any key to exit]");
+	System::println(_("fatal error: ") + message);
+	System::println(_("     [press any key to exit]"));
 	System::read();
 	System::exit();
 #else
-	System::exit(num, "fatal error: " + message);
+	System::exit(num, _("fatal error: ") + message);
 #endif
 }
 
 void ConsoleFrontend::handleWarning(const String& message) const
 {
 	if(verbose >= 0) {
-		System::println("warning: " + message);
+		System::println(_("warning: ") + message);
 	}
 }
 
 
 void ConsoleFrontend::printVersion()
 {
-	System::println(String("Version ") + userVersion); 
-	System::println(aboutText); 
+	System::println(String(_("Version ")) + getUserVersion()); 
+	System::println(getAboutText()); 
 	System::println(); 
 }
 
@@ -91,31 +116,31 @@ void ConsoleFrontend::printHelp()
 {
 	printVersion(); 
 
-	System::println("Usage: robotour [options] prog1 [prog2 [...]]");
+	System::println(_("Usage: robotour [options] prog1 [prog2 [...]]"));
 	System::println();
-	System::println("Options:");
-	System::println("  -h, -help  Print this help text."); 
+	System::println(_("Options:"));
+	System::println(_("  -h, -help  Print this help text.")); 
 #ifdef __NETWORK__
-	System::println("  -tele      Switch to work group mode (internet simulation)");
+	System::println(_("  -tele      Switch to work group mode (internet simulation)"));
 #endif
 #ifdef __SYMBIAN32__
-	System::println("  -cd F      Set current folder to F before running robotour.");
+	System::println(_("  -cd F      Set current folder to F before running robotour."));
 #endif
-	System::println("  -n         Number of simulations to do (standard: 10)");
-	System::println("  -s         Switch to \"single\" mode: First against all");
-	System::println("  -c         Switch to \"charts\" mode: everyone against everyone (default)");
-	System::println("  -t n       Switch to \"top <n>\" mode: like RobServ");
-	System::println("  -T n       Same as -t, but old results are recognized");
-	System::println("     -cf F   The competition folder (bots & result files) (default: current)");
-	System::println("  -i         Simulate all bots in one field");
-	System::println("  -o optfile Specify location of the options file (default: ./robocom.rco)");
-	System::println("  -p x       print the field every x cycles (default: 0 = function inactive)");
-	System::println("  -debug p x Debug every x cycles (default: 0 = function inactive) the bots");
-	System::println("             on field range p (coords start at 0; example for p: 0,0:1,1)");
-	System::println("  -batch     Non-interactive mode: Never ever pop up any message boxes");
-	System::println("  -r         No randomize => always the same result");
-	System::println("  -v n       Set verbose level (0-5) (default = 5; no output = 0)");
-	System::println("  progn      Any robot (.rob or .rbi) file, or file pattern (e.g. *.rob).");
+	System::println(_("  -n         Number of simulations to do (standard: 10)"));
+	System::println(_("  -s         Switch to \"single\" mode: First against all"));
+	System::println(_("  -c         Switch to \"charts\" mode: everyone against everyone (default)"));
+	System::println(_("  -t n       Switch to \"top <n>\" mode: like RobServ"));
+	System::println(_("  -T n       Same as -t, but old results are recognized"));
+	System::println(_("     -cf F   The competition folder (bots & result files) (default: current)"));
+	System::println(_("  -i         Simulate all bots in one field"));
+	System::println(_("  -o optfile Specify location of the options file (default: ./robocom.rco)"));
+	System::println(_("  -p x       print the field every x cycles (default: 0 = function inactive)"));
+	System::println(_("  -debug p x Debug every x cycles (default: 0 = function inactive) the bots\n"
+					  "             on field range p (coords start at 0; example for p: 0,0:1,1)"));
+	System::println(_("  -batch     Non-interactive mode: Never ever pop up any message boxes"));
+	System::println(_("  -r         No randomize => always the same result"));
+	System::println(_("  -v n       Set verbose level (0-5) (default = 5; no output = 0)"));
+	System::println(_("  progn      Any robot (.rob or .rbi) file, or file pattern (e.g. *.rob)."));
 
 	// print plugin help
 	for(Iterator<FrontendPlugin*> iter = plugins.begin(); iter.hasElement(); ++iter)
@@ -151,7 +176,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				numRepeats = params[i].intValue(10);
 			}
 
@@ -160,7 +185,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				printtime = params[i].intValue(0);
 			}
 
@@ -169,7 +194,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i+=2; // look at next args
 				if(used[i-1] || used[i])
-					handleSystemError(1, "Parameter(s) missing for argument -" + arg);
+					handleSystemError(1, _("Parameter(s) missing for argument -") + arg);
 				debugrange = params[i-1];
 				debugtime = params[i].intValue(0);
 			}
@@ -193,7 +218,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				fightTypeParam = params[i].intValue(20);
 			}
 
@@ -202,7 +227,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				competitionFolder = params[i];
 				// check that a path was given
 				char c = competitionFolder[competitionFolder.length() - 1];
@@ -222,7 +247,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				verbose = params[i].intValue(5);
 			}
 
@@ -231,7 +256,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				optionFile = params[i];
 			}
 
@@ -272,7 +297,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			{
 				i++; // look at next arg
 				if(used[i])
-					handleSystemError(1, "Parameter missing for argument -" + arg);
+					handleSystemError(1, _("Parameter missing for argument -") + arg);
 				String newCurrentFolder = params[i];
 				// check that a path was given
 				char c = newCurrentFolder[newCurrentFolder.length() - 1];
@@ -290,7 +315,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 
 			else
 			{
-				System::println("Warning: unknown parameter " + params[i]);
+				System::println(_("Warning: unknown parameter ") + params[i]);
 			}
 		}
 		else // file or file pattern
@@ -302,7 +327,7 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 				if(File(fullParam).exists())
 				  files += fullParam;
 				else
-				  System::println("warning: file not found: " + fullParam);
+				  System::println(_("warning: file not found: ") + fullParam);
 			}
 			else { // yes, so add all files matching the pattern
 				Array<File> f(StarFilenameFilter::getFiles(fullParam));
@@ -366,18 +391,23 @@ void ConsoleFrontend::MyTourDisplayer::exit(TourStatusType exitType, const Array
 	myResults.sort(TourResult::compareByPoints);
 
 	Time duration = Time::getCurrentTime() - starttime;
-	System::println(String("Simulation took ") + duration.sec + "." + 
-		String(duration.msec + 1000).substring(1) + " seconds.");
+	System::println(String::format(_("Simulation took %.3f seconds."), duration.sec + duration.msec / 1000.0));
 	System::println();
-	System::println("Tournament results:");
-	System::println("Robot name                     Wins Looses Ties Points");
-	System::println("------------------------------------------------------");
+	System::println(_("Tournament results:"));
+	// NOTE FOR TRANSLATORS: The plus characters in the second line below are 
+	// used to mark the table columns. They will not be shown on the screen. 
+	System::println(_("Robot name                     Wins Losses Ties Points"));
+	String header = _("+------------------------------+----+------+----+-----");
+	Array<int> cols = getColWidths(header, 5); 
+	header = header.replace('+', '-'); 
+	System::println(header); 
+
 	for(int i = 0; i < myResults.length(); i++)
-		System::println(resizeString(myResults[i].headers["name"].value, 30) + " " +
-			String(myResults[i].wins, 10, 4) + " " +
-			String(myResults[i].looses, 10, 6) + " " +
-			String(myResults[i].ties, 10, 4) + " " +
-			String(int(myResults[i].points), 10, 6));
+		System::println(resizeString(myResults[i].headers["name"].value, cols[0]-1) + " " +
+			String(myResults[i].wins, 10, cols[1]-1) + " " +
+			String(myResults[i].looses, 10, cols[2]-1) + " " +
+			String(myResults[i].ties, 10, cols[3]-1) + " " +
+			String(int(myResults[i].points), 10, cols[4]-1));
 }
 
 ////////////////// ConsoleBotPresenter //////////////////////
@@ -408,15 +438,14 @@ void ConsoleBotPresenter::initTour(const TourInitInfo& info)
 void ConsoleBotPresenter::initSim(Simulation* const sim)
 {
 	simNum++;
-	System::println(String("Starting simulation ") + simNum + " of " + simCount + "...");
+	System::println(String::format(_("Starting simulation %d of %d..."), (int) simNum, (int) simCount));
 	for(Iterator<Bot*> iter = sim->bots.begin(); iter.hasElement(); ++iter)
 	{
 		Bot* bot = iter.get();
 		Program* prog = bot->owner;
-		System::println(prog->headers["name"].value + " (" + prog->globalNum + ") has got " +
-			bot->banks.length() + " banks; starts on position: " + 
-			bot->vars[botPosX] + "/" + bot->vars[botPosY] + ";" + 
-			bot->tasks[0]->vars[taskDir]);
+		System::println(String::format(_("%s (%d) has got %d banks, starts at position: %d/%d;%d"), 
+			prog->headers["name"].value.cStr(), (int) prog->globalNum,
+			(int) bot->banks.length(), (int) bot->vars[botPosX], (int) bot->vars[botPosY], (int) bot->tasks[0]->vars[taskDir]));
 	}
 }
 
@@ -433,14 +462,15 @@ void ConsoleBotPresenter::exitSim(Simulation* const sim, const GameState& simRes
 {
 	switch(simResult.event) {
 		case gameAbort:
-			System::println("The match was aborted and is considered as a tie.");
+			System::println(_("The match was aborted and is considered as a tie."));
 			break;
 		case gameTie:
-			System::println("The bots tied.");
+			System::println(_("The bots tied."));
 			break;
 		case gameFinished:
-			System::println(sim->getProgram(simResult.affectedProgram)->headers["name"].value +
-				" won after " + sim->curCycle + " cycles!");
+			System::println(String::format(_("%s won after %d cycles!"), 
+				sim->getProgram(simResult.affectedProgram)->headers["name"].value.cStr(), 
+				(int) sim->curCycle));
 			break;
 		default:
 			break;
@@ -478,7 +508,7 @@ SimSupervisor::GameState FieldPrinter::exec(Simulation* const sim)
 {
 	System::setPos(0,0);
 	
-	System::print("Cycle " + String(sim->curCycle, 10, 5) + ": ");
+	System::print(String::format(_("Cycle %5d: "), sim->curCycle));
 	for(int p = 0; p < sim->getNumPrograms(); p++)
 		System::print(String(sim->getProgram(p)->vars[progMybots], 10, 5));
 	System::println();
@@ -531,11 +561,11 @@ SimSupervisor::GameState FieldPrinter::exec(Simulation* const sim)
 DebugPrinter::DebugPrinter(int debugtime, String debugrange) : debugtime(debugtime)
 {
 	Array<String> parts = debugrange.split(":","");
-	if(parts.length() != 2) System::exit(51, "error: -debug: Format for p is startx,starty:endx,endy");
+	if(parts.length() != 2) System::exit(51, _("error: -debug: Format for p is startx,starty:endx,endy"));
 	Array<String> start = parts[0].split(",","");
 	Array<String> end = parts[1].split(",","");
 	if((start.length() != 2) || (end.length() != 2))
-		System::exit(51, "error: -debug: Format for p is startx,starty:endx,endy");
+		System::exit(51, _("error: -debug: Format for p is startx,starty:endx,endy"));
 	sx = start[0].intValue(0);
 	sy = start[1].intValue(0);
 	ex = end[0].intValue(0);
@@ -570,7 +600,7 @@ SimSupervisor::GameState DebugPrinter::exec(Simulation* const sim)
 {
 	System::setPos(0, sim->getNumPrograms());
 
-	System::println(String("Cycle ") + sim->curCycle + ":      ");
+	System::println(String::format(_("Cycle %d:      "), (int) sim->curCycle));
 	int i = -1;
 	for(int y = sy; y <= ey; y++) {
 		for(int x = sx; x <= ex; x++)
