@@ -1,7 +1,7 @@
 /*
  * robconsole.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -34,6 +34,11 @@ class ConsoleBotPresenter;
 class FieldPrinter;
 class DebugPrinter;
 
+/// Given a string of the format "+----+---------+------", 
+/// takes the difference of the positions of adjacent plus characters and 
+/// stuffs them into the returned array. 
+/// @param minCols How many columns do you want to have? 
+lrt::Array<int> getColWidths(const lrt::String& header, int numCols);
 
 class ConsoleFrontend : public Frontend {
 
@@ -42,12 +47,12 @@ public:
 	virtual ~ConsoleFrontend();
 
 	// from ErrorHandler
-	virtual void handleLoadError(const String& affectedFile, const String& message) const;
+	virtual void handleLoadError(const lrt::String& affectedFile, const lrt::String& message) const;
 	virtual void handleBotError(const Bot* affectedBot, ExecReturnType type) const;
-	virtual void handleSystemError(int num, const String& message) const;
-	virtual void handleWarning(const String& message) const;
+	virtual void handleSystemError(int num, const lrt::String& message) const;
+	virtual void handleWarning(const lrt::String& message) const;
 
-	virtual bool interpreteParamsImpl(const Array<String>& params, Array<bool>& used);
+	virtual bool interpreteParamsImpl(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used);
 	virtual void fillOptions(SimOptions& options);
 
 protected:
@@ -55,17 +60,17 @@ protected:
 	public:
 		MyTourDisplayer(ConsoleBotPresenter* cbp = 0);
 		virtual void init(const TourInitInfo&);
-		virtual TourStatusType update(const Array<TourResult>& status);
-		virtual void exit(TourStatusType exitType, const Array<TourResult>& result);
+		virtual TourStatusType update(const lrt::Array<TourResult>& status);
+		virtual void exit(TourStatusType exitType, const lrt::Array<TourResult>& result);
 
 	private:
-		Time starttime;
+		lrt::Time starttime;
 		ConsoleBotPresenter* cbp;
 	};
 	int verbose;
 	int printtime;
 	int debugtime;
-	String debugrange;
+	lrt::String debugrange;
 
 	void printHelp();
 	void printVersion(); 
@@ -104,14 +109,14 @@ public:
 private:
 	int printtime;
 	GameState retState;
-	String boundary;
+	lrt::String boundary;
 };
 
 
 class DebugPrinter : public SimSupervisor {
 
 public:
-	DebugPrinter(int debugtime, String debugrange);
+	DebugPrinter(int debugtime, lrt::String debugrange);
 	virtual ~DebugPrinter();
 
 	virtual SimSuperPosition getPreferredPosition();
