@@ -1,7 +1,7 @@
 /*
  * robdefines.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -340,13 +340,44 @@ bool DefineInputStream::skipRestOfLine()
 {
 	int c;
 	while(true) {
+		bool baseStream = (curStream == 0); 
 		c = read();
-		if(c < 0) break;
+		if(c < 0 && baseStream) break; // if a mini stream ends, we don't return
 		if(c == '\n') break;
 	}
 	return (c >= 0);
 }
 
+bool DefineInputStream::expectEndOfLine()
+{
+	int c; 
+	bool inComment = false;
+
+	while(true) {
+		bool baseStream = (curStream == 0); 
+		c = read(); 
+		// EOF (return FALSE immediately)
+		if(c < 0) {
+			if(baseStream) // EOF in base stream => real EOF => break
+				break; 
+			else // if a mini stream ends, just ignore this
+				continue; 
+		}
+		// \n (return OK) 
+		if(c == '\n') break; 
+		// start a comment? 
+		if(ignoreComments && c == commentStart) inComment = true;
+		// inside comments, everything is OK
+		if(inComment) continue; 
+		// is it a separator? 
+		if(separators.indexOf(c) >= 0) continue; 
+		
+		// not a separator, return WRONG
+		c = -1; break; 
+	}
+	return (c >= 0); 
+}
+
 bool DefineInputStream::eos()
 {
 	if(curStream > 0) return false;
