@@ -1,7 +1,7 @@
 /*
  * robdefines.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -28,15 +28,13 @@
 #include <rtstreams.h>
 #include <rtmap.h>
 
-using namespace lrt;
-
 namespace rt {
 
 /// An input stream which automatically replaces Defines while reading
-class DefineInputStream : public InputStream  {
+class DefineInputStream : public lrt::InputStream  {
 public:
-	static const String whitespace;
-	DefineInputStream(InputStream *in, const String &separators, const char commentStart = 0);
+	static const lrt::String whitespace;
+	DefineInputStream(lrt::InputStream *in, const lrt::String &separators, const char commentStart = 0);
 	virtual void close();
 	virtual ~DefineInputStream();
 
@@ -50,28 +48,35 @@ public:
 	virtual bool fail();
 
 	virtual int read();
-	RobLoadReturnType getWord(String& word, const String& specialSeps = "");
-	String getLine(bool skipEmpty = true);
+	RobLoadReturnType getWord(lrt::String& word, const lrt::String& specialSeps = "");
+	lrt::String getLine(bool skipEmpty = true);
 
 	int getLineNumber();
+	// Skips until the end of the line. 
+	// Returns false if end of file, true normally. 
 	bool skipRestOfLine();
+	// Expects the end of the line. 
+	// Separators or comments (if enabled) before the end of line are allowed. 
+	// If any other non-separator character is encountered before the end of line, returns false. 
+	// Otherwise returns true. 
+	bool expectEndOfLine();
 
 	bool eos();
 
 	/** checks the identifier (eg label name, define param) for validity.
       * The function assumes that the first magic char (eg '?') was removed from the identifier. */
-	bool isIdentifierValid(const String& str);
+	bool isIdentifierValid(const lrt::String& str);
 
 private:
 	class Define {
 	public:
-		Define(const String& name = "");
+		Define(const lrt::String& name = "");
 		~Define() {}
 
-		InputStream* getStream();
+		lrt::InputStream* getStream();
 
-		String name, value;
-		Vector<String> params;
+		lrt::String name, value;
+		lrt::Vector<lrt::String> params;
 		int lineOffset;
 	};
 
@@ -85,27 +90,27 @@ private:
 		int lineOffset;
 		int buf;
 		bool eol;
-		StringMap<String> params;
+		lrt::StringMap<lrt::String> params;
 	};
 
-	class StringInStream : public InputStream {
+	class StringInStream : public lrt::InputStream {
 	public:
-		StringInStream(const String&);
+		StringInStream(const lrt::String&);
 		virtual ~StringInStream() {}
 		virtual int read();
 		bool eos();
 	private:
-		const String& str;
+		const lrt::String& str;
 		int pos;
 	};
 
 	void unread(int c);
-	RobLoadReturnType readParams(StringMap<String>& params, Vector<String>& paramNames);
+	RobLoadReturnType readParams(lrt::StringMap<lrt::String>& params, lrt::Vector<lrt::String>& paramNames);
 	RobLoadReturnType createDefine();
 	
-	Vector<StreamInfo> infos;
-	Vector<InputStream*> streams;
-	StringMap<Define> defineMap;
+	lrt::Vector<StreamInfo> infos;
+	lrt::Vector<lrt::InputStream*> streams;
+	lrt::StringMap<Define> defineMap;
 
 	enum {
 		identCharInvalid = 0x00,
@@ -118,7 +123,7 @@ private:
 	void initValidIdentifierChars();
 
 	int markLineNum;
-	String separators;
+	lrt::String separators;
 	char commentStart;
 	bool ignoreComments, autoTrim, defines;
 	int curStream;
