@@ -1,7 +1,7 @@
 /*
  * robfrontend.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -22,6 +22,7 @@
 #include "robtopmgr.h"
 #include "robvars.h"
 #include "robstrings.h"
+#include "robtrans.h"
 
 // plugins
 #ifndef __NO_SIF__
@@ -61,7 +62,7 @@ FrontendPlugin* Frontend::findPlugin(const String& name)
 {
 	FrontendPlugin* ret = 0;
 	for(List<FrontendPlugin*>::Node* n = plugins.first(); n; n = n->getNext())
-		if(n->accessElement()->getName() == name)
+		if(n->accessElement()->getCodeName() == name)
 			ret = n->accessElement();
 	return ret;
 }
@@ -72,6 +73,18 @@ Frontend::~Frontend()
 	delete manager;
 }
 
+void Frontend::reset()
+{
+	// reset all of the plugins
+	for(Iterator<FrontendPlugin*> iter = plugins.begin(); iter.hasElement(); ++iter)
+	{
+		iter.get()->reset(); 
+	}
+
+	// we don't have to do anything ourselves, 
+	// but derived classes may have to. 
+}
+
 bool Frontend::interpreteParams(const Array<String>& params)
 {
 	files.clear(); // needed when doing another tournament (doAllAgain)
@@ -112,11 +125,11 @@ void Frontend::fillOptions(SimOptions& options)
 {
 	options.numRepeats = numRepeats;
 	if(!options.glob.getGlobals(optionFile))
-		handleSystemError(18, "Could not read option file " + optionFile);
+		handleSystemError(18, String::format(_("Could not read option file %s"), optionFile.cStr()));
 	if(noRandom) Math::seed(1);
 
 	if(files.length() < 1) {
-		handleSystemError(17, "No robots specified.");
+		handleSystemError(17, _("No robots specified."));
 		return;
 	}
 	options.files = files;
@@ -156,7 +169,7 @@ SimManager* Frontend::getManager()
 			manager = new AllInOneManager();
 			break;
 		default:
-			System::exit(49, "Unknown fight type!");
+			System::exit(49, _("Unknown fight type!"));
 	}
 	return manager;
 }
