@@ -1,7 +1,7 @@
 /*
  * robfrontend.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -24,8 +24,6 @@
 #include <rtlist.h>
 #include <rtstring.h>
 
-using namespace lrt;
-
 #include "robmanage.h"
 #include "robvars.h"
 #include "robbase.h"
@@ -54,17 +52,26 @@ public:
 	/** Return when your plugin should be called to interprete the params. 
 	  * @see FpInterpretePos */
 	virtual FpInterpretePos getInterpretePos() = 0;
-	/** Return a short, but specific name for your plugin. */
-	virtual String getName() = 0;
-	/** Return a String describing your plugin's parameters, or an empty string 
+	/** Return an internal, short, but specific name for your plugin. This one will be used for identifying the plugin
+	  * and should not be translated. */
+	virtual lrt::String getCodeName() = 0;
+	/** Return a short, but specific name for your plugin. This one will be shown to the users
+	  * and should be translated. */
+	virtual lrt::String getName() = 0;
+	/** Return a lrt::String describing your plugin's parameters, or an empty string 
 	  * if you don't have any. */
-	virtual String getHelpText() = 0;
+	virtual lrt::String getHelpText() = 0;
+	/** This will be called when the Frontend is reset, 
+	  * i.e. a new tournament is being set up and thus, all old
+	  * settings, simulation supervisors and tournament displayers have become invalid. 
+	  */
+	virtual void reset() {}
 	/** Return true if you want to continue creating a sim, using these params,
 	  * or false if they're somehow invalid. 
 	  * For each parameter which is unique to your plugin and which doesn't have to
 	  * be interpreted by the main Frontend, set <tt>used[i]</tt> to <tt>true</tt>.
 	  * @param used Note: Size is one larger than params. (to make your life easier) */
-	virtual bool interpreteParams(const Array<String>& params, Array<bool>& used) = 0;
+	virtual bool interpreteParams(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used) = 0;
 	/** In this method, you can add your own SimSupervisors and TourDisplayer to 
 	  * the tournament. */
 	virtual void fillOptions(SimOptions& options) = 0;
@@ -72,7 +79,7 @@ public:
 	  * This method is intended for using your plugin without parameters. If the
 	  * plugin determines from parameters that it is active, you need to setup 
 	  * <tt>active</tt> yourself. */
-	void setActive(bool a) { active = a; }
+	virtual void setActive(bool a) { active = a; }
 	bool isActive() { return active; }
 	virtual ~FrontendPlugin() {}
 
@@ -92,15 +99,15 @@ class Frontend : public ErrorHandler{
 public:
 	/// do another tournament? normally false
 	bool doAllAgain;
-	/// returns a pointer to the plugin with given 'name', if there is one
+	/// returns a pointer to the plugin with given internal codename, if there is one
 	/// otherwise returns NULL
-	virtual FrontendPlugin* findPlugin(const String& name);
+	virtual FrontendPlugin* findPlugin(const lrt::String& codeName);
 	virtual ~Frontend();
 
 	/// reset the Frontend for a new tournament
-	virtual void reset() {}
+	virtual void reset(); 
 	/** Calls interpreteParams() of the plugins, then the impl() method. */
-	bool interpreteParams(const Array<String>& params);
+	bool interpreteParams(const lrt::Array<lrt::String>& params);
 	/** Derived classes should call Frontend::fillOptions() in their xxxFrontend::fillOptions()
 	  * somewhere to process the standard things (noRandom, numRepeats, optionFile). */
 	virtual void fillOptions(SimOptions& options);
@@ -123,23 +130,23 @@ public:
 	int fightTypeParam;
 	/** The competition folder (not only for top mode!)
 	  * This does apply to robot files (on the command line) and to results files. */
-	String competitionFolder;
+	lrt::String competitionFolder;
 
 	/// Create reproducable results (as far as possible) 
 	bool noRandom;
 	/// Repeat amount for each simulation
 	int numRepeats;
 	/// The option ("RCO") file (or resource) containing all global settings
-	String optionFile;
+	lrt::String optionFile;
 	/// The robot files
-	Vector<String> files;
+	lrt::Vector<lrt::String> files;
 
 protected:
 
 	/// adds a plugin of every type to the plugin list
 	virtual void initPlugins();
 	/// Contains one of all available frontend plugins.
-	List<FrontendPlugin*> plugins;
+	lrt::List<FrontendPlugin*> plugins;
 
 	SimManager* manager;
 	/// inits the plugins
@@ -147,7 +154,7 @@ protected:
 	/** Return true if you want to continue creating a sim, using these params,
 	  * or false if they're somehow invalid. 
 	  * @param used Note: Size is one larger than params. (to make your life easier) */
-	virtual bool interpreteParamsImpl(const Array<String>& params, Array<bool>& used) = 0;
+	virtual bool interpreteParamsImpl(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used) = 0;
 
 };
 
