@@ -1,7 +1,7 @@
 /*
  * robglob.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -19,6 +19,7 @@
 
 #include "robbase.h"
 #include "robpackage.h"
+#include "robtrans.h"
 
 using namespace lrt;
 
@@ -50,7 +51,9 @@ bool Globals::getGlobals(const String& filex)
 	enableMultitasking  = getRint( sRoboCom, "EnableMultitasking",	0,		0,		1);
 	enableFAT           = getRint( sRoboCom, "FAT",					0,		0,		1);
 	enableLifetime		= getRint( sRoboCom, "EnableLifetime",		0,		0,		1);
+	enableFirstLifetime	= getRint( sRoboCom, "EnableFirstLifetime",	0,		0,		1);
 	enableNutcracker    = getRint( sRoboCom, "NutCracker",          1,      0,      1);
+	colorChange         = getRint( sRoboCom, "ColorChange",         0,      0,      1); 
 	minId				= getRint( sRoboCom, "MinID",				5000);
 	maxId				= getRint( sRoboCom, "MaxID",				25000,	minId);
 
@@ -60,6 +63,7 @@ bool Globals::getGlobals(const String& filex)
 	maxTasks			= getRint( sRoboCom, "MaxTasks",			1,		1);
 	maxMybots           = getRint( sRoboCom, "MaxMyBots",			32000,	1);
 	maxLifetime			= getInt( sRoboCom, "MaxLifetime",			32000000,1);
+	firstMaxLifetime	= getInt( sRoboCom, "FirstLifetime",		32000000,1);
 
 	IniSection& sTiming  = ini.getSection("Timing");
 	durDie             = getRint( sTiming, "durDie",				1,		0 );
@@ -113,12 +117,14 @@ rint Globals::getRint( IniSection& sec, const char* name, rint def, rint min, ri
 	int val = v.intValue(def);
 
 	if((val == def) && (def < 0))
-		errHandler->handleSystemError(11, String("Could not find option ") + name);
+		errHandler->handleSystemError(11, String::format(_("Could not find option %s"), name));
 
 	if(val < min)
-		errHandler->handleSystemError(19, String("Invalid RCO option ") + name + ": " + val + " < " + min);
+		errHandler->handleSystemError(19, String::format(_("Invalid RCO option %s: %d is less than the minimum value %d"), 
+			name, (int) val, (int) min));
 	if(val > max)
-		errHandler->handleSystemError(19, String("Invalid RCO option ") + name + ": " + val + " > " + max);
+		errHandler->handleSystemError(19, String::format(_("Invalid RCO option %s: %d is more than the maximum value %d"),
+			name, (int) val, (int) max));
 
 	return (rint)val;
 }
@@ -130,12 +136,14 @@ int Globals::getInt( IniSection& sec, const char* name, int def, int min, int ma
 	int val = v.intValue(def);
 
 	if((val == def) && (def < 0))
-		errHandler->handleSystemError(11, String("Could not find option ") + name);
+		errHandler->handleSystemError(11, String::format(_("Could not find option %s"), name));
 
 	if(val < min)
-		errHandler->handleSystemError(19, String("Invalid RCO option ") + name + ": " + val + " < " + min);
+		errHandler->handleSystemError(19, String::format(_("Invalid RCO option %s: %d is less than the minimum value %d"), 
+			name, (int) val, (int) min));
 	if(val > max)
-		errHandler->handleSystemError(19, String("Invalid RCO option ") + name + ": " + val + " > " + max);
+		errHandler->handleSystemError(19, String::format(_("Invalid RCO option %s: %d is more than the maximum value %d"),
+			name, (int) val, (int) max));
 
 	return val;
 }
