@@ -1,7 +1,7 @@
 /*
  * robglob.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -24,8 +24,6 @@
 #include <rtmath.h>
 #include <rtini.h>
 
-//using namespace lrt;
-
 // You must not include anything else from RoboTour in this file.
 #include "robvars.h"
 
@@ -51,7 +49,9 @@ public:
 	rint enableMultitasking;
 	rint enableFAT;
 	rint enableLifetime;
+	rint enableFirstLifetime; 
 	rint enableNutcracker; 
+	rint colorChange; 
 	rint firstRobotMobile;
 	rint minId;
 	rint maxId;
@@ -62,6 +62,7 @@ public:
 	rint maxTasks;//
 	rint maxMybots;//
 	unsigned long maxLifetime;//
+	unsigned long firstMaxLifetime; 
 
 	rint durDie;
 	rint durMove;
