@@ -1,7 +1,7 @@
 /*
  * robhtml.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -18,6 +18,7 @@
 #include "robhtml.h"
 
 #include "robutils.h"
+#include "robtrans.h"
 
 #include <rtsystem.h>
 #include <rtini.h>
@@ -60,7 +61,7 @@ bool HtmlCreator::createChartsHtml(bool recalc, const String& iniName, const Str
 
 	if(!cssExists())
 		if(!writeCss())
-			System::println("warning: couldn't write css file");
+			System::println(_("warning: couldn't write CSS file"));
 
 	Vector<TopTourResult> store(0);
 
@@ -90,7 +91,7 @@ bool HtmlCreator::createChartsHtml(bool recalc, const String& iniName, const Str
 	}
 
 	if(store.length() == 0)
-		System::println("warning: empty charts or reading error?");
+		System::println(_("warning: empty charts or read error?"));
 
 	// create the HTML
 	NoBreakSection nbsProtectHtml; // create complete HTML always
@@ -99,38 +100,38 @@ bool HtmlCreator::createChartsHtml(bool recalc, const String& iniName, const Str
 	if(html->fail())
 	{ delete html; return false; }
 
-	html->write("<html>\n<head>\n <title>RoboTour Charts</title>\n");
+	html->write("<html>\n<head>\n <title>" + toHtml(_("RoboTour Charts")) + "</title>\n");
 	html->write(" <link rel=\"stylesheet\" href=\"" + cssName + "\">\n");
 	html->write("</head>\n\n");
 	html->write("<body class=\"bodybg\">\n");
-	html->write("<h1>RoboTour Charts</h1>\n");
+	html->write("<h1>" + toHtml(_("RoboTour Charts")) + "</h1>\n");
 	html->write("<h3>" + toHtml(competitionName) + "</h3>\n");
 	html->write("<table border=0 cellspacing=2 cellpadding=2 width=\"100%\">\n");
 	html->write("<tr class=\"title\">\n");
 
-	html->write("  <TD>\n" );
+	html->write("  <td>\n" );
 	html->write("    &nbsp;\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD>\n" );
-	html->write("   Name<BR>\n" );
-	html->write("   <SMALL>Last Updated</SMALL>\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD>\n" );
-	html->write("   Author,<BR>Country\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD align=center width=50>\n" );
-	html->write("   WINS\n" );
-	html->write("   </TD>\n" );
-	html->write("  <TD align=center width=50>\n" );
-	html->write("   LOSES\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD align=center width=50>\n" );
-	html->write("   TIES\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD align=center width=100>\n" );
-	html->write("   SCORE\n" );
-	html->write("  </TD>\n" );
-	html->write(" </TR>\n" );
+	html->write("  </td>\n" );
+	html->write("  <td>\n" );
+	html->write("   " + toHtml(_("Name")) + "<br>\n" );
+	html->write("   <small>" + toHtml(_("Last Updated")) + "</small>\n" );
+	html->write("  </td>\n" );
+	html->write("  <td>\n" );
+	html->write("   " + toHtml(_("Author")) + ",<br>" + toHtml(_("Country")) + "\n" );
+	html->write("  </td>\n" );
+	html->write("  <td align=center width=50>\n" );
+	html->write("   " + toHtml(_("Wins")) + "\n" );
+	html->write("   </td>\n" );
+	html->write("  <td align=center width=50>\n" );
+	html->write("   " + toHtml(_("Losses")) + "\n" );
+	html->write("  </td>\n" );
+	html->write("  <td align=center width=50>\n" );
+	html->write("   " + toHtml(_("Ties")) + "\n" );
+	html->write("  </td>\n" );
+	html->write("  <td align=center width=100>\n" );
+	html->write("   " + toHtml(_("Score")) + "\n" );
+	html->write("  </td>\n" );
+	html->write(" </tr>\n" );
 
 	for(int b = 0; b < store.length(); b++)
 	{
@@ -148,42 +149,43 @@ bool HtmlCreator::createChartsHtml(bool recalc, const String& iniName, const Str
 		String dethtml	   = getDetailedHtml(res.fileName).
 			getLocalName(outputFolder).replace(File::separatorChar, '/');
 
-		html->write(" <TR class=\"topcur\">\n" );
-		html->write("  <TD>\n" );
+		html->write(" <tr class=\"topcur\">\n" );
+		html->write("  <td>\n" );
 		html->write(String("    ") + (b+1) + ".\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD>\n" );
+		html->write("  </td>\n" );
+		html->write("  <td>\n" );
 		if(createLinks)
-		  html->write("   <A HREF=\"" + dethtml + "\">" + programname + "</A>\n");
+		  html->write("   <a href=\"" + dethtml + "\">" + programname + "</a>\n");
 		else
 		  html->write("   " + programname + "\n");
 
 		if(createDownloadLinks)
-		  html->write("   <BR><SMALL>" + date + "&nbsp;&nbsp;<A HREF=\"" + filename + "\">Download</A></SMALL>\n");
+		  html->write("   <br><small>" + date + "&nbsp;&nbsp;<a href=\"" + filename + "\">" 
+		  	  + toHtml(_("Download")) + "</a></small>\n");
 		else
-		  html->write("   <BR><SMALL>" + date + "&nbsp;&nbsp;</SMALL>\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD>\n" );
-		html->write("   " +author+ ",<BR>" +country+ "\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD align=center width=50>\n" );
+		  html->write("   <br><small>" + date + "&nbsp;&nbsp;</small>\n");
+		html->write("  </td>\n" );
+		html->write("  <td>\n" );
+		html->write("   " +author+ ",<br>" +country+ "\n");
+		html->write("  </td>\n" );
+		html->write("  <td align=center width=50>\n" );
 		html->write("   " +wins+ "\n");
-		html->write("   </TD>\n" );
-		html->write("  <TD align=center width=50>\n" );
+		html->write("   </td>\n" );
+		html->write("  <td align=center width=50>\n" );
 		html->write("   " +looses+ "\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD align=center width=50>\n" );
+		html->write("  </td>\n" );
+		html->write("  <td align=center width=50>\n" );
 		html->write("   " +ties+ "\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD align=center width=100>\n" );
+		html->write("  </td>\n" );
+		html->write("  <td align=center width=100>\n" );
 		html->write("   " +points+ "\n");
-		html->write("  </TD>\n" );
-		html->write(" </TR>\n" );
+		html->write("  </td>\n" );
+		html->write(" </tr>\n" );
 	}
 
-	html->write("</TABLE>\n");
-	html->write("</BODY>\n");
-	html->write("</HTML>");
+	html->write("</table>\n");
+	html->write("</body>\n");
+	html->write("</html>");
 
 	html->close();
 	delete html;
@@ -195,7 +197,7 @@ bool HtmlCreator::createDetailedHtml(const String& botFileName)
 {
 	if(!cssExists())
 		if(!writeCss())
-			System::println("warning: couldn't write css file");
+			System::println(_("warning: couldn't write CSS file"));
 
 	String infoFile = myManager.getInfoFileName(botFileName);
 	TopInfo info(infoFile);
@@ -215,53 +217,53 @@ bool HtmlCreator::createDetailedHtml(const String& botFileName)
 	if(html->fail())
 	{ delete html; return false; }
 
-	html->write("<html>\n<head>\n <title>RoboTour Detailed Simulation Results</title>\n");
+	html->write("<html>\n<head>\n <title>" + toHtml(_("RoboTour Detailed Simulation Results")) + "</title>\n");
 	html->write(" <link rel=\"stylesheet\" href=\"" + cssName + "\">\n");
 	html->write("</head>\n\n");
 	html->write("<body class=\"bodybg\">\n");
 
-	html->write("<H1>Detailed Simulation Results for " + toHtml(info.headers["name"].value) + "</H1>\n\n");
+	html->write("<H1>" + toHtml(_("Detailed Simulation Results for ")) + toHtml(info.headers["name"].value) + "</H1>\n\n");
 
 	html->write("<H3>" + toHtml(competitionName) + "</H3>\n\n" );
 
-	html->write("<TABLE WIDTH=\"100%\">\n");
-	html->write(" <TR>" );
-	html->write("  <TD class=\"detleft\" WIDTH=\"70%\">\n");
-	html->write("   <BIG><B>" + toHtml(info.headers["name"].value) + "</B></BIG><BR>\n");
-	html->write("   " + toHtml(info.headers["author"].value) + "<BR>\n");
-	html->write("   " + toHtml(info.headers["country"].value) + "<BR>\n");
-	html->write("  </TD>\n" );
-	html->write("  <TD class=\"detright\">" );
-	html->write("   <SMALL>last changed:<BR>\n" );
-	html->write("   " + toHtml(info.date.toString()) + "<BR><BR>\n");
+	html->write("<table WIDTH=\"100%\">\n");
+	html->write(" <tr>" );
+	html->write("  <td class=\"detleft\" WIDTH=\"70%\">\n");
+	html->write("   <BIG><B>" + toHtml(info.headers["name"].value) + "</B></BIG><br>\n");
+	html->write("   " + toHtml(info.headers["author"].value) + "<br>\n");
+	html->write("   " + toHtml(info.headers["country"].value) + "<br>\n");
+	html->write("  </td>\n" );
+	html->write("  <td class=\"detright\">" );
+	html->write("   <small>" + toHtml(_("last changed:")) + "<br>\n" );
+	html->write("   " + toHtml(info.date.toString()) + "<br>&nbsp;<br>\n");
 	if(createDownloadLinks)
-	  html->write("   <A HREF=\"" + botLink + "\">Download " + toHtml(botLink) + "</A></SMALL>\n");
+	  html->write("   <a href=\"" + botLink + "\">" + toHtml(_("Download")) + " " + toHtml(botLink) + "</a></small>\n");
 	else
-	  html->write("   File name: " + toHtml(botLink) + "</SMALL>\n");
+	  html->write("   " + toHtml(_("File name:")) + " " + toHtml(botLink) + "</small>\n");
 
-	html->write("  </TD>" );
-	html->write(" </TR>" );
-	html->write("</TABLE>\n\n" );
+	html->write("  </td>" );
+	html->write(" </tr>" );
+	html->write("</table>\n\n" );
 
 	// big table
-	html->write("<TABLE BORDER=\"0\" CELLSPACING=\"2\" CELLPADDING=\"2\" WIDTH=\"100%\">\n");
-	html->write(" <TR class=\"title\">\n" );
-	html->write("  <TD>\n" );
-	html->write("   Opponent<BR>\n" );
-	html->write("   <SMALL>Last Updated</SMALL>\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD>\n" );
-	html->write("   Author,<BR>Country\n" );
-	html->write("  <TD align=center width=50>\n" );
-	html->write("   WINS\n" );
-	html->write("   </TD>\n" );
-	html->write("  <TD align=center width=50>\n" );
-	html->write("   LOSES\n" );
-	html->write("  </TD>\n" );
-	html->write("  <TD align=center width=50>\n" );
-	html->write("   TIES\n" );
-	html->write("  </TD>\n" );
-	html->write(" </TR>\n" );
+	html->write("<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"100%\">\n");
+	html->write(" <tr class=\"title\">\n" );
+	html->write("  <td>\n" );
+	html->write("   " + toHtml(_("Opponent")) + "<br>\n" );
+	html->write("   <small>" + toHtml(_("Last updated")) + "</small>\n" );
+	html->write("  </td>\n" );
+	html->write("  <td>\n" );
+	html->write("   " + toHtml(_("Author")) + ",<br>" + toHtml(_("Country")) + "\n" );
+	html->write("  <td align=center width=50>\n" );
+	html->write("   " + toHtml(_("Wins")) + "\n" );
+	html->write("   </td>\n" );
+	html->write("  <td align=center width=50>\n" );
+	html->write("   " + toHtml(_("Losses")) + "\n" );
+	html->write("  </td>\n" );
+	html->write("  <td align=center width=50>\n" );
+	html->write("   " + toHtml(_("Ties")) + "\n" );
+	html->write("  </td>\n" );
+	html->write(" </tr>\n" );
 
 	Vector<TopTourResult> store(0);
 	readDetailed(botFileName, store);
@@ -299,52 +301,53 @@ bool HtmlCreator::createDetailedHtml(const String& botFileName)
 				cssClass = "badold";
 		}
 
-		html->write(" <TR class=\"" + cssClass + "\">\n");
-		html->write("  <TD>\n" );
+		html->write(" <tr class=\"" + cssClass + "\">\n");
+		html->write("  <td>\n" );
 		if(createLinks)
-			html->write("   <A HREF=\"" + dethtml + "\">" + programname + "</A><BR>\n");
+			html->write("   <a href=\"" + dethtml + "\">" + programname + "</a><br>\n");
 		else
-			html->write("   " + programname + "<BR>\n");
+			html->write("   " + programname + "<br>\n");
 		if(createDownloadLinks)
-			html->write("   <SMALL>"+ date + "&nbsp;&nbsp;<A HREF=\""+ filename +"\">Download</A></SMALL>\n");
+			html->write("   <small>"+ date + "&nbsp;&nbsp;<a href=\""+ filename +"\">" 
+			    + toHtml(_("Download")) + "</a></small>\n");
 		else
-			html->write("   <SMALL>"+ date + "</SMALL>\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD>\n" );
-		html->write("   " + author + ",<BR>" + country + "\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD align=center width=50>\n" );
+			html->write("   <small>"+ date + "</small>\n");
+		html->write("  </td>\n" );
+		html->write("  <td>\n" );
+		html->write("   " + author + ",<br>" + country + "\n");
+		html->write("  </td>\n" );
+		html->write("  <td align=center width=50>\n" );
 		html->write("   " + wins + "\n");
-		html->write("   </TD>\n" );
-		html->write("  <TD align=center width=50>\n" );
+		html->write("   </td>\n" );
+		html->write("  <td align=center width=50>\n" );
 		html->write("   " + looses + "\n");
-		html->write("  </TD>\n" );
-		html->write("  <TD align=center width=50>\n" );
+		html->write("  </td>\n" );
+		html->write("  <td align=center width=50>\n" );
 		html->write("   " + ties + "\n");
-		html->write("  </TD>\n" );
-		html->write(" </TR>\n" );
+		html->write("  </td>\n" );
+		html->write(" </tr>\n" );
 	}
 
 	// print legend
-	html->write("</TABLE>\n");
-	html->write("<A HREF=\"" + chartsLink + "\">Back to the charts</A><BR>\n\n");
-	html->write("<h3>Legend:</h3>\n");
-	html->write("<TABLE cellpadding=2 cellspacing=0 border=0>\n");
-	html->write("<TR><TD class=\"topcur\">\n");
-	html->write("  Opponent is in the charts\n");
-	html->write("</TD></TR>\n");
-	html->write("<TR><TD class=\"topold\">\n");
-	html->write("  Former version of a charts bot\n");
-	html->write("</TD></TR>\n");
-	html->write("<TR><TD class=\"badcur\">\n");
-	html->write("  Opponent isn't good enough for the charts\n");
-	html->write("</TD></TR>\n");
-	html->write("<TR><TD class=\"badold\">\n");
-	html->write("  Former version of a bot, which is not in the charts\n");
-	html->write("</TD></TR>\n");
-	html->write("</TABLE>\n");
-	html->write("</BODY>\n");
-	html->write("</HTML>\n");
+	html->write("</table>\n");
+	html->write("<a href=\"" + chartsLink + "\">" + toHtml(_("Back to the charts")) + "</a><br>\n\n");
+	html->write("<h3>" + toHtml(_("Legend:")) + "</h3>\n");
+	html->write("<table cellpadding=2 cellspacing=0 border=0>\n");
+	html->write("<tr><td class=\"topcur\">\n");
+	html->write("  " + toHtml(_("Opponent is in the charts")) + "\n");
+	html->write("</td></tr>\n");
+	html->write("<tr><td class=\"topold\">\n");
+	html->write("  " + toHtml(_("Former version of a charts bot")) + "\n");
+	html->write("</td></tr>\n");
+	html->write("<tr><td class=\"badcur\">\n");
+	html->write("  " + toHtml(_("Opponent isn't good enough for the charts")) + "\n");
+	html->write("</td></tr>\n");
+	html->write("<tr><td class=\"badold\">\n");
+	html->write("  " + toHtml(_("Former version of a bot, which is not in the charts")) + "\n");
+	html->write("</td></tr>\n");
+	html->write("</table>\n");
+	html->write("</body>\n");
+	html->write("</html>\n");
 
 	html->close();
 	delete html;
@@ -360,7 +363,7 @@ bool HtmlCreator::readDetailed(const String& botFileName, Vector<TopTourResult>&
 	String resFile = myManager.getResultFileName(botFile);
 	IniFile results;
 	if(!results.read(resFile))
-		System::println("warning: result file " + resFile + " not found.");
+		System::println(String::format(_("warning: result file %s not found"), resFile.cStr()));
 
 
 	IniFile::Iterator iter = results.begin();
