@@ -1,7 +1,7 @@
 /*
  * robhtml.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -25,8 +25,6 @@
 
 #include "robtopmgr.h"
 
-using namespace lrt;
-
 namespace rt {
 
 /** Creates HTML results files for top mode competitions. 
@@ -39,15 +37,15 @@ public:
 	  * This file name is used relative to the <tt>competitionFolder</tt>. 
 	  * Currently this value is "<tt>charts.xxx</tt>".
 	  */
-	static String defaultChartsIniName;
+	static lrt::String defaultChartsIniName;
 	/** A suitable default for the charts html file name.
 	  * This file name is used relative to the <tt>outputFolder</tt>. 
 	  * Currently this value is "<tt>charts.html</tt>".
 	  */
-	static String defaultChartsHtmlName;
+	static lrt::String defaultChartsHtmlName;
 
 	/// Escapes any critical characters in the given text to their HTML entities. 
-	static String toHtml(const String& text);
+	static lrt::String toHtml(const lrt::String& text);
 
 	/** Creates a new HtmlCreator which reads and writes from/to the given paths,
 	  * using the given options.
@@ -61,41 +59,41 @@ public:
 	  *                    be included into the pages?
 	  * @param createDownloadLinks Should links to the robot files be created?
 	  */
-	HtmlCreator(const String& competitionName, const File& competitionFolder,
-		const File& outputFolder, bool createLinks, bool createDownloadLinks);
+	HtmlCreator(const lrt::String& competitionName, const lrt::File& competitionFolder,
+		const lrt::File& outputFolder, bool createLinks, bool createDownloadLinks);
 
 	~HtmlCreator() {}
 
 	/** Returns the file of the detailed html file for the given bot name. */
-	File getDetailedHtml(const String& botFileName);
+	lrt::File getDetailedHtml(const lrt::String& botFileName);
 	
 	/** Creates the main HTML page. 
 	  * @param recalc If specified, rewrites the charts.cxx file at first from 
 	  *               the details sources. 
 	  */
 	bool createChartsHtml(bool recalc = false, 
-		const String& iniName = defaultChartsIniName,
-		const String& htmlName = defaultChartsHtmlName);
+		const lrt::String& iniName = defaultChartsIniName,
+		const lrt::String& htmlName = defaultChartsHtmlName);
 	/** Creates a detailed HTML page for the given bot. */
-	bool createDetailedHtml(const String& botFileName);
+	bool createDetailedHtml(const lrt::String& botFileName);
 
 
 protected:
-	String competitionName;
+	lrt::String competitionName;
 	// from last createChartsHtml() run
-	String chartsHtmlName;
-	File competitionFolder;
-	File outputFolder;
+	lrt::String chartsHtmlName;
+	lrt::File competitionFolder;
+	lrt::File outputFolder;
 	bool createLinks;
 	bool createDownloadLinks;
 
 	TopManager myManager;
 
-	// Reads the Detailed Result File and all of the referenced info files for
+	// Reads the Detailed Result lrt::File and all of the referenced info files for
 	// the given bot into the store. The store is cleared first.
-	bool readDetailed(const String& botFileName, Vector<TopTourResult>& store);
+	bool readDetailed(const lrt::String& botFileName, lrt::Vector<TopTourResult>& store);
 	
-	static String cssName;
+	static lrt::String cssName;
 	bool cssExists();
 	// Copies the CSS file (resource) to the output folder. 
 	bool writeCss();
