@@ -1,7 +1,7 @@
 /*
  * robinstr.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -26,8 +26,6 @@
 #include "robvars.h" // everyone include this!
 #include "robbase.h"
 
-using namespace lrt;
-
 // abstract base class Instr is in robbase.h
 namespace rt {
 
@@ -41,7 +39,7 @@ public:
 
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
   InstrDie(const Globals& glob);
   ~InstrDie();
@@ -58,7 +56,7 @@ public:
   virtual rint getNumCycles(Task* task);
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
   InstrMove(const Globals& glob);
   ~InstrMove();
@@ -74,9 +72,9 @@ public:
 
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrTurn(const Globals& glob, const Array<Op>& ops);
+  InstrTurn(const Globals& glob, const lrt::Array<Op>& ops);
 
   ~InstrTurn();
 };
@@ -92,9 +90,9 @@ public:
   rint getNumCycles(Task* task);
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrScan(const Globals& glob, const Array<Op>& ops);
+  InstrScan(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrScan();
 };
 
@@ -109,9 +107,9 @@ public:
   rint getNumCycles(Task* task);
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrFarscan(const Globals& glob, const Array<Op>& ops);
+  InstrFarscan(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrFarscan();
 };
 
@@ -125,9 +123,9 @@ public:
 
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrSet(const Globals& glob, const Array<Op>& ops);
+  InstrSet(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrSet();
 };
 
@@ -141,9 +139,9 @@ public:
 
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrMin(const Globals& glob, const Array<Op>& ops);
+  InstrMin(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrMin();
 };
 
@@ -158,9 +156,9 @@ public:
 
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrMax(const Globals& glob, const Array<Op>& ops);
+  InstrMax(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrMax();
 };
 
@@ -175,9 +173,9 @@ public:
 
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrAdd(const Globals& glob, const Array<Op>& ops);
+  InstrAdd(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrAdd();
 };
 
@@ -191,8 +189,8 @@ class InstrSub : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
-  InstrSub(const Globals& glob, const Array<Op>& ops);
+  lrt::String getName();
+  InstrSub(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrSub();
 };
 
@@ -206,9 +204,9 @@ class InstrMul : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrMul(const Globals& glob, const Array<Op>& ops);
+  InstrMul(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrMul();
 };
 
@@ -222,9 +220,9 @@ class InstrDiv : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrDiv(const Globals& glob, const Array<Op>& ops);
+  InstrDiv(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrDiv();
 };
 
@@ -238,9 +236,9 @@ class InstrMod : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrMod(const Globals& glob, const Array<Op>& ops);
+  InstrMod(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrMod();
 };
 
@@ -255,9 +253,9 @@ public:
   virtual rint getNumCycles(Task* task);
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrTrans(const Globals& glob, const Array<Op>& ops);
+  InstrTrans(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrTrans();
 };
 
@@ -271,9 +269,9 @@ public:
   virtual rint getNumCycles(Task* task);
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrRtrans(const Globals& glob, const Array<Op>& ops);
+  InstrRtrans(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrRtrans();
 };
 
@@ -286,9 +284,9 @@ class InstrAjump : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrAjump(const Globals& glob, const Array<Op>& ops);
+  InstrAjump(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrAjump();
 };
 
@@ -302,9 +300,9 @@ class InstrJump : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrJump(const Globals& glob, const Array<Op>& ops);
+  InstrJump(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrJump();
 };
 
@@ -318,9 +316,9 @@ class InstrBjump : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrBjump(const Globals& glob, const Array<Op>& ops);
+  InstrBjump(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrBjump();
 };
 
@@ -336,9 +334,9 @@ public:
   virtual ExecReturnType exec(Task* task);
   virtual TimingMode getTimingMode();
 
-  String getName();
+  lrt::String getName();
 
-  InstrSleep(const Globals& glob, const Array<Op>& ops);
+  InstrSleep(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrSleep();
 };
 
@@ -352,9 +350,9 @@ class InstrComp : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrComp(const Globals& glob, const Array<Op>& ops);
+  InstrComp(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrComp();
 };
 
@@ -368,9 +366,9 @@ class InstrNcomp : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrNcomp(const Globals& glob, const Array<Op>& ops);
+  InstrNcomp(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrNcomp();
 };
 
@@ -384,9 +382,9 @@ class InstrLcomp : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrLcomp(const Globals& glob, const Array<Op>& ops);
+  InstrLcomp(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrLcomp();
 };
 
@@ -400,9 +398,9 @@ class InstrGcomp : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrGcomp(const Globals& glob, const Array<Op>& ops);
+  InstrGcomp(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrGcomp();
 };
 
@@ -417,9 +415,9 @@ public:
   virtual rint getNumCycles(Task* task);
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrCreate(const Globals& glob, const Array<Op>& ops);
+  InstrCreate(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrCreate();
 };
 
@@ -432,9 +430,9 @@ class InstrRandom : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrRandom(const Globals& glob, const Array<Op>& ops);
+  InstrRandom(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrRandom();
 };
 
@@ -449,7 +447,7 @@ class InstrBreak : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
   InstrBreak(const Globals& glob);
   ~InstrBreak();
@@ -464,9 +462,9 @@ class InstrInit : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
-  InstrInit(const Globals& glob, const Array<Op>& ops);
+  InstrInit(const Globals& glob, const lrt::Array<Op>& ops);
   ~InstrInit();
 };
 
@@ -479,7 +477,7 @@ class InstrSeize : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
   InstrSeize(const Globals& glob);
   ~InstrSeize();
@@ -494,7 +492,7 @@ class InstrResume : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
   InstrResume(const Globals& glob);
   ~InstrResume();
@@ -509,7 +507,7 @@ class InstrQuit : public Instr{
 public:
   virtual ExecReturnType exec(Task* task);
 
-  String getName();
+  lrt::String getName();
 
   InstrQuit(const Globals& glob);
   ~InstrQuit();
