@@ -1,7 +1,7 @@
 /*
  * robloader.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -22,6 +22,7 @@
 #include "robvars.h"
 #include "robstrings.h"
 #include "robinstr.h"
+#include "robtrans.h"
 
 #include <rtstring.h>
 #include <rtcollect.h>
@@ -52,7 +53,7 @@ bool RobLoader::canLoad(const String& filename)
 
 String RobLoader::getFormatName()
 {
-	return "Robot Source Files (*.rob)";
+	return _("Robot Source Files (*.rob)");
 }
 
 
@@ -67,7 +68,7 @@ RobLoader::LoadReturnType RobLoader::load()
 	LoadReturnType ret;
 	if(isExample) {
 		ret.success = false;
-		ret.message = "Example loaders cannot really load programs!";
+		ret.message = _("Example loaders cannot really load programs!");
 		return ret;
 	}
 	/// load bot...
@@ -96,7 +97,7 @@ RobLoader::LoadReturnType RobLoader::loadHeaders()
 	LoadReturnType ret;
 	if(isExample) {
 		ret.success = false;
-		ret.message = "Example loaders cannot really load programs!";
+		ret.message = _("Example loaders cannot really load programs!");
 		return ret;
 	}
 	/// load headers...
@@ -129,7 +130,7 @@ RobLoader::LoadReturnType RobLoader::error(RobLoadReturnType num, DefineInputStr
 	ret.success = (num == rlOK);
 	ret.message = "";
 	if(in) ret.message += String(in->getLineNumber()) + ": ";
-	ret.message += robLoadFailMsg[num];
+	ret.message += getRobLoadFailMsg(num);
 	return ret;
 }
 
@@ -285,8 +286,8 @@ RobLoadReturnType RobLoader::convertParamSrc(const String& word, Op& op)
 	  else if(myWord == "$maxlifetime")
 	  {
 		  if(!glob.enableRC3Instr) return rlFailRC3Required;
-		  op.type = opTypeGlobal;
-		  op.ptr = simMaxLifetime;
+		  op.type = opTypeLifetime; // special handling (generation check)
+		  op.ptr = 0; // irrelevant 
 	  }
 	  else if(myWord == "$timeout")
 	  {
@@ -459,7 +460,7 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
 			  return rlFailTooManyBanks;
           String bankName = in->getLine(false);
 		  if(bankName == "")
-			  bankName = "Unnamed Bank";
+			  bankName = _("Unnamed Bank");
 		  newBank = new Bank(owner, bankName);
       }
       else // really strange
@@ -482,7 +483,7 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
 
 		  if( word[0] == '@' ) // label
           {
-              in->skipRestOfLine();
+              in->skipRestOfLine();  
               j--;       // j must NOT be increased!
               continue;
           }
@@ -491,14 +492,16 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
           if( word == "die" )
           {
               newBank->instr += new InstrDie(glob);
-              in->skipRestOfLine();
+			  ret = expectEol(in); 
+			  if(ret) return ret; 
               continue;
           }
 
           if( word == "move" )
           {
               newBank->instr += new InstrMove(glob);
-              in->skipRestOfLine();
+			  ret = expectEol(in); 
+			  if(ret) return ret; 
               continue;
           }
 
@@ -784,7 +787,8 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
           {
 			  if(!glob.enableMultitasking) return rlFailMuTaRequired;
               newBank->instr += new InstrBreak(glob);
-              in->skipRestOfLine();
+			  ret = expectEol(in); 
+			  if(ret) return ret; 
               continue;
           }
 
@@ -792,7 +796,8 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
           {
 			  if(!glob.enableMultitasking) return rlFailMuTaRequired;
               newBank->instr += new InstrSeize(glob);
-              in->skipRestOfLine();
+			  ret = expectEol(in); 
+			  if(ret) return ret; 
               continue;
           }
 
@@ -800,7 +805,8 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
           {
 			  if(!glob.enableMultitasking) return rlFailMuTaRequired;
               newBank->instr += new InstrResume(glob);
-              in->skipRestOfLine();
+			  ret = expectEol(in); 
+			  if(ret) return ret; 
               continue;
           }
 
@@ -808,7 +814,8 @@ RobLoadReturnType RobLoader::doLoad(DefineInputStream* in)
           {
 			  if(!glob.enableMultitasking) return rlFailMuTaRequired;
               newBank->instr += new InstrQuit(glob);
-              in->skipRestOfLine();
+			  ret = expectEol(in); 
+			  if(ret) return ret; 
               continue;
           }
 
@@ -881,10 +888,19 @@ RobLoadReturnType RobLoader::readOps(DefineInputStream* in, Array<Op>& ops, bool
 				return rlFailExpectComma;
 		}
 	}
-	in->skipRestOfLine();
+	ret = expectEol(in); 
+	if(ret) return ret; 
 	return rlOK;
 }
 
+RobLoadReturnType RobLoader::expectEol(DefineInputStream* in) 
+{
+	bool ok = in->expectEndOfLine();
+	if(in->eos()) ok = true; // EOF is ok too
+	if(ok) return rlOK; 
+	else return rlFailExpectEndOfLine; 
+}
+
 
 } // namespace
 
