@@ -1,7 +1,7 @@
 /*
  * robloader.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -27,8 +27,6 @@
 #include "robvars.h"
 #include "robdefines.h"
 
-using namespace lrt;
-
 namespace rt {
 
 /// Loads ROB files 
@@ -38,9 +36,9 @@ public:
 	RobLoader(const ErrorHandler* handler);
 	virtual ~RobLoader();
 
-	virtual ProgramLoader* create(const String& filename, const Globals& glob);
-	virtual bool canLoad(const String& filename);
-	virtual String getFormatName();
+	virtual ProgramLoader* create(const lrt::String& filename, const Globals& glob);
+	virtual bool canLoad(const lrt::String& filename);
+	virtual lrt::String getFormatName();
 
 protected:
 	virtual LoadReturnType load();
@@ -51,24 +49,26 @@ private:
 	typedef Instr::Op Op;
 
 	// concrete constructor
-	RobLoader(const RobLoader* example, const String& filename, const Globals& glob);
+	RobLoader(const RobLoader* example, const lrt::String& filename, const Globals& glob);
 	bool isExample;
 
-	StringMap<rint> labels;
+	lrt::StringMap<rint> labels;
 
 	// converts our error to the generic ProgramLoader error
 	LoadReturnType error(RobLoadReturnType num, DefineInputStream* in);
 
 	/// after finishing, file position is before first "Bank" or "Define" in file
 	RobLoadReturnType doLoadHeaders(DefineInputStream* in);
-	RobLoadReturnType mkOldHeader(DefineInputStream* in, const String& name);
+	RobLoadReturnType mkOldHeader(DefineInputStream* in, const lrt::String& name);
 	RobLoadReturnType mkNewHeader(DefineInputStream* in, HeaderType type);
 
 	RobLoadReturnType doLoad(DefineInputStream* in);
 	RobLoadReturnType getLabels(DefineInputStream* in);
-	RobLoadReturnType readOps(DefineInputStream* in, Array<Op>& ops, bool* dest);
-	RobLoadReturnType convertParamDest(const String& word, Op& op);
-	RobLoadReturnType convertParamSrc(const String& word, Op& op);
+	RobLoadReturnType readOps(DefineInputStream* in, lrt::Array<Op>& ops, bool* dest);
+	RobLoadReturnType convertParamDest(const lrt::String& word, Op& op);
+	RobLoadReturnType convertParamSrc(const lrt::String& word, Op& op);
+	// expects an EOL or EOF, there may only be comments or whitespace before it
+	RobLoadReturnType expectEol(DefineInputStream* in); 
 };
 
 
