@@ -1,7 +1,7 @@
 /*
  * robmanage.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -20,6 +20,7 @@
 #include "robmanage.h"
 #include "robbase.h"
 #include "robsupervis.h"
+#include "robtrans.h"
 
 #include <rtstring.h>
 #include <rtcollect.h>
@@ -68,7 +69,7 @@ SimOptions::~SimOptions()
 void SimManager::setup(SimOptions* const options)
 {
 	if(options == 0) options->errHandler->handleSystemError(36, 
-		"options may not be 0 in SimManager::setup!");
+		_("options may not be NULL in SimManager::setup!"));
 	this->options = options;
 	createPrograms();
 	// now we can ask about tour information
@@ -95,7 +96,7 @@ void SimManager::createSupervisors()
 void SimManager::createPrograms()
 {
 	if(Program::exampleLoaders.length() == 0) options->errHandler->handleSystemError(37, 
-		"cannot load bots: no example loaders!");
+		_("cannot load bots: no example loaders!"));
 	
 	for(int i = 0; i < options->files.length(); i++)
 	{
@@ -106,7 +107,7 @@ void SimManager::createPrograms()
 			for(int pl = 0; pl < Program::exampleLoaders.length(); pl++)
 				formats += "\n  " + Program::exampleLoaders[pl]->getFormatName();
 			options->errHandler->handleLoadError(
-				options->files[i], "unknown type of file. Known file formats:" + formats);
+				options->files[i], _("unknown type of file. Known file formats:") + formats);
 		}
 		else {
 			programs += newProgram;
