@@ -1,7 +1,7 @@
 /*
  * robotour.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -13,6 +13,20 @@
  * 
  */
 
+/** @mainpage RoboTour - The fast and portable RoboCom interpreter
+  * @section desc Description  
+  * RoboTour is a fast, portable, fully compatible and free RoboCom interpreter
+  * and tournament engine. It can be used to run simple simulations, big tournaments
+  * and even create competitions to which robots can be added later on. 
+  * Graphical display of tournaments (even in 3D), robot debugging and simulation
+  * history are all available. 
+  */
+
+/** @namespace rt
+  * All classes in the RoboTour main program and the associated programs 
+  * are inside the namespace rt. 
+  */
+
 /** @file robotour.cpp
   * Interpretes command line parameters, and holds RoboTour together.
   */
@@ -122,7 +136,7 @@ int rtRun(const lrt::Array<lrt::String>& args)
 	}while(frontend->doAllAgain);
 
 rtMain_done:
-	delete frontend; deleteAll(rt::Program::exampleLoaders);
+	delete frontend; lrt::deleteAll(rt::Program::exampleLoaders);
 	return 0;
 }
 
@@ -142,8 +156,9 @@ int rtMain(const lrt::Array<lrt::String>& args)
 #include <wx/thread.h>
 #include "robwxvis.h"
 #include "robwxutil.h"
+#include <rtmain.h>
 
-lrt::Array<lrt::String>* theArgs = 0; 
+const lrt::Array<lrt::String>* theArgs = 0; 
 
 class RtWxApp : public wxApp {
 public:
@@ -159,14 +174,12 @@ public:
 	{
 		// Run simulations
 		wxGetApp().exitCode = rtRun(*theArgs);
-		// now RoboTour is done, so that, if the user closes the app, we'll leave. 
-		wxTheApp->SetExitOnFrameDelete(true);
-		// but if the frame *was* already closed, that won't help any more...
+		// but if the frame *was* already closed, need to shut down ourselves...
 		if(!RobVisFrame::theVisFrame)
 		{ // we'll have to exit manually now
 #ifdef __WXMSW__ // special workaround: if no windows present, ExitMainLoop won't help within MSW
 			if(!wxTheApp->GetTopWindow()) 
-				System::exit(wxGetApp().exitCode);
+				lrt::System::exit(wxGetApp().exitCode);
 			else
 #endif // MSW
 			wxTheApp->ExitMainLoop(); // should quit the program
@@ -178,11 +191,37 @@ public:
 	}
 };
 
+wxLocale rtMyLocale; 
+
+void rtInitTranslation()
+{
+	bool locOk = rtMyLocale.Init();
+
+#ifdef EXTRA_DATA_DIR
+	rtMyLocale.AddCatalogLookupPathPrefix(wxString(wxT(EXTRA_DATA_DIR)) + wxFILE_SEP_PATH + wxT("locale")); 
+#endif
+	// look near the executable file also
+	rtMyLocale.AddCatalogLookupPathPrefix(Wx::Conv(lrt::File(lrt::File::getExecutableFile().getParent(), "locale").getName()));
+
+	
+	locOk &= rtMyLocale.AddCatalog(wxT("robotour"));
+	/*if(!locOk)
+		lrt::System::println("warning: Program translation for language "
+		+ Wx::Conv(rtMyLocale.GetName()) + " could not be loaded. \nThe program will be in English.");
+	*/
+	// in some configurations, we bring out own version of the wxstd catalog
+	rtMyLocale.AddCatalog(wxT("robotour-wxstd")); 
+}
+
 bool RtWxApp::OnInit()
 {
+	wxApp::OnInit(); 
+
+	rtInitTranslation(); 
+
 	exitCode = 0; 
-    SetAppName("RoboTour");
-	SetVendorName("RoboComTeam");
+    SetAppName(wxT("RoboTour"));
+	SetVendorName(wxT("RoboComTeam"));
 	SetExitOnFrameDelete(false);
 	RobVisFrame::theVisFrame = new RobVisFrame();
 	RobVisFrame::theVisFrame->Show();
@@ -201,21 +240,34 @@ int RtWxApp::OnExit()
 
 IMPLEMENT_APP_NO_MAIN(RtWxApp)
 
-int main(int argc, char** argv)
+int rtMain(const lrt::Array<lrt::String>& args)
 {
-	lrt::File::initialize(argv[0]);
-	// convertStdArgsToLrtArgs()
-	theArgs = new lrt::Array<lrt::String>(argc-1); 
-
-	for(int i = 1; i < argc; i++)
-	{
-		(*theArgs)[i-1] = argv[i];
-	}
+	theArgs = &args; 
 
 	if(selectFrontend(*theArgs) == UseWxFrontend)
 		return Wx::Startup();
-	else
-		return rtRun(*theArgs);
+	else {
+		wxChar* dummy_arg = wxT("dummy"); 
+#ifdef __WXMSW__
+		// There is a bug (at last I believe so) in wxMSW. 
+		// It wants to free() all of the command line arguments 
+		// that are passed to wxEntryStart, as well as the array itself. 
+		// So we've got to copy them. 
+		wxChar** dummy_argv = new wxChar*[2]; 
+		dummy_argv[0] = wxStrdup(dummy_arg); dummy_argv[1] = NULL;
+#else
+		wxChar* dummy_argv[] = { dummy_arg, NULL };
+#endif
+		int dummy_argc = 1;
+
+		bool initOK = wxEntryStart(dummy_argc, dummy_argv); 
+		if(initOK) 
+			rtInitTranslation(); 
+		int retCode = rtRun(*theArgs);
+		if(initOK)
+			wxEntryCleanup(); 
+		return retCode;
+	}
 }
 
 #endif // WX
