@@ -1,7 +1,7 @@
 /*
  * robprofile.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -21,6 +21,8 @@
 #include "robinstr.h"
 #include "robhtml.h"
 
+#include "robtrans.h"
+
 #include <rtfile.h>
 
 using namespace lrt;
@@ -32,15 +34,20 @@ FpInterpretePos ProfilePlugin::getInterpretePos()
 	return fpInterPosBefore;
 }
 
+String ProfilePlugin::getCodeName()
+{
+	return "ProfilePlugin";
+}
+
 String ProfilePlugin::getName()
 {
-	return "Robot Code Profiler";
+	return _("Robot Code Profiler");
 }
 
 String ProfilePlugin::getHelpText()
 {
-	return "  -prof T    Create a profile of type T for all robots. Possible types are \n"
-		   "             count (number of instr. exec.), time (spent during them) + fail.\n";
+	return _("  -prof T    Create a profile of type T for all robots. Possible types are \n"
+		     "             count (number of instr. exec.), time (spent during them) + fail.");
 }
 
 bool ProfilePlugin::interpreteParams(const Array<String>& params, Array<bool>& used)
@@ -51,7 +58,7 @@ bool ProfilePlugin::interpreteParams(const Array<String>& params, Array<bool>& u
 			used[i] = true;
 			// get my profile type param
 			if(used[i+1]) 
-				parent->handleSystemError(1, "Parameter missing for argument -prof");
+				parent->handleSystemError(1, _("Parameter missing for argument -prof"));
 			used[i+1] = true;
 			String type = params[i+1].lowerCase();
 			if(type == "count") {
@@ -64,7 +71,7 @@ bool ProfilePlugin::interpreteParams(const Array<String>& params, Array<bool>& u
 				mode = profFailure;
 			}
 			else 
-				parent->handleSystemError(1, "Invalid parameter for argument -prof");
+				parent->handleSystemError(1, _("Invalid parameter for argument -prof"));
 
 			active = true;
 		}
@@ -84,6 +91,22 @@ ProfilePlugin::ProfilePlugin(Frontend* parent) : FrontendPlugin(parent), mode(pr
 
 ///////////////////////// ProfileSimSupervisor
 
+// Replaces extension of file with a new one
+// which must be given with a dot, such as ".html"
+String replaceExtension(const String& file, const String& newExt)
+{
+	String outFile = file; 
+	int dotIndex; 
+	if((dotIndex = outFile.lastIndexOf('.')) > 0)
+		outFile = outFile.substring(0, dotIndex) + newExt;
+	else
+		outFile += newExt; 
+	return outFile; 
+}
+
+
+
+
 ProfileSupervisor::ProfileSupervisor(Frontend* parent, ProfileMode mode) : parent(parent), mode(mode)
 {
 }
@@ -149,30 +172,34 @@ void ProfileSupervisor::exitSim(Simulation* const curSim)
 void ProfileSupervisor::printProgram(Program* prog)
 {
 	ProgramLoader* loader = prog->getLoader();
-	if(!loader) { parent->handleWarning("Cannot get loader. Cannot write program profile."); return; }
+	if(!loader) { parent->handleWarning(_("Cannot get loader. Cannot write program profile.")); return; }
 	String progFileName = loader->getFileName();
-	if(!progFileName.length()) { parent->handleWarning("Program without file. Cannot write program profile."); return; }
+	if(!progFileName.length()) { parent->handleWarning(_("Program without file. Cannot write program profile.")); return; }
 	// Construct profile file name. The profile is saved in the robot folder, and has the
 	// same name as the robot, but with a 'profile.' prefix. 
 	File progFile(progFileName);
-	String profileName = progFile.getParent() + "profile." + progFile.getFileName();
+	String profileName = progFile.getParent() + "profile." + replaceExtension(progFile.getFileName(), ".txt");
 	// Open the profile file for writing.
 	FileOutputStream os(profileName);
-	if(os.fail()) { parent->handleWarning("Cannot create / write to profile file " + profileName + "."); return; }
+	if(os.fail()) { 
+		parent->handleWarning(String::format(_("Cannot create / write to profile file %s."), 
+			profileName.cStr()));
+		return; 
+	}
 
 	String name = prog->headers["Name"].value;
-	System::println("Writing profile of robot '" + name + "' to file " + profileName + " ...");
-	os.write("Profile of '" + name + "':\n");
+	System::println(String::format(_("Writing profile of robot '%s' to file %s ..."), name.cStr(), profileName.cStr()));
+	os.write(String::format(_("Profile of '%s':\n"), name.cStr()));
 	String desc;
 	switch(mode) {
 	  case profCount:
-		desc = "Contains number of executions of each instruction.";
+		desc = _("Contains number of executions of each instruction.");
 		break;
 	  case profTime:
-		desc = "Contains amount of cycles spent during all executions of each instruction.";
+		desc = _("Contains amount of cycles spent during all executions of each instruction.");
 		break;
 	  case profFailure:
-		desc = "Contains permilleage of instruction executions that failed.";
+		desc = _("Contains permilleage of instruction executions that failed.");
 		break;
 	}
 	os.write(desc + "\n");
@@ -183,7 +210,7 @@ void ProfileSupervisor::printProgram(Program* prog)
 		Bank* curBank = banks[b];
 		if(curBank->isSecret) // don't print RBI banks!
 			continue;
-		os.write(String("\nBank ") + curBank->name + " (" + (b+1) + ")\n");
+		os.write(String::format(_("\nBank %s (%d)\n"), curBank->name.cStr(), (int) (b+1)));
 		printInstrs(curBank, &os);
 	}
 
@@ -258,15 +285,10 @@ public:
 
 void ProfileSupervisor::printHtml(const String& profileFile)
 {
-	String outFile = profileFile; 
-	int dotIndex; 
-	if((dotIndex = outFile.lastIndexOf('.')) > 0)
-		outFile = outFile.substring(0, dotIndex) + ".html";
-	else
-		outFile += ".html"; 
+	String outFile = replaceExtension(profileFile, ".html"); 
 
 	FileInputStream* fin = new FileInputStream(profileFile, true);
-	if(fin->fail()) { parent->handleWarning("cannot open profile file"); delete fin; return; }
+	if(fin->fail()) { parent->handleWarning(_("cannot open profile file")); delete fin; return; }
 	ParseInputStream pin(fin, ParseInputStream::whitespace);
 
 	FileOutputStream fout(outFile);
@@ -287,7 +309,7 @@ void ProfileSupervisor::printHtml(const String& profileFile)
 		max = Math::max(max, lines[m].number);
 
 	// write output file
-	fout.write("<html><head><title>Profile for " + profileFile + "</title></head>\n"
+	fout.write("<html><head><title>" + String(_("Profile for ")) + profileFile + "</title></head>\n"
                "<body style=\"font-family:lucidatypewriter,lucida console,courier new,courier,monospaced,monospace\">\n"
                "<table border=0 cellpadding=0 cellspacing=0>\n");
 
@@ -326,8 +348,8 @@ bool ProfileSupervisor::isReachable(Bank* b, const String& name, Simulation* sim
 				if(name == banks[bb]->name)
 					return true;
 				else {
-					System::println("WARNING: identical bank pointer, but name has changed from '" 
-					    + name + "' to '" + banks[bb]->name + "'!!!");
+					System::println(String::format(_("warning: identical bank pointer, but name has changed from '%s' to '%s'!"),
+						name.cStr(), banks[bb]->name.cStr()));
 					return false;
 				}
 			}
