@@ -1,7 +1,7 @@
 /*
  * robprofile.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -27,8 +27,6 @@
 #include <rtsystem.h>
 #include <rtstreams.h>
 
-using namespace lrt;
-
 namespace rt {
 
 /// Type of Profile that is generated
@@ -43,9 +41,10 @@ class ProfilePlugin : public FrontendPlugin
 {
 public:
 	virtual FpInterpretePos getInterpretePos();
-	virtual String getName();
-	virtual String getHelpText();
-	virtual bool interpreteParams(const Array<String>& params, Array<bool>& used);
+	virtual lrt::String getCodeName();
+	virtual lrt::String getName();
+	virtual lrt::String getHelpText();
+	virtual bool interpreteParams(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used);
 	virtual void fillOptions(SimOptions& options);
 
 	/// Get the profile mode.
@@ -61,11 +60,11 @@ private:
 };
 
 struct ProfileBankData {
-	String name;
-	Map<Instr*, unsigned int> data;
+	lrt::String name;
+	lrt::Map<Instr*, unsigned int> data;
 };
 
-typedef Map< Bank*, ProfileBankData >  ProfileMap; 
+typedef lrt::Map< Bank*, ProfileBankData >  ProfileMap; 
 
 class ProfileSupervisor : public ExecSupervisor
 {
@@ -83,10 +82,10 @@ private:
 
 	ProfileMap profData;
 	void printProgram(Program*);
-	void printHtml(const String& profFileName); 
-	void printInstrs(Bank*, OutputStream* out);
+	void printHtml(const lrt::String& profFileName); 
+	void printInstrs(Bank*, lrt::OutputStream* out);
 	// is the bank in one of the programs of that simulation? 
-	bool isReachable(Bank*, const String& name, Simulation*);
+	bool isReachable(Bank*, const lrt::String& name, Simulation*);
 	// NOTE. We don't want to detect the fatal errors again (the instruction already does that
 	// by itself, and they can be shown) but the more subtle cases here :
 	//   * trying to create or move when there is already a bot in front of you
