@@ -1,7 +1,7 @@
 /*
  * robrating.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -18,6 +18,8 @@
 //////////////////////////////////////////////////////////////////////
 
 #include "robrating.h"
+#include "robtrans.h"
+
 
 using namespace lrt;
 
@@ -28,14 +30,19 @@ FpInterpretePos RatingPlugin::getInterpretePos()
 	return fpInterPosBefore;
 }
 
+String RatingPlugin::getCodeName()
+{
+	return "RatingPlugin";
+}
+
 String RatingPlugin::getName()
 {
-	return "Robot Rating Agency";
+	return _("Robot Rating Agency");
 }
 
 String RatingPlugin::getHelpText()
 {
-	return "  -rate N    Produce a rating for the first bot on cycle N and end \n             the game. If N < 0, wait for timeout. ";
+	return _("  -rate N    Produce a rating for the first bot on cycle N and end \n             the game. If N < 0, wait for timeout. ");
 }
 
 bool RatingPlugin::interpreteParams(const Array<String>& params, Array<bool>& used)
