@@ -1,7 +1,7 @@
 /*
  * robsound.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -18,6 +18,7 @@
 //////////////////////////////////////////////////////////////////////
 
 #include "robsound.h"
+#include "robtrans.h"
 
 #include <rtsound.h>
 
@@ -30,9 +31,14 @@ FpInterpretePos SoundPlugin::getInterpretePos()
 	return fpInterPosBefore;
 }
 
+String SoundPlugin::getCodeName()
+{
+	return "SoundPlugin";
+}
+
 String SoundPlugin::getName()
 {
-	return "Sound Plugin";
+	return _("Sound Plugin");
 }
 
 String SoundPlugin::getHelpText()
@@ -40,7 +46,7 @@ String SoundPlugin::getHelpText()
 	if(!Sound::isSupported())
 		return "";
 	
-	return "  -sound     Enable sound output.";
+	return _("  -sound     Enable sound output.");
 }
 
 bool SoundPlugin::canPlay(bool checkSilent)
@@ -48,7 +54,7 @@ bool SoundPlugin::canPlay(bool checkSilent)
 	if(!Sound::isSupported())
 	{
 		if(!checkSilent)
-			parent->handleWarning("Cannot play any sounds.");
+			parent->handleWarning(_("Cannot play any sounds."));
 		return false;
 	}
 
@@ -62,12 +68,21 @@ bool SoundPlugin::canPlay(bool checkSilent)
 	return true;
 }
 
+void SoundPlugin::reset()
+{
+	// when the tournament is reset, the old 
+	// sim supervisors and tour displayers will have been deleted. 
+	// Thus, our pointers are now invalid. 
+	tourDisp = 0; 
+	simSup = 0; 
+}
+
 bool SoundPlugin::interpreteParams(const Array<String>& params, Array<bool>& used)
 {
 	for(int i = 0; i < params.length(); i++)
 		if(params[i].lowerCase() == "-sound") // Yippee! We may play! ;-)
 		{
-			active = true;
+			setActive(true); 
 			used[i] = true;
 		}
 	return true;
@@ -79,24 +94,39 @@ void SoundPlugin::fillOptions(SimOptions& options)
 
 	if(!canPlay(false)) // really play?
 	{
-		active = false;
+		setActive(false); 
 		return;
 	}
 
-	options.tourDisps += new SoundTourDisplayer();
-	options.supervisors += new SoundSimSupervisor();
+	tourDisp = new SoundTourDisplayer(); 
+	tourDisp->setActive(active); 
+	simSup = new SoundSimSupervisor(); 
+	simSup->setActive(active); 
+
+	options.tourDisps += tourDisp;
+	options.supervisors += simSup;
+}
+
+void SoundPlugin::setActive(bool a) 
+{
+	FrontendPlugin::setActive(a); 
+	if(tourDisp) 
+		tourDisp->setActive(a); 
+	if(simSup)
+		simSup->setActive(a); 
 }
 
 bool SoundPlugin::isSoundInstalled(const String& sound, bool checkSilent)
 {
 	bool inst = Sound::isPresent(sound);
 	if(!checkSilent && !inst)
-		parent->handleWarning("Required sound not found: " + sound + Sound::getExtension());
+		parent->handleWarning(_("Required sound not found: ") + sound + Sound::getExtension());
 	return inst;
 }
 
 
-SoundPlugin::SoundPlugin(Frontend* parent) : FrontendPlugin(parent)
+SoundPlugin::SoundPlugin(Frontend* parent) 
+	: FrontendPlugin(parent), tourDisp(0), simSup(0)
 {
 }
 
@@ -110,7 +140,8 @@ TourStatusType SoundTourDisplayer::update(const Array<TourResult>& status)
 
 void SoundTourDisplayer::exit(TourStatusType exitType, const Array<TourResult>& result)
 {
-	Sound::play("end", true);
+	if(active) 
+		Sound::play("end", true);
 }
 
 
@@ -120,7 +151,7 @@ const int SoundSimSupervisor::minMillis = 60000 / 320;	// 200 BPM
 const int SoundSimSupervisor::maxMillis = 60000 / 80;		// 50 BPM
 
 
-SoundSimSupervisor::SoundSimSupervisor() : cycles(1000), lastTime(Time::getCurrentTime())
+SoundSimSupervisor::SoundSimSupervisor() : active(true), cycles(1000), lastTime(Time::getCurrentTime())
 {
 	retState.affectedProgram = 0;
 	retState.event = gameNothing;
@@ -149,13 +180,18 @@ SimSupervisor::GameState SoundSimSupervisor::exec(Simulation* const curSim)
 	else if(diff > maxMillis)
 		cycles /= 2;
 
-	Sound::play("tick", false, false);
+	if(active) 
+		Sound::play("tick", false, false);
 
 	return retState;
 }
 
 void SoundSimSupervisor::exitSim(Simulation* const curSim, const GameState& simResult)
 {
+	if(!active)
+		return; 
+
+
 	if(simResult.event == gameFinished)
 	{
 		if(simResult.affectedProgram == 0)
