@@ -1,7 +1,7 @@
 /*
  * robstreamif.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -16,10 +16,13 @@
 // Implements the Stream Interface (see Streamif.txt)
 
 #include "robstreamif.h"
+#include "robtrans.h"
 
 #include <rtsystem.h>
 #include <rtfile.h>
 
+using namespace lrt; 
+
 namespace rt {
 
 ////////////// Defines all known commands and options for them
@@ -106,14 +109,19 @@ FpInterpretePos StreamInterface::getInterpretePos()
 	return fpInterPosAfter;
 }
 
+String StreamInterface::getCodeName()
+{
+	return "StreamInterface";
+}
+
 String StreamInterface::getName()
 {
-	return "Stream Interface";
+	return _("Stream Interface");
 }
 
 String StreamInterface::getHelpText()
 {
-	// The stream interface is secret and should not be presented to the user
+	// The stream interface is internal and should not be presented to the user
 	return "";
 }
 
@@ -128,7 +136,7 @@ bool StreamInterface::interpreteParams(const Array<String>& params, Array<bool>&
 		{
 			p++; // look at next arg
 			if(used[p])
-				parent->handleSystemError(1, "Parameter missing for argument -v");
+				parent->handleSystemError(1, _("Parameter missing for argument -v"));
 			active = (params[p] == "-999");
 		}
 	}
@@ -148,12 +156,12 @@ bool StreamInterface::interpreteParams(const Array<String>& params, Array<bool>&
 
 		if(command == "version")
 		{
-			write(version);
+			write(getVersion());
 			continue;
 		}
 		if(command == "langversion")
 		{
-			write(String("RC") + languageVersion);
+			write(String("RC") + getLanguageVersion());
 			continue;
 		}
 		if(command == "commands")
