@@ -1,7 +1,7 @@
 /*
  * robstreamif.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -61,24 +61,25 @@ public:
 	virtual ~StreamInterface();
 
 	virtual FpInterpretePos getInterpretePos();
-	virtual String getName();
-	virtual String getHelpText();
-	virtual bool interpreteParams(const Array<String>& params, Array<bool>& used);
+	virtual lrt::String getCodeName();
+	virtual lrt::String getName();
+	virtual lrt::String getHelpText();
+	virtual bool interpreteParams(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used);
 	virtual void fillOptions(SimOptions& options);
 
 	// reads a command or parameter
-	String read();
+	lrt::String read();
 	// writes a result or status message
-	void write(const String&);
+	void write(const lrt::String&);
 	// writes a simple array
 	void writeArray(SifSimpleStringArray*);
 
 private:
-	Array<String>* curLine;
+	lrt::Array<lrt::String>* curLine;
 	int curPos;
 	StreamifMode mode;
 	Frontend::FightType fightType;
-	Vector<int> curBotNums;
+	lrt::Vector<int> curBotNums;
 
 	static SifSimpleStringArray setupCommands;
 	static SifSimpleStringArray ttypeOptions;
@@ -117,8 +118,8 @@ public:
 	virtual ~StreamTourDisplayer();
 
 	virtual void init(const TourInitInfo&);
-	virtual TourStatusType update(const Array<TourResult>& status);
-	virtual void exit(TourStatusType exitType, const Array<TourResult>& result);
+	virtual TourStatusType update(const lrt::Array<TourResult>& status);
+	virtual void exit(TourStatusType exitType, const lrt::Array<TourResult>& result);
 
 private:
 	StreamInterface* parent;
@@ -130,8 +131,8 @@ public:
 	virtual ~StreamErrorHandler();
 
 	virtual void handleBotError(const Bot* affectedBot, ExecReturnType type) const;
-	virtual void handleLoadError(const String& affectedFile, const String& message) const;
-	virtual void handleSystemError(int num, const String& message) const;
+	virtual void handleLoadError(const lrt::String& affectedFile, const lrt::String& message) const;
+	virtual void handleSystemError(int num, const lrt::String& message) const;
 
 private:
 	StreamInterface* parent;
