@@ -1,7 +1,7 @@
 /*
  * robstrings.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -21,29 +21,43 @@
 #ifndef __RT_ROBSTRINGS__
 #define __RT_ROBSTRINGS__
 
+namespace lrt {
+	class String; 
+}
+
+#include "robvars.h"
+
 namespace rt {
 
+/// Names of the simulation variables (Simulation::vars).
+/// These cannot, and must not, be translated. 
 extern const char* simVarNames[];
+/// Names of the program variables (Program::vars).
+/// These cannot, and must not, be translated. 
 extern const char* progVarNames[];
+/// Names of the robot variables (Bot::vars).
+/// These cannot, and must not, be translated. 
 extern const char* botVarNames[];
+/// Names of the task variables (Task::vars).
+/// These cannot, and must not, be translated. 
 extern const char* taskVarNames[];
 
-/** Bot::exec() fail codes. Leave first one empty.
+/** Bot::exec() failure codes (translated).
   * @see ExecReturnType */
-extern const char* failMsg[];
+lrt::String getFailMsg(ExecReturnType);
 
-/** RobLoader::load() fail codes. Leave first one empty.
+/** RobLoader::load() fail codes (translated).
   * @see RobLoadReturnType */
-extern const char* robLoadFailMsg[];
+lrt::String getRobLoadFailMsg(RobLoadReturnType); 
 
 /** RbiLoader::load() fail codes. Leave first one empty.
   * @see RbiLoadReturnType */
-extern const char* rbiLoadFailMsg[];
+lrt::String getRbiLoadFailMsg(RbiLoadReturnType); 
 
 /** Generic ProgramLoader::loadXxx() failure codes. 
   * @see GenLoadFailType
   */
-extern const char* genLoadFailMsg[];
+lrt::String getGenLoadFailMsg(GenLoadFailType); 
 
 } // namespace
 
