@@ -1,7 +1,7 @@
 /*
  * robtopmgr.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -18,6 +18,7 @@
 
 #include "robhtml.h"
 #include "robutils.h"
+#include "robtrans.h"
 
 #include <rtsystem.h>
 #include <rtini.h>
@@ -43,7 +44,7 @@ TopManager::~TopManager() {}
 void TopManager::setup(SimOptions* const options)
 {
 	if(options == 0) options->errHandler->handleSystemError(36, 
-		"options may not be 0 in TopManager::setup!");
+		_("options may not be NULL in TopManager::setup!"));
 	this->options = options;
 
 	newFiles = options->files;
@@ -155,12 +156,12 @@ bool TopManager::saveRes(const String& bot1, const String& bot2,
 	// save the changes to disk
 	if(!res1.write(resF1))
 	{
-		options->errHandler->handleWarning("couldn't write result file " + resF1);
+		options->errHandler->handleWarning(_("couldn't write result file ") + resF1);
 		return false;
 	}
 	if(!res2.write(resF2))
 	{
-		options->errHandler->handleWarning("couldn't write result file " + resF2);
+		options->errHandler->handleWarning(_("couldn't write result file ") + resF2);
 		return false;
 	}
 
@@ -211,7 +212,7 @@ bool TopManager::doFights(const String& botname)
 
 	if(info == 0)
 	{
-		options->errHandler->handleWarning("Unable to open the robot file " + botname + "!");
+		options->errHandler->handleWarning(String::format(_("Cannot open the robot file %s."), botname.cStr()));
 		return false;
 	}
 
@@ -247,8 +248,8 @@ bool TopManager::doFights(const String& botname)
 
 		}
 
-		System::println(String("*** ") + options->numRepeats + "x " + 
-			botname + " against " + otherBotName + " ***");
+		System::println(String::format(_("*** %dx %s against %s ***"), (int) options->numRepeats,
+			botname.cStr(), otherBotName.cStr()));
 
 		deleteAll(programs);
 		results.clear();
@@ -301,7 +302,7 @@ bool TopManager::doFights(const String& botname)
 	delete info;
 
 	// create charts html
-	HtmlCreator html("Any", competitionFolder, competitionFolder, true, true);
+	HtmlCreator html(_("Any"), competitionFolder, competitionFolder, true, true);
 	html.createChartsHtml(false, chartsFileName);
 
 	return true;
@@ -370,8 +371,8 @@ void TopManager::calcCharts(const IniFile& charts, Vector<TopTourResult>& store)
 				ties   += s["ties"].intValue(0);
 			}
 			else
-				System::println("warning: " + botname + " didn't fight against " + 
-					oppName + ".");
+				options->errHandler->handleWarning(String::format(_("%s didn't fight against %s"), 
+					botname.cStr(), oppName.cStr()));
 			++opponentIter;
 		}
 
@@ -441,7 +442,7 @@ bool TopManager::addAndCheck(const String& botname)
 	// can I load this program?
 	if(!newProg || (newProg->getBanks().length() == 0)) 
 	{
-		options->errHandler->handleWarning("wasn't able to load " + botname + ".");
+		options->errHandler->handleWarning(String::format(_("cannot load %s."), botname.cStr()));
 		return false;
 	}
 	else
