@@ -1,7 +1,7 @@
 /*
  * robtopmgr.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -26,8 +26,6 @@
 #include "robbase.h"
 #include "robmanage.h"
 
-using namespace lrt;
-
 namespace rt {
 
 class TopInfo;
@@ -43,7 +41,7 @@ public:
 	  * @param size The chart size for this competition.
 	  * @param competitionFolder The folder in which the result files should be stored. 
 	  */
-	TopManager(bool importOld, int size, const String& competitionFolder);
+	TopManager(bool importOld, int size, const lrt::String& competitionFolder);
 	virtual ~TopManager();
 
 	virtual void setup(SimOptions* const options);
@@ -53,35 +51,35 @@ public:
 	// unlike in the rest of RoboTour where it means "bot program name". 
 	// All of these botnames must be file names localized against the competition folder
 
-	String getResultFileName(const String& botname); // get the resultfile filename
-	String getInfoFileName(const String& botname);   // get the infofile filename
-	String getId(const String& botname);
-	bool setIfInTop(const String& botname, const String& top);
+	lrt::String getResultFileName(const lrt::String& botname); // get the resultfile filename
+	lrt::String getInfoFileName(const lrt::String& botname);   // get the infofile filename
+	lrt::String getId(const lrt::String& botname);
+	bool setIfInTop(const lrt::String& botname, const lrt::String& top);
 
-	bool saveRes(const String& bot1, const String& bot2, int wins, int looses, int ties);
-	TopInfo* updateBotInfo(const String& botname);
-	bool doFights(const String& botname); // let a bot fight against the charts
+	bool saveRes(const lrt::String& bot1, const lrt::String& bot2, int wins, int looses, int ties);
+	TopInfo* updateBotInfo(const lrt::String& botname);
+	bool doFights(const lrt::String& botname); // let a bot fight against the charts
 	/** Reads the charts ini file into the given store, which is cleared first. 
 	  * This method is not intended for usage in TopManager itself (which should always 
 	  * calculate the results from the results files, not from the charts), but for
 	  * usage in HTML (or other readable formats) generators. */
-	void readCharts(const IniFile& charts, Vector<TopTourResult>& store);
+	void readCharts(const lrt::IniFile& charts, lrt::Vector<TopTourResult>& store);
 	/** Calculates the charts store from the results files. The store is cleared first.
 	  * When done, sorts the store so that it is ordered after points, highest first. */
-	void calcCharts(const IniFile& charts, Vector<TopTourResult>& store);
+	void calcCharts(const lrt::IniFile& charts, lrt::Vector<TopTourResult>& store);
 	/** Sorts the store so that it is ordered after points, highest first. */
-	void sortCharts(Vector<TopTourResult>& store);
+	void sortCharts(lrt::Vector<TopTourResult>& store);
 	/** Removes all entries from the store and the charts which are not eligible for the
 	  * charts anymore. */
-	void checkChartsLength(IniFile& charts, Vector<TopTourResult>& store);
+	void checkChartsLength(lrt::IniFile& charts, lrt::Vector<TopTourResult>& store);
 
 	/** Updates the charts with the values from the given store. */
-	bool updateCharts(IniFile& charts, const Array<TopTourResult>& store);
+	bool updateCharts(lrt::IniFile& charts, const lrt::Array<TopTourResult>& store);
 
 	/** Try to add a program to the currently loaded programs. Checks if the new program
 	  * can be assembled correctly. If it doesn't, it is not added and <tt>false</tt> is
 	  * returned.  */
-	bool addAndCheck(const String& botname);
+	bool addAndCheck(const lrt::String& botname);
 
 protected:
 	TourInitInfo getTourInitInfo();
@@ -89,25 +87,25 @@ protected:
 private:
 	bool importOld;
 	int size;
-	String chartsFileName;
-	File competitionFolder;
-	Vector<String> newFiles;
+	lrt::String chartsFileName;
+	lrt::File competitionFolder;
+	lrt::Vector<lrt::String> newFiles;
 };
 
 /** Holds special information about a certain robot. This information is only used
   * by TopManager and its HTML generators. */
 class TopInfo {
 public:
-	TopInfo(const String& fileName);
+	TopInfo(const lrt::String& fileName);
 	~TopInfo();
 
-	String fileName;
+	lrt::String fileName;
 
-	StringMap<Program::HeaderField> headers; 
+	lrt::StringMap<Program::HeaderField> headers; 
 
-	String id;           ///< ID of one bot
-	Time date;         ///< date of Info-file-creation
-	String top;          ///< whether the bot is in the top
+	lrt::String id;           ///< ID of one bot
+	lrt::Time date;         ///< date of Info-file-creation
+	lrt::String top;          ///< whether the bot is in the top
 
 	void fetchDate();	 ///< fetches current date into this TopInfo
 	void incID();
@@ -124,14 +122,14 @@ public:
 	/// DON't use!!
 	TopTourResult() : TourResult(), id(0), infoId(0), top(), date() {}
 	/// Use this one instead.
-	TopTourResult(const StringMap<Program::HeaderField>& headers, const String& fileName) :
+	TopTourResult(const lrt::StringMap<Program::HeaderField>& headers, const lrt::String& fileName) :
 	    TourResult(headers, fileName), id(0), infoId(0), top(), date()
 	{}
 
 	int id; ///< required only by the TopManager
 	int infoId; ///< required only for det htmls (version check)
-	String top; ///< required only for det htmls ?
-	Time date;
+	lrt::String top; ///< required only for det htmls ?
+	lrt::Time date;
 };
 
 } // namespace
