@@ -1,7 +1,7 @@
 /*
  * robvars.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -18,18 +18,21 @@
   * as well as some global variables and typedefs. 
   */
 
-// In this file, you must not include anything!
+// In this file, you must not include anything from RoboTour! (librt is OK)
 
 #ifndef __RT_ROBVARS__
 #define __RT_ROBVARS__
 
+#include <rtstring.h>
+
+
 namespace rt {
 
 /// RoboTour's version, user-displayed version and copyright text
-extern const char* version; ///< version string for use by the program. must be parsable as a floating-point number.
-extern const char* userVersion; ///< same as version, but formatted for the user. 
-extern const char* aboutText; ///< copyright and release info
-extern const int languageVersion;
+extern lrt::String getVersion(); ///< version string for use by the program. must be parsable as a floating-point number.
+extern lrt::String getUserVersion(); ///< same as version, but formatted for the user. 
+extern lrt::String getAboutText(); ///< copyright and release info
+extern int getLanguageVersion(); ///< maximum supported language version
 
 /// The "RoboCom Integer" (rint) is an all-purpose 16-bit signed integer.
 typedef short rint;
@@ -57,9 +60,10 @@ enum SimVar {
 	simMaxVars,			///< $MaxVars
 	simMaxTasks,		///< $MaxTasks
 	simMaxMybots,		///< $MaxMybots
-	simTimeout,			///< $Timeout
+	simTimeout,			///< $lrt::Timeout
 	simElimTrigger,		///< $ElimTrigger
-	simMaxLifetime,		///< $MaxLifetime
+	simMaxLifetime,		///< $MaxLifetime for childbots
+	simMaxFirstLifetime, ///< $MaxLifetime for motherbots
 	simVarLength		///< sim variable count (array length)
 };
 
@@ -141,6 +145,7 @@ enum OpType {
 	opTypeGlobal,     //!< a simulation variable (#PUB...)
 	opTypeFields,	  //!< only $FIELDS (because it's direction dependent)
 	opTypeAge,		  //!< only $AGE (because it has to be calculated)
+	opTypeLifetime,   //!< only $MAXLIFETIME (because it depends on being a motherbot or not)
 	opTypeLabel,      //!< a label-jump-call (@begin)
 	opTypeAbsLabel,   //!< an absolute label call (@@begin)
 	opTypeRandom = 99 //!< a random number ($RANDNUM)
@@ -206,7 +211,7 @@ enum RobLoadReturnType {
 	rlFailExpectBank = 6,		///< Bank expected
 	rlFailUndefinedLabel = 7,	///< Call of undefined label
 	rlFailRedefinedLabel = 8,	///< Label declared twice
-	rlFailNoFile = 9,			///< File not found (or not accessible)
+	rlFailNoFile = 9,			///< lrt::File not found (or not accessible)
 	rlFailNoMemory = 10,		///< Insufficient memory
 	rlFailRC3Required = 11,		///< RC3 instruction found, but disabled (e.g. MUL)
 	rlFailMuTaRequired = 12,	///< MuTa instruction found, but disabled (e.g. INIT)
@@ -224,7 +229,8 @@ enum RobLoadReturnType {
 	rlFailRecurse = 24,			///< Too many recursion levels
 	rlFailUndefinedDefine = 25,	///< Undeclared define
 	rlFailRedefinedDefine = 26,	///< Define declared twice
-	rlFailInvalidIdentifier = 27 ///< Invalid character in identifier (e.g. '<')
+	rlFailInvalidIdentifier = 27, ///< Invalid character in identifier (e.g. '<')
+	rlFailExpectEndOfLine = 28  ///< End of line expected
 };
 
 ////// for RbiLoader: ///////////////////////////
@@ -235,7 +241,7 @@ enum RbiLoadReturnType {
 	rbFailUnknownCommand = 2,	///< unknown command (e.g. AOGZ)
 	rbFailUnknownParam = 3,		///< unknown parameter (e.g. $g02)
 	rbFailWrongParCount = 4,	///< wrong number of parameters for instruction (e.g. MOVE 5)
-	rbFailNoFile = 5,			///< File not found (or not accessible)
+	rbFailNoFile = 5,			///< lrt::File not found (or not accessible)
 	rbFailNoMemory = 6,			///< Insufficient memory
 	rbFailRC3Required = 7,		///< RC3 instruction found, but disabled (e.g. MUL)
 	rbFailMuTaRequired = 8,		///< MuTa instruction found, but disabled (e.g. INIT)
