@@ -1,7 +1,7 @@
 /*
  * robvis.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -18,6 +18,11 @@
 #include "robvis.h"
 #include "robwxvis.h"
 #include "robwxfe.h"
+#include "robwxstruct.h"
+#include "robsound.h"
+
+#include "robuntrans.h"
+#include "robtrans.h"
 
 using namespace lrt;
 
@@ -39,19 +44,45 @@ void PostAndWait(wxEvent& evt, int maxWait)
 	static int numProcessors = wxThread::GetCPUCount();
 
 	int numEventsSent = (++RobVisFrame::guiInfo.numEventsSent);
-	// On Multiprocessor systems, and if this event is not a critical one, 
-	// continue calculating while max. ONE event is still being processed by the GUI thread
-	// (Don't do it on SingleProcessor systems, because it will make the GUI un-reactive)
+
+	// continue processing while handling non-critical events 
+	// this is much more efficient
+	// and we don't have to fear GUI unreactiveness any more
+	// because we only handle RoboTourEvents in OnIdle. 
 	RoboTourEvent* evtAsRT = wxDynamicCast(&evt, RoboTourEvent);
 	bool uncritical = (evtAsRT && (evtAsRT->retData == 0));
-	if((numProcessors > 1) && uncritical && (maxWait >= 0) && (numEventsSent % 16)) 
-		numEventsSent--; // relaxed waiting condition, which is faster
-
-	wxPostEvent(RobVisFrame::theVisFrame, evt);
 	
+	// has lots of real time elapsed since we sent the first event in the 
+	// evtHandler's queue? 
+	bool realTimeElapsed = false; 
+	// ensure that the visFrame doesn't close just now... 
+	RobVisFrame::visLocker.Enter(); 
+	if(HaveVisFrame()){
+		// check how old the oldest event in the queue is
+		RobEventHandler* evtHandler = RobVisFrame::theVisFrame->GetRobEventHandler(); 
+		lrt::Time oldestTime = evtHandler->GetLastTime(); 
+		lrt::Time currentTime = lrt::Time::getCurrentTime(); 
+		if((currentTime - oldestTime).toInt() > 200 /* 200 msec is a lot of real time */) {
+			/*
+			lrt::String str = lrt::String("[TimeElapsed!: lastTime=") + oldestTime.toInt()
+				+ " currentTime=" + currentTime.toInt() + "]"; 
+			wxLogDebug("%s\n", str.cStr()); 
+			*/
+			realTimeElapsed = true; 
+		}
+		
+		evtHandler->AddPendingEvent(evt); 
+	}
+	RobVisFrame::visLocker.Leave(); 
+
+	// we may be able to continue processing
+	if(uncritical && (maxWait >= 0) && !realTimeElapsed) 
+		numEventsSent -= 100; 
+
+
 	int msWait = 0; 
 	while(HaveVisFrame() && (RobVisFrame::guiInfo.restart != gtourExit)  
-	  && (RobVisFrame::guiInfo.numEvents < numEventsSent) && ((maxWait < 0) || (msWait < maxWait)))
+	  && (RobVisFrame::guiInfo.numEvents < numEventsSent) && ((maxWait < 0) || (msWait++ < maxWait)))
 		wxThread::Sleep(1); // not yet finished
 }
 
@@ -61,14 +92,19 @@ FpInterpretePos VisPlugin::getInterpretePos()
 	return fpInterPosBefore; 
 }
 
+String VisPlugin::getCodeName()
+{
+	return "VisPlugin";
+}
+
 String VisPlugin::getName()
 {
-	return "Robot Visualization Engine";
+	return getTranslation("Robot Visualization Engine");
 }
 
 String VisPlugin::getHelpText()
 {
-	return "  -vis       Enable built-in graphical visualization during simulation";
+	return getTranslation("  -vis       Enable built-in graphical visualization during simulation");
 }
 bool VisPlugin::interpreteParams(const Array<String>& params, Array<bool>& used)
 {
@@ -88,7 +124,7 @@ void VisPlugin::fillOptions(SimOptions& options)
 {
 	if(active) {
 		VisDebugSupervisor* debugsup = new VisDebugSupervisor(parent);
-		VisSupervisor* vsup = new VisSupervisor(debugsup); 
+		VisSupervisor* vsup = new VisSupervisor(parent, debugsup); 
 		options.supervisors += vsup;
 		options.supervisors += debugsup;
 		options.tourDisps += new VisTourDisplayer(vsup);
@@ -107,7 +143,8 @@ VisPlugin::~VisPlugin()
 }
 
 
-VisSupervisor::VisSupervisor(VisDebugSupervisor* debugger) : initInfo(0,0), debugger(debugger), watch(new wxStopWatch)
+VisSupervisor::VisSupervisor(Frontend* parent, VisDebugSupervisor* debugger) 
+	: parent(parent), initInfo(0,0), debugger(debugger), watch(new wxStopWatch)
 {
 }
 
@@ -217,13 +254,48 @@ void VisSupervisor::processGuiRequests(Simulation* sim)
 		PostAndWait(evt);
 		RobVisFrame::guiInfo.reqPlayerInfo = -1; 
 	}
-	// other requests here...
+	// other GuiInfo requests here...
 	else // no request pending
 	{
 		wxThread::Sleep(1); // so that time passes by
 	}
-	if(debugger)
-		debugger->processGuiRequests(sim);
+
+	// GUI requests
+	Request* req = 0; 
+	while(req = RobVisFrame::guiInfo.reqDebug.removeFirst())
+	{
+		if(dynamic_cast<DebugRequest*>(req) && debugger)
+			debugger->processGuiRequest(sim, (DebugRequest*) req); 
+
+		if(dynamic_cast<SoundRequest*>(req)) {
+			processSoundRequest((SoundRequest*) req); 
+		}
+
+		// request has been processed (hopefully) 
+		delete req; 
+	}
+}
+
+void VisSupervisor::processSoundRequest(SoundRequest* req) 
+{
+	SoundPlugin* plug = dynamic_cast<SoundPlugin*>(parent->findPlugin("SoundPlugin")); 
+	if(plug) {
+		if(!plug->canPlay()) 
+			return; 
+
+		switch(req->type) {
+			case SoundRequest::TurnOn:
+				plug->setActive(true); 
+				break; 
+			case SoundRequest::TurnOff:
+				plug->setActive(false); 
+				break; 
+		
+			case SoundRequest::None:
+			default:
+				return;
+		}
+	}
 }
 
 //////////////////// VisTourDisplayer ///////////
@@ -302,7 +374,7 @@ void VisDebugSupervisor::initSim(Simulation* const sim)
 SimSupervisor::GameState VisDebugSupervisor::exec(Simulation* const curSim)
 {
 	int oldID = nextDebugID;
-	processGuiRequests(curSim);
+	//processGuiRequests(curSim);
 	for(Map<int,DebugInfo>::Iterator iter = debugInfo.begin(); iter.hasElement();)
 	{
 		DebugInfo& di = iter.get().getValue();
@@ -311,11 +383,11 @@ SimSupervisor::GameState VisDebugSupervisor::exec(Simulation* const curSim)
 		if(di.debugID < oldID) // is an old request, and was not yet sent
 		{
 			keepDI = false; // need to find it!
-			if(!di.alive) lrt::System::exit(201, "dead bot in debugInfo");
+			if(!di.alive) lrt::System::exit(201, getTranslation("dead bot found in debugInfo"));
 			// Simulation.find(bot);
 			for(List<Bot*>::Node* n = curSim->bots.first(); n; n = n->getNext())
 			{
-				if(di.botID == (int)n->accessElement()) // here it is
+				if(di.botID == n->accessElement()) // here it is
 				{
 					if(di.updateFrom(n->accessElement(), true)) // data has changed
 					{
@@ -341,7 +413,8 @@ SimSupervisor::GameState VisDebugSupervisor::exec(Simulation* const curSim)
 
 void VisDebugSupervisor::exitSim(Simulation* const curSim, const GameState& simResult)
 {
-	RobVisFrame::guiInfo.reqDebug.clear(); // requests from the old simulation are no longer relevant in the next one
+	// debug requests from the old simulation are no longer relevant in the next one
+	RobVisFrame::guiInfo.reqDebug.clearOfType(typeid(DebugRequest)); 
 
 	for(Map<int,DebugInfo>::Iterator iter = debugInfo.begin(); iter.hasElement(); iter.remove())
 	{
@@ -353,41 +426,30 @@ void VisDebugSupervisor::exitSim(Simulation* const curSim, const GameState& simR
 	}
 }
 
-void VisDebugSupervisor::processGuiRequests(Simulation* sim) // my own (debug) requests
+void VisDebugSupervisor::processGuiRequest(Simulation* sim, DebugRequest* req) // my own (debug) requests
 {
-	while(true)
+	if(req->debugX >= 0 && req->debugY >= 0 && req->debugX < sim->fieldWidth && req->debugY < sim->fieldHeight)
 	{
-		Request* req_ = RobVisFrame::guiInfo.reqDebug.removeFirst();
-		if(!req_) break; // no more requests;
-		DebugRequest* req = dynamic_cast<DebugRequest*>(req_);
-		if(req)
+		// find bot at field
+		Bot* bot = sim->field[req->debugX + req->debugY * sim->fieldWidth];
+		// start debugging it
+		if(bot) {
+			DebugInfo& di = debugInfo[nextDebugID]; // insert into map
+			di.updateFrom(bot, true);
+			di.debugID = nextDebugID;
+			DebugEvent evt(EVT_DEBUG_UPDATE_TYPE);
+			evt.data = di;
+			PostAndWait(evt);
+			nextDebugID++;
+		}
+	}
+
+	if(req->debugCloseID >= 0)
+	{
+		if(debugInfo.isSet(req->debugCloseID))
 		{
-			if(req->debugX >= 0 && req->debugY >= 0 && req->debugX < sim->fieldWidth && req->debugY < sim->fieldHeight)
-			{
-				// find bot at field
-				Bot* bot = sim->field[req->debugX + req->debugY * sim->fieldWidth];
-				// start debugging it
-				if(bot) {
-					DebugInfo& di = debugInfo[nextDebugID]; // insert into map
-					di.updateFrom(bot, true);
-					di.debugID = nextDebugID;
-					DebugEvent evt(EVT_DEBUG_UPDATE_TYPE);
-					evt.data = di;
-					PostAndWait(evt);
-					nextDebugID++;
-				}
-			}
-
-			if(req->debugCloseID >= 0)
-			{
-				if(debugInfo.isSet(req->debugCloseID))
-				{
-					debugInfo.remove(req->debugCloseID);
-				}
-			}
-
+			debugInfo.remove(req->debugCloseID);
 		}
-		delete req_;
 	}
 }
 
@@ -396,7 +458,7 @@ void VisDebugSupervisor::handleBotError(const Bot* affectedBot, ExecReturnType t
 	// debugInfo.find(affectedBot);
 	for(Map<int,DebugInfo>::Iterator iter = debugInfo.begin(); iter.hasElement();)
 	{
-		if(iter.get().getValue().botID == (int)affectedBot)
+		if(iter.get().getValue().botID == (const void*) affectedBot)
 		{
 			DebugInfo& di = iter.get().getValue();
 			di.alive = false;
