@@ -1,7 +1,7 @@
 /*
  * robvis.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -26,8 +26,6 @@
 #include <rtsystem.h>
 #include <rtstreams.h>
 
-using namespace lrt;
-
 class wxEvent;
 class wxStopWatch;
 
@@ -57,9 +55,10 @@ class VisPlugin : public FrontendPlugin
 {
 public:
 	virtual FpInterpretePos getInterpretePos();
-	virtual String getName();
-	virtual String getHelpText();
-	virtual bool interpreteParams(const Array<String>& params, Array<bool>& used);
+	virtual lrt::String getCodeName();
+	virtual lrt::String getName();
+	virtual lrt::String getHelpText();
+	virtual bool interpreteParams(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used);
 	virtual void fillOptions(SimOptions& options);
 	VisPlugin(Frontend* parent);
 	~VisPlugin();
@@ -69,26 +68,28 @@ private:
 class VisSupervisor : public SimSupervisor
 {
 public:
-	VisSupervisor(VisDebugSupervisor* debugger = 0);
+	VisSupervisor(Frontend* parent, VisDebugSupervisor* debugger = 0);
 	~VisSupervisor();
 	virtual unsigned long getStepCycles();
 	virtual void initSim(Simulation* const sim);
 	virtual GameState exec(Simulation* const curSim);
 	virtual void exitSim(Simulation* const curSim, const GameState& simResult);
-	void updateTour(const Array<TourResult>& tourStatus);
+	void updateTour(const lrt::Array<TourResult>& tourStatus);
 
 private: 
 	friend class VisTourDisplayer;
 
 	void processGuiRequests(Simulation* sim);
+	void processSoundRequest(SoundRequest* req); 
 
-	Vector<TourResult> tourStatus; 
+	lrt::Vector<TourResult> tourStatus; 
 	TourInitInfo initInfo;
 	int curSimNum; 
 
 	wxStopWatch* watch;
 
 	VisDebugSupervisor* debugger;
+	Frontend* parent; 
 };
 
 class VisTourDisplayer : public TourDisplayer {
@@ -96,9 +97,9 @@ class VisTourDisplayer : public TourDisplayer {
 public:
 	VisTourDisplayer(VisSupervisor* super);
 
-	virtual TourStatusType update(const Array<TourResult>& status);
+	virtual TourStatusType update(const lrt::Array<TourResult>& status);
 	virtual void init(const TourInitInfo& info) { super->initInfo = info; super->curSimNum = 0; }
-	virtual void exit(TourStatusType exitType, const Array<TourResult>& result) {}
+	virtual void exit(TourStatusType exitType, const lrt::Array<TourResult>& result) {}
 private:
 	VisSupervisor* super;
 };
@@ -116,10 +117,11 @@ public:
 	virtual void handleBotError(const Bot* affectedBot, ExecReturnType type);
 
 private: 
-	void processGuiRequests(Simulation* sim); // my own (debug) requests
+	// process my own (debug) requests -- called by the VisSupervisor
+	void processGuiRequest(Simulation* sim, DebugRequest* req); 
 	friend class VisSupervisor;
 
-	Map<int, DebugInfo> debugInfo;
+	lrt::Map<int, DebugInfo> debugInfo;
 	int nextDebugID;
 	WxFrontend* parent; // can be 0 (if another frontend is being used)
 };
