@@ -1,7 +1,7 @@
 /*
  * robwxdlgs.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -86,14 +86,14 @@ int TourTypeToSel(TourSetupInfo::TourType tt)
 ////////////////////// real implementation //////////////
 
 TourSetupDialog::TourSetupDialog(TourSetupInfo* data)
-	: wxDialog(RobVisFrame::theVisFrame, -1, "RoboTour - New Tournament", 
+	: wxDialog(RobVisFrame::theVisFrame, -1, _("RoboTour - New Tournament"), 
 		wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER), 
       data(data), assemblyGlob(this)
 {
 	assemblyGlob.getGlobals("assemble.rco"); // embedded resource file
 
 	CreateTourSetupDialog(this);
-	Wx::RestoreRect(this, "/GUI/TsdWindowRect");
+	Wx::RestoreRect(this, wxT("/GUI/TsdWindowRect"));
 	wxConfigBase* cfg = wxConfig::Get(); wxString sTmp; long iTmp;
 
 	wxImageList* robimagelist = new wxImageList(16,16);
@@ -101,32 +101,32 @@ TourSetupDialog::TourSetupDialog(TourSetupInfo* data)
 	robimagelist->Add(CreateTourSetupBitmap(TBMP_BINROB));
 
 	wxListCtrl* robctrl = (wxListCtrl*) FindWindow(TDLG_ROBOTS);
-	robctrl->InsertColumn(0, "Program", wxLIST_FORMAT_LEFT, -2);
-	robctrl->InsertColumn(1, "Author", wxLIST_FORMAT_LEFT, -2);
-	robctrl->InsertColumn(2, "File", wxLIST_FORMAT_LEFT, -2);
+	robctrl->InsertColumn(0, _("Program"), wxLIST_FORMAT_LEFT, -2);
+	robctrl->InsertColumn(1, _("Author"), wxLIST_FORMAT_LEFT, -2);
+	robctrl->InsertColumn(2, _("File"), wxLIST_FORMAT_LEFT, -2);
 	robctrl->AssignImageList(robimagelist, wxIMAGE_LIST_SMALL);
 	for(int rf = 0; rf < data->files.length(); rf++)
 		AddBot(Wx::Conv(data->files[rf]));
-	Wx::RestoreColumns(robctrl, "/GUI/TsdRobColumns");
+	Wx::RestoreColumns(robctrl, wxT("/GUI/TsdRobColumns"));
 
 	wxTextCtrl* osetctrl = (wxTextCtrl*) FindWindow(TDLG_OPTSET);
 	osetctrl->SetValue(Wx::Conv(data->optionFile));
-	if(cfg->Read("/Options/OptionSet", &sTmp)) osetctrl->SetValue(sTmp);
+	if(cfg->Read(wxT("/Options/OptionSet"), &sTmp)) osetctrl->SetValue(sTmp);
 
 	wxChoice* ttctrl = (wxChoice*) FindWindow(TDLG_TOURTYPE);
 	ttctrl->SetSelection(TourTypeToSel(data->type));
-	if(cfg->Read("/Options/TourType", &iTmp)) ttctrl->SetSelection(iTmp);
+	if(cfg->Read(wxT("/Options/TourType"), &iTmp)) ttctrl->SetSelection(iTmp);
 	
 	wxSpinCtrl* repctrl = (wxSpinCtrl*) FindWindow(TDLG_REPEATS);
 	repctrl->SetValue(data->numRepeats);
-	if(cfg->Read("/Options/RepeatCount", &iTmp)) repctrl->SetValue(iTmp);
+	if(cfg->Read(wxT("/Options/RepeatCount"), &iTmp)) repctrl->SetValue(iTmp);
 	
 	wxCheckBox* soundctrl = (wxCheckBox*) FindWindow(TDLG_SOUND);
 	if(data->haveSound)
 		soundctrl->SetValue(data->sound);
 	else
 		soundctrl->Disable();
-	if(cfg->Read("/Options/Sound", &iTmp)) soundctrl->SetValue(iTmp);
+	if(cfg->Read(wxT("/Options/Sound"), &iTmp)) soundctrl->SetValue(iTmp);
 
 	wxCheckBox* profctrl = (wxCheckBox*) FindWindow(TDLG_PROFILE);
 	wxChoice* proftypectrl = (wxChoice*) FindWindow(TDLG_PROFILETYPE);
@@ -138,7 +138,7 @@ TourSetupDialog::TourSetupDialog(TourSetupInfo* data)
 		profctrl->Disable(); proftypectrl->Disable();
 	}
 
-	cfg->Read("/Options/RobotPath", &robotPath);
+	cfg->Read(wxT("/Options/RobotPath"), &robotPath);
 }
 
 void TourSetupDialog::handleLoadError(const String& affectedFile, const String& message) const
@@ -199,21 +199,21 @@ void TourSetupDialog::AddBot(const wxString& botFile)
 	matchingLoader->setErrorHandler(oldHandler); 
 	if(prog == 0 || loadErrors.length())
 	{
-		wxString msg = "Cannot load robot " + botFile;
+		wxString msg; msg.Printf(_("Cannot load robot '%s'"), botFile.c_str());
 		if(loadErrors.length())
-			msg += "\nLoad error: " + Wx::Conv(loadErrors);
-		wxMessageBox(msg, "Load error", wxOK | wxICON_ERROR, this);
+			msg += _("\nLoad error: ") + Wx::Conv(loadErrors);
+		wxMessageBox(msg, _("Load error"), wxOK | wxICON_ERROR, this);
 		return;
 	}
 	// OK, program loaded, get bot info
-	wxString progname = Wx::Conv(prog->headers["name"].value) + " " + Wx::Conv(prog->headers["version"].value);
+	wxString progname = Wx::Conv(prog->headers["name"].value) + wxT(" ") + Wx::Conv(prog->headers["version"].value);
 	wxString author = Wx::Conv(prog->headers["author"].value);
 	// done with the program
 	delete prog;
 
 	wxListCtrl* robctrl = (wxListCtrl*) FindWindow(TDLG_ROBOTS);
 	int imgIndex = 0; // ROB
-	if(!(botFile.Lower().AfterLast('.') == "rob"))
+	if(!(botFile.Lower().AfterLast('.') == wxT("rob")))
 		imgIndex = 1; // RBI
 	long rowId = robctrl->GetItemCount();
 	robctrl->InsertItem(rowId, progname, imgIndex);
@@ -240,7 +240,7 @@ void TourSetupDialog::SwapBots(long b1, long b2)
 
 void TourSetupDialog::OnAdd(wxCommandEvent& evt)
 {
-	wxFileDialog fd(this, "Select robots", robotPath, "", "All robots files|*.rob;*.rbi|Robot sources (*.rob)|*.rob|Robot binaries (*.rbi)|*.rbi",
+	wxFileDialog fd(this, _("Select robots"), robotPath, wxT(""), _("All robots files|*.rob;*.rbi|Robot sources (*.rob)|*.rob|Robot binaries (*.rbi)|*.rbi"),
 		wxOPEN | wxMULTIPLE);
 	if(fd.ShowModal() == wxID_OK)
 	{
@@ -295,7 +295,7 @@ void TourSetupDialog::OnOptionSet(wxCommandEvent& evt)
 	wxTextCtrl* osetctrl = (wxTextCtrl*) FindWindow(TDLG_OPTSET);
 	wxString osetfile = osetctrl->GetValue();
 
-	wxFileDialog fd(this, "Select option set", osetfile, "", "Option set files (*.rco)|*.rco", wxOPEN);
+	wxFileDialog fd(this, _("Select option set"), osetfile, wxT(""), _("Option set files (*.rco)|*.rco"), wxOPEN);
 	if(fd.ShowModal() == wxID_OK)
 	{
 		osetfile = fd.GetPath();
@@ -307,7 +307,7 @@ void TourSetupDialog::OnOK(wxCommandEvent& evt)
 {
 	data->ok = true;
 
-	Wx::StoreRect(this, "/GUI/TsdWindowRect");
+	Wx::StoreRect(this, wxT("/GUI/TsdWindowRect"));
 	wxConfigBase* cfg = wxConfig::Get();
 
 	wxListCtrl* robctrl = (wxListCtrl*) FindWindow(TDLG_ROBOTS);
@@ -315,24 +315,24 @@ void TourSetupDialog::OnOK(wxCommandEvent& evt)
 	{
 		data->files += Wx::Conv(GetItemText(robctrl, rf, 2));
 	}
-	Wx::StoreColumns(robctrl, "/GUI/TsdRobColumns");
+	Wx::StoreColumns(robctrl, wxT("/GUI/TsdRobColumns"));
 
 	wxTextCtrl* osetctrl = (wxTextCtrl*) FindWindow(TDLG_OPTSET);
 	data->optionFile = Wx::Conv(osetctrl->GetValue());
-	cfg->Write("/Options/OptionSet", osetctrl->GetValue());
+	cfg->Write(wxT("/Options/OptionSet"), osetctrl->GetValue());
 
 	wxChoice* ttctrl = (wxChoice*) FindWindow(TDLG_TOURTYPE);
 	data->type = SelToTourType(ttctrl->GetSelection());
-	cfg->Write("/Options/TourType", ttctrl->GetSelection());
+	cfg->Write(wxT("/Options/TourType"), ttctrl->GetSelection());
 
 	wxSpinCtrl* repctrl = (wxSpinCtrl*) FindWindow(TDLG_REPEATS);
 	data->numRepeats = repctrl->GetValue();
-	cfg->Write("/Options/RepeatCount", repctrl->GetValue());
+	cfg->Write(wxT("/Options/RepeatCount"), repctrl->GetValue());
 
 	if(data->haveSound) {
 		wxCheckBox* soundctrl = (wxCheckBox*) FindWindow(TDLG_SOUND);
 		data->sound = soundctrl->IsChecked();
-		cfg->Write("/Options/Sound", soundctrl->IsChecked());
+		cfg->Write(wxT("/Options/Sound"), soundctrl->IsChecked());
 	}
 	if(data->haveProfiler) {
 		wxCheckBox* profctrl = (wxCheckBox*) FindWindow(TDLG_PROFILE);
@@ -341,7 +341,7 @@ void TourSetupDialog::OnOK(wxCommandEvent& evt)
 		data->profileType = proftypectrl->GetSelection(); //?
 	}
 
-	cfg->Write("/Options/RobotPath", robotPath);
+	cfg->Write(wxT("/Options/RobotPath"), robotPath);
 	cfg->Flush();
 
 	wxDialog::OnOK(evt);
@@ -357,20 +357,20 @@ BEGIN_EVENT_TABLE(BotErrFilterDialog, wxDialog)
 END_EVENT_TABLE()
 
 BotErrFilterDialog::BotErrFilterDialog()
-	: wxDialog(RobVisFrame::theVisFrame, -1, "Robot message filter", 
+	: wxDialog(RobVisFrame::theVisFrame, -1, _("Robot message filter"), 
 		   wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER),
 	  allowAny(true), allowSpecific(-failLast+1)
 {
 	wxSizer* sz = new wxBoxSizer(wxVERTICAL);
-	anyCB = new wxCheckBox(this, -1, "Report the following robot errors:");
+	anyCB = new wxCheckBox(this, -1, _("Report the following robot errors:"));
 	sz->Add(anyCB, 0, wxALIGN_LEFT | wxALL, 3);
 	specificCLB = new wxCheckListBox(this, -1);
 	sz->Add(specificCLB, 1, wxEXPAND | wxALL, 3);
 	sz->Add(new wxStaticLine(this, -1), 0, wxEXPAND | wxALL, 3);
-	sz->Add(new wxButton(this, wxID_CLOSE, "Close"), 0, wxALIGN_RIGHT | wxALL, 3);
+	sz->Add(new wxButton(this, wxID_CLOSE, _("Close")), 0, wxALIGN_RIGHT | wxALL, 3);
 
 	for(int en = -1; en >= failLast; en--)
-		specificCLB->Append(rt::failMsg[-en]);
+		specificCLB->Append(Wx::Conv(lrt::String(rt::getFailMsg((rt::ExecReturnType)en))));
 
 	SetSizer(sz);
 	SetSize(300, 300);
@@ -382,11 +382,11 @@ BotErrFilterDialog::BotErrFilterDialog()
 void BotErrFilterDialog::LoadSettings()
 {
 	wxConfigBase* cfg = wxConfig::Get();
-	allowAny = (bool) cfg->Read("/GUI/ShowAnyBotError", 1);
+	allowAny = (bool) cfg->Read(wxT("/GUI/ShowAnyBotError"), 1);
 	anyCB->SetValue(allowAny);
 	specificCLB->Enable(allowAny);
 
-	lrt::String str = Wx::Conv(cfg->Read("/GUI/ShowThisBotError", ""));
+	lrt::String str = Wx::Conv(cfg->Read(wxT("/GUI/ShowThisBotError"), wxT("")));
 	lrt::Array<lrt::String> arr = str.split(",", "");
 	int term = lrt::Math::min(arr.length(), -failLast+1);
 	for(int c = 0; c < term; c++) {
@@ -398,12 +398,12 @@ void BotErrFilterDialog::LoadSettings()
 void BotErrFilterDialog::StoreSettings()
 {
 	wxConfigBase* cfg = wxConfig::Get();
-	cfg->Write("/GUI/ShowAnyBotError", (long)allowAny);
+	cfg->Write(wxT("/GUI/ShowAnyBotError"), (long)allowAny);
 
 	lrt::String str;
 	for(int c = 0; c < allowSpecific.length(); c++)
 		str += String((int) allowSpecific[c]) + ",";
-	cfg->Write("/GUI/ShowThisBotError", Wx::Conv(str));
+	cfg->Write(wxT("/GUI/ShowThisBotError"), Wx::Conv(str));
 	cfg->Flush();
 }
 
@@ -486,7 +486,7 @@ BEGIN_EVENT_TABLE(BotColourComponent, wxControl)
 END_EVENT_TABLE()
 
 ProgramColourDialog::ProgramColourDialog(const BotPainter& prevSettings)
-: wxDialog(RobVisFrame::theVisFrame, -1, "Change program colours", wxDefaultPosition, 
+: wxDialog(RobVisFrame::theVisFrame, -1, _("Change program colours"), wxDefaultPosition, 
 		   wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER), painter(new BotPainter(prevSettings))
 {
 	wxSizer* sz = new wxBoxSizer(wxVERTICAL);
@@ -497,8 +497,8 @@ ProgramColourDialog::ProgramColourDialog(const BotPainter& prevSettings)
 	sz->Add(new wxStaticLine(this, -1), 0, wxEXPAND | wxALL, 3);
 	wxSizer* bsz = new wxBoxSizer(wxHORIZONTAL);
 	bsz->Add(1, 1, 1); 
-	bsz->Add(new wxButton(this, wxID_OK, "Ok"), 0, wxALL, 3);
-	bsz->Add(new wxButton(this, wxID_CANCEL, "Cancel"), 0, wxALL, 3);
+	bsz->Add(new wxButton(this, wxID_OK, _("OK")), 0, wxALL, 3);
+	bsz->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0, wxALL, 3);
 	sz->Add(bsz, 0, wxEXPAND);
 
 	SetSizerAndFit(sz);
@@ -541,7 +541,7 @@ END_EVENT_TABLE()
 	*/
 
 DebugDialog::DebugDialog(DebugInfo& initialInfo) 
-	: wxDialog(RobVisFrame::theVisFrame, -1, "RoboTour Debugger", wxDefaultPosition, wxDefaultSize, 
+	: wxDialog(RobVisFrame::theVisFrame, -1, _("RoboTour Debugger"), wxDefaultPosition, wxDefaultSize, 
 			   wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER | wxSYSTEM_MENU), namedVarT(rt::botVarLength), 
 	  curBank(0), curTask(0), follow(false)
 {
@@ -569,16 +569,16 @@ void DebugDialog::SetupColumns()
 {
 	int x, y;
 
-	bankLC->InsertColumn(0, "Num", wxLIST_FORMAT_RIGHT, -1);
-	bankLC->GetTextExtent("9999", &x, &y); bankLC->SetColumnWidth(0, x);
-	bankLC->InsertColumn(1, "Cnt", wxLIST_FORMAT_CENTER, -1);
-	bankLC->GetTextExtent("9999", &x, &y); bankLC->SetColumnWidth(1, x);
-	bankLC->InsertColumn(2, "Name", wxLIST_FORMAT_LEFT, -1);
+	bankLC->InsertColumn(0, _("Num"), wxLIST_FORMAT_RIGHT, -1);
+	bankLC->GetTextExtent(wxT("99999"), &x, &y); bankLC->SetColumnWidth(0, x);
+	bankLC->InsertColumn(1, _("Cnt"), wxLIST_FORMAT_CENTER, -1);
+	bankLC->GetTextExtent(wxT("99999"), &x, &y); bankLC->SetColumnWidth(1, x);
+	bankLC->InsertColumn(2, _("Name"), wxLIST_FORMAT_LEFT, -1);
 	bankLC->SetGrowableCol(2);
 
-	unnamedVarLC->InsertColumn(0, "ID", wxLIST_FORMAT_LEFT, -1);
-	unnamedVarLC->GetTextExtent("#999", &x, &y); unnamedVarLC->SetColumnWidth(0, x);
-	unnamedVarLC->InsertColumn(1, "Value", wxLIST_FORMAT_LEFT, -1);
+	unnamedVarLC->InsertColumn(0, _("ID"), wxLIST_FORMAT_LEFT, -1);
+	unnamedVarLC->GetTextExtent(wxT("#9999"), &x, &y); unnamedVarLC->SetColumnWidth(0, x);
+	unnamedVarLC->InsertColumn(1, _("Value"), wxLIST_FORMAT_LEFT, -1);
 	unnamedVarLC->SetGrowableCol(1);
 }
 
@@ -612,7 +612,7 @@ void DebugDialog::SetLCLength(wxListCtrl* lc, long numEntries) // makes sure tha
 	long prevEntries = lc->GetItemCount();
 	if(prevEntries < numEntries)
 		for(long e = prevEntries; e < numEntries; e++)
-			lc->InsertItem(e, "");
+			lc->InsertItem(e, wxT(""));
 	else if(prevEntries > numEntries)
 		for(long e = prevEntries-1; e >= numEntries; e--)
 			lc->DeleteItem(e);
@@ -621,15 +621,15 @@ void DebugDialog::SetLCLength(wxListCtrl* lc, long numEntries) // makes sure tha
 void DebugDialog::StoreSettings()
 {
 	wxConfigBase* cfg = wxConfig::Get();
-	cfg->Write("/GUI/DbgFollow", follow);
-	Wx::StoreRect(this, "/GUI/DbgWindowRect");
+	cfg->Write(wxT("/GUI/DbgFollow"), follow);
+	Wx::StoreRect(this, wxT("/GUI/DbgWindowRect"));
 }
 
 void DebugDialog::LoadSettings()
 {
 	wxConfigBase* cfg = wxConfig::Get();
-	Wx::RestoreRect(this, "/GUI/DbgWindowRect");
-	follow = (bool) cfg->Read("/GUI/DbgFollow", (long)false);
+	Wx::RestoreRect(this, wxT("/GUI/DbgWindowRect"));
+	follow = (bool) cfg->Read(wxT("/GUI/DbgFollow"), (long)false);
 	followCB->SetValue(follow);
 }
 
@@ -658,8 +658,8 @@ void DebugDialog::HandleUpdate(DebugInfo& newInfo, bool first)
 	{
 		if(newInfo.banks[b].hasChanged || first)
 		{
-			bankLC->SetItem(b, 0, wxString::Format("%d", b+1), newInfo.banks[b].owner);
-			bankLC->SetItem(b, 1, wxString::Format("%d", newInfo.banks[b].instructions.length()));
+			bankLC->SetItem(b, 0, wxString::Format(wxT("%d"), b+1), (int) newInfo.banks[b].owner);
+			bankLC->SetItem(b, 1, wxString::Format(wxT("%d"), (int) newInfo.banks[b].instructions.length()));
 			bankLC->SetItem(b, 2, Wx::Conv(newInfo.banks[b].name));
 		}
 	}
@@ -677,7 +677,7 @@ void DebugDialog::HandleUpdate(DebugInfo& newInfo, bool first)
 			{
 				wxStaticText* displayT = namedVarT[v];
 				if(displayT)
-					displayT->SetLabel(wxString::Format("%d", newInfo.namedVars[v]));
+					displayT->SetLabel(wxString::Format(wxT("%d"), (int) newInfo.namedVars[v]));
 			}
 		}
 	}
@@ -686,15 +686,15 @@ void DebugDialog::HandleUpdate(DebugInfo& newInfo, bool first)
 		SetLCLength(unnamedVarLC, newInfo.unnamedVars.length());
 		for(int v = 0; v < newInfo.unnamedVars.length(); v++)
 		{
-			unnamedVarLC->SetItem(v, 0, wxString::Format("#%d", v+1));
-			unnamedVarLC->SetItem(v, 1, wxString::Format("%d", newInfo.unnamedVars[v]));
+			unnamedVarLC->SetItem(v, 0, wxString::Format(wxT("#%d"), (int) (v+1)));
+			unnamedVarLC->SetItem(v, 1, wxString::Format(wxT("%d"), (int) newInfo.unnamedVars[v]));
 		}
 	}
 
 	UpdateTaskData(newInfo, first);
 
 	if(newInfo.alive == false)
-		programT->SetLabel("The bot was destroyed.");
+		programT->SetLabel(_("The bot was destroyed."));
 
 	// finally, the 'newInfo' is now the current one. 
 	info = newInfo;
@@ -711,16 +711,16 @@ void DebugDialog::UpdateTaskData(DebugInfo& newInfo, bool force)
 	if((newInfo.tasks.length() != info.tasks.length()) || force)
 	{
 		taskSL->SetRange(0, newInfo.tasks.length() - 1);
-		taskNumT->SetLabel(wxString::Format("%d/%d", curTask+1, newInfo.tasks.length()));
+		taskNumT->SetLabel(wxString::Format(wxT("%d/%d"), (int) (curTask+1), (int) newInfo.tasks.length()));
 	}
 
 	DebugInfo::TaskInfo& myTaskInfo = newInfo.tasks[curTask];
 	if(force || myTaskInfo.hasChanged)
 	{
 		// labels
-		curInstrT->SetLabel(wxString::Format("%d", myTaskInfo.instrPos+1));
+		curInstrT->SetLabel(wxString::Format(wxT("%d"), (int) (myTaskInfo.instrPos+1)));
 		curInstrTextT->SetLabel(Wx::Conv(myTaskInfo.instrText));
-		curBankT->SetLabel(wxString::Format("%d", myTaskInfo.runBank+1));
+		curBankT->SetLabel(wxString::Format(wxT("%d"), (int) (myTaskInfo.runBank+1)));
 		// viewer
 		{
 			wxClientDC viewDC(taskViewP);
@@ -786,7 +786,7 @@ void DebugDialog::OnFollow(wxCommandEvent&)
 	follow = followCB->GetValue();
 }
 
-void DebugDialog::OnTask(wxCommandEvent&)
+void DebugDialog::OnTask(wxScrollEvent&)
 {
 	int newTask = taskSL->GetValue();
 	if(newTask != curTask)
