@@ -1,7 +1,7 @@
 /*
  * robwxdlgs.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -126,7 +126,7 @@ private:
 	void UpdateInstrList(DebugInfo& info);
 	void UpdateBankImageList();
 
-	void OnTask(wxCommandEvent&);
+	void OnTask(wxScrollEvent&);
 	void OnFollow(wxCommandEvent&);
 	void OnBankList(wxListEvent&);
 
@@ -157,22 +157,3 @@ private:
 
 #endif
 
-
-//#define DD_INSTRSET 10014
-//#define DD_MOBILE 10015
-//#define DD_GENERATION 10016
-//#define DD_ACTIVE 10017
-//#define DD_XPOS 10018
-//#define DD_YPOS 10019
-//#define DD_COLOUR 10020
-//#define DD_FOLLOW 10021
-//#define DD_BANKS 10022
-//#define DD_PROGRAM 10023
-//#define DD_TASK 10024
-//#define DD_TASKNUM 10025
-//#define DD_CURINSTR 10026
-//#define DD_CURBANK 10027
-//#define DD_BOTPAINT 10028
-//#define DD_CURINSTRTEXT 10029
-//#define DD_INSTR 10030
-//#define DD_VARIABLES 10031
