@@ -1,7 +1,7 @@
 /*
  * robwxfe.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -15,7 +15,11 @@
 
 // Implements the Frontend for GUI mode
 
+#include "robtrans.h"
+#include "robuntrans.h"
+
 #include "robwxfe.h"
+#include "robwxutil.h"
 #include "robvis.h"
 #include "robwxvis.h"
 
@@ -40,8 +44,8 @@ void WxFrontend::handleBotError(const Bot* affectedBot, ExecReturnType type) con
 	if(HaveVisFrame()) {
 		RoboTourEvent evt(EVT_RT_MSGROBERR_TYPE);
 		evt.msgData.id = type;
-		evt.msgData.msg = String("robot death: ") + affectedBot->vars[botPosX] + 
-			"/" + affectedBot->vars[botPosY] + ": " + failMsg[-type];
+		evt.msgData.msg = lrt::String::format(getTranslation("robot death: %d/%d: %s").cStr(), 
+			(int) affectedBot->vars[botPosX], (int) affectedBot->vars[botPosY], getFailMsg(type).cStr());
 		evt.msgData.program = affectedBot->owner->programNum;
 		evt.LoadSimData(affectedBot->owner->sim, -1 /* don't know the sim num right now! */);
 		PostAndWait(evt, 100);
@@ -54,39 +58,40 @@ void WxFrontend::handleBotError(const Bot* affectedBot, ExecReturnType type) con
 		n->accessElement()->handleBotError(affectedBot, type);
 }
 
-void WxFrontend::handleLoadError(const String& affectedFile, const String& message) const
+void WxFrontend::handleLoadError(const lrt::String& affectedFile, const lrt::String& message) const
 {
 	if(HaveVisFrame()) {
 		RoboTourEvent evt(EVT_RT_MSGERROR_TYPE);
-		evt.msgData.msg = "load error: " + affectedFile + ": " + message;
+		evt.msgData.msg = getTranslation("load error: ") + affectedFile + ": " + message;
 		PostAndWait(evt, 100);
 	}
 	ConsoleFrontend::handleLoadError(affectedFile, message);
 }
 
-void WxFrontend::handleSystemError(int num, const String& message) const
+void WxFrontend::handleSystemError(int num, const lrt::String& message) const
 {
 	if(HaveVisFrame()) {
-		wxMessageBox(wxString::Format("fatal error: %d - %s", num, message.cStr()), "RoboTour Fatal Error", wxOK | wxICON_ERROR);
+		wxMessageBox(wxString::Format(_("fatal error: %d - %s"), num, Wx::Conv(message).c_str()), 
+			_("RoboTour Fatal Error"), wxOK | wxICON_ERROR);
 		wxTheApp->ExitMainLoop();
 		wxThread::Sleep(500); // give wx time to shut down
-		System::exit(num);
+		lrt::System::exit(num);
 	}
 	else
 		ConsoleFrontend::handleSystemError(num, message);
 }
 
-void WxFrontend::handleWarning(const String& message) const
+void WxFrontend::handleWarning(const lrt::String& message) const
 {
 	if(HaveVisFrame()) {
 		RoboTourEvent evt(EVT_RT_MSGWARN_TYPE);
-		evt.msgData.msg = "warning: " + message;
+		evt.msgData.msg = getTranslation("warning: ") + message;
 		PostAndWait(evt, 100);
 	}
 	ConsoleFrontend::handleWarning(message);
 }
 
-bool WxFrontend::interpreteParamsImpl(const Array<String>& params, Array<bool>& used)
+bool WxFrontend::interpreteParamsImpl(const lrt::Array<lrt::String>& params, lrt::Array<bool>& used)
 {
 	// interprete command line parameters
 	bool consRet = ConsoleFrontend::interpreteParamsImpl(params, used);
@@ -97,8 +102,8 @@ bool WxFrontend::interpreteParamsImpl(const Array<String>& params, Array<bool>&
 		return consRet;
 	}
 
-	SoundPlugin* sp = (SoundPlugin*) findPlugin("Sound Plugin");
-	ProfilePlugin* pp = (ProfilePlugin*) findPlugin("Robot Code Profiler");
+	SoundPlugin* sp = (SoundPlugin*) findPlugin("SoundPlugin");
+	ProfilePlugin* pp = (ProfilePlugin*) findPlugin("ProfilePlugin");
 
 	// wait until the user decides to setup a new tournament
 	RobVisFrame::guiInfo.abortTourPressed = false; 
