@@ -1,7 +1,7 @@
 /*
  * robwxgl.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -90,7 +90,7 @@ static int glParams[] = { WX_GL_RGBA, WX_GL_DEPTH_SIZE, 16, WX_GL_AUX_BUFFERS, 0
                           0/*End*/ };
 
 GLFieldPanel::GLFieldPanel(wxWindow* parent, RobVisFrame* vframe, wxWindowID id)
-	: wxGLCanvas(parent, id, wxDefaultPosition, wxSize(640, 480), 0/*style*/, "wxGLCanvas", glParams), FieldDisplay(vframe),
+	: wxGLCanvas(parent, id, wxDefaultPosition, wxSize(640, 480), 0/*style*/, wxT("wxGLCanvas"), glParams), FieldDisplay(vframe),
 	  glInitDone(false), useHQ(false), posDist(10), angUp(45), angSide(0), quadric(0)
 {
 	// pre-initialize simInfo, so we can draw the empty field 
@@ -200,7 +200,7 @@ void GLFieldPanel::Update(bool force)
 
 	// draw the whole field in one polygon
 	glCallList(listBigField);
-	if(glGetError()) wxLogError("glCallList(field)");
+	if(glGetError()) wxLogError(wxT("glCallList(field)"));
 
 	GLfloat white[] = {1, 1, 1, 1};
 	glMaterialfv(GL_FRONT, GL_SPECULAR, white); // set highlights to white
@@ -270,11 +270,11 @@ void GLFieldPanel::OnLeftUp(wxMouseEvent& event)
 //	lrt::System::println(Wx::Conv(wxString::Format("pix coord: <%d,%d> vp<%d,%d,%d,%d>", pixX, pixY, viewport[0], viewport[1], viewport[2], viewport[3])));
 	double objX, objY, objZ, yTmp;
 	if(!gluUnProject(pixX, pixY, 0.0, fieldModelMatrix, projMatrix, viewport, &objX, &objY, &objZ))
-		wxLogError("gluUnProject(x,y,0)");
+		wxLogError(wxT("gluUnProject(x,y,0)"));
 	yTmp = objY;
 //	lrt::System::println(Wx::Conv(wxString::Format("front coord: <%f,%f,%f>", objX, objY, objZ)));
 	if(!gluUnProject(pixX, pixY, 1.0, fieldModelMatrix, projMatrix, viewport, &objX, &objY, &objZ))
-		wxLogError("gluUnProject(x,y,1)");
+		wxLogError(wxT("gluUnProject(x,y,1)"));
 //	lrt::System::println(Wx::Conv(wxString::Format("back coord: <%f,%f,%f>", objX, objY, objZ)));
 	// interpolate so that Y=0 (field level)
 	if((objY > 0 && yTmp > 0) || yTmp < objY) {
@@ -301,7 +301,7 @@ void GLFieldPanel::OnLeftUp(wxMouseEvent& event)
 		lrt::System::println("clicked outside of field!");
 		return; 
 	}
-	lrt::System::println(Wx::Conv(wxString::Format("click point: <%f,%f, [%f]> => <%d,%d>", objX, objZ, objY, fieldX, fieldY)));
+	lrt::System::println(Wx::Conv(wxString::Format(wxT("click point: <%f,%f, [%f]> => <%d,%d>"), objX, objZ, objY, fieldX, fieldY)));
 	vframe->HandleFieldClick(fieldX, fieldY);
 }
 void GLFieldPanel::OnRightUp(wxMouseEvent& event)
@@ -477,7 +477,7 @@ void GLFieldPanel::UpdateBigFieldIfNeeded()
 {
 	if(!texField || !glIsTexture(texField))
 	{
-		wxLogError("update big field called, but texField not loaded!");
+		wxLogError(wxT("update big field called, but texField not loaded!"));
 	}
 
 	if(simInfo.width == lbfX && simInfo.height == lbfY)
@@ -497,7 +497,7 @@ void GLFieldPanel::UpdateBigFieldIfNeeded()
 	GLfloat dark[4] = {0.1f, 0.1f, 0.1f, 1};
 
 	glNewList(listBigField, GL_COMPILE);
-	if(glGetError()) wxLogError("glNewList()");
+	if(glGetError()) wxLogError(wxT("glNewList()"));
 	  glEnable(GL_TEXTURE_2D);
 	  glMaterialfv(GL_FRONT, GL_DIFFUSE, white);
 	  glMaterialfv(GL_FRONT, GL_AMBIENT, dark);
@@ -527,11 +527,11 @@ int GLFieldPanel::LoadTexture(const wxBitmap& bitmap)
 	unsigned int texNum;
 	glEnable(GL_TEXTURE_2D);
 	glGenTextures(1, &texNum);
-	if(glGetError()) wxLogError("glGenTextures()");
+	if(glGetError()) wxLogError(wxT("glGenTextures()"));
 	glBindTexture(GL_TEXTURE_2D, texNum);
-	if(glGetError()) wxLogError("glBindTexture()");
+	if(glGetError()) wxLogError(wxT("glBindTexture()"));
 	gluBuild2DMipmaps(GL_TEXTURE_2D, 3, img.GetWidth(), img.GetHeight(), GL_RGB, GL_UNSIGNED_BYTE, img.GetData());
-	if(glGetError()) wxLogError("gluBuild2DMipmaps()");
+	if(glGetError()) wxLogError(wxT("gluBuild2DMipmaps()"));
 //	glDisable(GL_TEXTURE_2D);
 	return texNum;
 }
