@@ -1,7 +1,7 @@
 /*
  * robwxhist.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -32,7 +32,7 @@ HistoryCtrl::HistoryCtrl(wxWindow* parent, wxWindowID id, const wxPoint& pos, co
 	  max(255), screenPos(0), bmpPos(0), minInterval(50), lastCycle(-10000)
 {
 	SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
-	SetToolTip("History");
+	SetToolTip(_("History"));
 	buf = new wxBitmap(size.x * 2, size.y);
 	ClearHistory();
 }
@@ -56,7 +56,11 @@ void HistoryCtrl::ClearHistory()
 	lastCycle = -1000; 
 	screenPos = 0;
 	bmpPos = 0;
+#if wxCHECK_VERSION(2, 5, 0) // this wxWindow:: method has been renamed recently
+	ClearBackground();
+#else
 	Clear();
+#endif
 	wxMemoryDC trgDC;
 	trgDC.SelectObject(*buf);
 	wxBrush bgBrush(GetBackgroundColour(), wxSOLID);
@@ -70,6 +74,9 @@ void HistoryCtrl::UpdateFrom(RoboTourEvent& evt)
 		return;
 	if(evt.simData.cycle > lastCycle && evt.simData.cycle < lastCycle + minInterval)
 		return;
+	if(!RobVisFrame::theVisFrame)
+		return; 
+
 	lastCycle = evt.simData.cycle;
 	lrt::Vector<TourInfo>& data = evt.tourData;
 
