@@ -1,7 +1,7 @@
 /*
  * robwxstruct.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -64,6 +64,20 @@ void RequestQueue::clear()
 	lrt::deleteAll(begin());
 }
 
+void RequestQueue::clearOfType(const std::type_info& type) 
+{
+	wxCriticalSectionLocker csl(*critSect); 
+
+	for(lrt::Iterator<Request*> iter = begin(); iter.hasElement(); ) {
+		if(typeid(*(iter.get())) == type) {
+			delete iter.get(); 
+			remove(iter); 
+		}
+		else
+			++iter; 
+	}
+}
+
 
 ///////////////////////////////// BotInfo
 BotInfo::BotInfo(Bot* bot)
@@ -81,8 +95,8 @@ BotInfo::BotInfo(Bot* bot)
 		for(int t = 0; t < bot->tasks.length(); t++) {
 			Task* ta = bot->tasks[t]; 
 			rint curBank = ta->vars[taskCurBank];
-			if(curBank >= bot->banks.length())
-				continue;  // it might be invalid!
+			if(curBank >= bot->banks.length() || curBank < 0)
+				continue;  // bank number might be invalid!
 			head[ ta->vars[taskDir] ] = bot->banks[ curBank ]->owner->programNum;
 		}
 		active = bot->vars[botActive];
@@ -115,13 +129,13 @@ bool BotInfo::operator=(const BotInfo& b)
 
 bool DebugInfo::BankInfo::updateFrom(Bank* bank)
 {
-	if(id == (int)bank) {
+	if(id == bank) {
 		hasChanged = false;
 		return hasChanged; // already up-to-date
 	}
 	
 	hasChanged = true;
-	id = (int)bank;
+	id = bank;
 	owner = bank->owner->programNum;
 
 	if(bank->isSecret)
@@ -176,7 +190,7 @@ bool DebugInfo::updateFrom(Bot* bot, bool alive)
 	bool hasChanged = false; // the return value
 	
 	ASSIGN_CHECK_CHANGE(this->alive, alive);
-	ASSIGN_CHECK_CHANGE(botID, (int)bot);
+	ASSIGN_CHECK_CHANGE(botID, bot);
 	botInfo = BotInfo(bot);
 	programName = bot->owner->headers["name"].value;
 
