@@ -1,7 +1,7 @@
 /*
  * robwxstruct.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -24,6 +24,8 @@
 #include "robmanage.h"
 #include "robvars.h"
 
+#include <typeinfo>
+
 // predefines // 
 namespace rt { class Bot; }
 namespace lrt {
@@ -66,6 +68,21 @@ public:
 	int debugX, debugY, debugCloseID;
 };
 
+class SoundRequest : public Request {
+public:
+	enum Type {
+		None, 
+		TurnOn,
+		TurnOff
+	}; 
+
+public:
+	SoundRequest() : type(None) {}
+	Request* clone() const { return new SoundRequest(*this); }
+
+	Type type; 
+}; 
+
 class RequestQueue : lrt::List<Request*> {
 public:
 	RequestQueue();
@@ -73,6 +90,7 @@ public:
 	void append(const Request&);
 	Request* removeFirst(); // returned Request must be deleted
 	void clear();
+	void clearOfType(const std::type_info& type); 
 private:
 	wxCriticalSection* critSect;
 };
@@ -196,7 +214,7 @@ struct DebugInfo
 	struct BankInfo {
 		BankInfo() : id(0), owner(-1), hasChanged(false) {}
 		bool updateFrom(rt::Bank*);
-		int id;
+		void* id;
 		int owner;
 		lrt::String name;
 		lrt::Vector<lrt::String> instructions;
@@ -208,7 +226,7 @@ struct DebugInfo
 	bool updateFrom(rt::Bot*, bool alive); // returns TRUE if ANYTHING has changed
 
 	int debugID; // which debugging session is this? (each bot gets a new one)
-	int botID;
+	void* botID;
 
 	bool alive; 
 
