@@ -1,7 +1,7 @@
 /*
  * robwxutil.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -14,24 +14,29 @@
  */
 
 // Implements utilities for wxWidgets
+#ifdef __WXWIN__ // must not do anything for !wxWin 
 
-#include <wx/wx.h>
-#include <wx/listctrl.h>
-#include <wx/config.h>
-#include <wx/mimetype.h>
+#include <wx/string.h>
+#include <wx/app.h>
+#if wxUSE_GUI
+#	include <wx/wx.h>
+#	include <wx/listctrl.h>
+#	include <wx/config.h>
+#	include <wx/mimetype.h>
+#endif
 
 #include <rtstring.h>
 #include <rtmath.h>
 
 #include "robwxutil.h"
 
-#ifdef __WXMSW__ // (WINDOWS)
+#if defined(__WXMSW__) && wxUSE_GUI // (WINDOWS GUI mode using WinMain)
 #  include <windows.h>
 #  include <wx/msw/winundef.h>
 
 int Wx::Startup()
 {
-	char* dummy_argv = "dummy";
+	wxChar* dummy_argv = wxT("dummy");
 	return wxEntry(GetModuleHandle(0), 0, dummy_argv, SW_SHOW);
 }
 
@@ -39,28 +44,34 @@ int Wx::Startup()
 
 int Wx::Startup()
 {
-	char* dummy_argv[] = { "dummy", 0 };
-	return wxEntry(1, dummy_argv);
+	wxChar* dummy_argv[] = { wxT("dummy"), 0 };
+	int dummy_argc = 1;
+	return wxEntry(dummy_argc, dummy_argv);
 }
 
 #endif // (OS SELECTION)
 
 wxString Wx::Conv(const lrt::String& str)
 {
-	return wxString(str.cStr());
+	return wxString(str.cStr(), *wxConvCurrent);
 }
 
 lrt::String Wx::Conv(const wxString& str)
 {
-	return lrt::String(str.c_str());
+	return lrt::String(str.mb_str(*wxConvCurrent));
 }
 
 
+// ///////////////////////////////////////////////////////////////
+// remainder only for GUI mode
+#if wxUSE_GUI || !defined(wxUSE_GUI) // it is the default
+
+
 void Wx::StoreArray(const lrt::Array<int>& arr, const wxString& cfgKey)
 {
 	wxString val;
 	for(int c = 0; c < arr.length(); c++) {
-		val << arr[c] << ",";
+		val << arr[c] << wxT(",");
 	}
 	val.Truncate(val.Len() - 1); // stop last comma
 	wxConfigBase* cfg = wxConfig::Get();
@@ -70,7 +81,7 @@ void Wx::StoreArray(const lrt::Array<int>& arr, const wxString& cfgKey)
 lrt::Array<int> Wx::ReadArray(int def, const wxString& cfgKey)
 {
 	wxConfigBase* cfg = wxConfig::Get();
-	lrt::String str = Wx::Conv(cfg->Read(cfgKey, ""));
+	lrt::String str = Wx::Conv(cfg->Read(cfgKey, wxT("")));
 	lrt::Array<lrt::String> arr = str.split(",", "");
 	lrt::Array<int> ret(arr.length());
 	for(int i = 0; i < arr.length(); i++)
@@ -78,7 +89,7 @@ lrt::Array<int> Wx::ReadArray(int def, const wxString& cfgKey)
 	return ret; 
 }
 
-// FIXME: for toplevel windows (frames dialogs)
+// for toplevel windows (frames dialogs)
 // * handle "MAXIMIZED" case specially
 void Wx::StoreRect(wxWindow* win, const wxString& cfgKey)
 {
@@ -95,25 +106,25 @@ void Wx::StoreRect(wxWindow* win, const wxString& cfgKey)
 		else if(twin->IsMaximized())
 		{
 			// just re-use previous state
-			val = cfg->Read(cfgKey, "");
-			if(val.AfterLast(',') != "max") // was not already saved max'ed => append ",max"
-				val += ",max"; 
+			val = cfg->Read(cfgKey, wxT(""));
+			if(val.AfterLast(',') != wxT("max")) // was not already saved max'ed => append ",max"
+				val += wxT(",max"); 
 			cfg->Write(cfgKey, val);
 			return;
 		}
 	}
 	// window is no toplevel, or is not in a special state
-	val = wxString::Format("%d,%d,%d,%d", rect.x, rect.y, rect.width, rect.height);
+	val = wxString::Format(wxT("%d,%d,%d,%d"), rect.x, rect.y, rect.width, rect.height);
 	cfg->Write(cfgKey, val);
 }
 
-// FIXME: for toplevel windows (frames dialogs)
+// for toplevel windows (frames dialogs)
 // * handle "MAXIMIZED" case specially
 // * make sure that the window is not positioned offscreen due to resolution changes
 void Wx::RestoreRect(wxWindow* win, const wxString& cfgKey)
 {
 	wxConfigBase* cfg = wxConfig::Get();
-	lrt::String str = Wx::Conv(cfg->Read(cfgKey, ""));
+	lrt::String str = Wx::Conv(cfg->Read(cfgKey, wxT("")));
 	lrt::Array<lrt::String> arr = str.split(",", "");
 	if(arr.length() < 4 || arr.length() > 5) // invalid str
 		return;
@@ -141,7 +152,7 @@ void Wx::StoreColumns(wxListCtrl* ctrl, const wxString& cfgKey)
 	int colCount = ctrl->GetColumnCount();
 	wxString val;
 	for(int c = 0; c < colCount; c++) {
-		val << ctrl->GetColumnWidth(c) << ",";
+		val << ctrl->GetColumnWidth(c) << wxT(",");
 	}
 	wxConfigBase* cfg = wxConfig::Get();
 	cfg->Write(cfgKey, val);
@@ -151,7 +162,7 @@ void Wx::RestoreColumns(wxListCtrl* ctrl, const wxString& cfgKey)
 {
 	int colCount = ctrl->GetColumnCount();
 	wxConfigBase* cfg = wxConfig::Get();
-	lrt::String str = Wx::Conv(cfg->Read(cfgKey, ""));
+	lrt::String str = Wx::Conv(cfg->Read(cfgKey, wxT("")));
 	lrt::Array<lrt::String> arr = str.split(",", "");
 	int term = arr.length(); if(colCount < term) term = colCount;
 	for(int c = 0; c < term; c++)
@@ -160,27 +171,26 @@ void Wx::RestoreColumns(wxListCtrl* ctrl, const wxString& cfgKey)
 
 void Wx::ShowInBrowser(const wxString& htmlFile)
 {
-	wxFileType* ftHtml = wxTheMimeTypesManager->GetFileTypeFromMimeType("text/html");
+	wxFileType* ftHtml = wxTheMimeTypesManager->GetFileTypeFromMimeType(wxT("text/html"));
 	wxString browserCmd; 
 	if(ftHtml) browserCmd = ftHtml->GetOpenCommand(htmlFile); 
 	delete ftHtml; ftHtml = 0; 
 
 	if(browserCmd.IsEmpty()) { // resort to asking the user... 
-		browserCmd = ReadString("", "/BrowserCmd"); 
+		browserCmd = ReadString(wxT(""), wxT("/BrowserCmd")); 
 		if(browserCmd.IsEmpty())
-			browserCmd = wxGetTextFromUser("Enter the command to start your favourite browser:", "Browser selection", "netscape"); 
+			browserCmd = wxGetTextFromUser(_("Enter the command to start your favourite browser:"), _("Browser selection"), wxT("firefox")); 
 		if(browserCmd.IsEmpty()) // user doesn't want to enter browser
 			return; 
 		else {
-			StoreString(browserCmd, "/BrowserCmd"); 
-			browserCmd += " " + htmlFile;
+			StoreString(browserCmd, wxT("/BrowserCmd")); 
+			browserCmd += wxT(" ") + htmlFile;
 		}
 	}
 	if(!wxExecute(browserCmd)) {
-		wxLogError("Cannot start browser for showing HTML file. Please open %s yourself.", htmlFile.c_str()); 
-		StoreString("", "/BrowserCmd"); // browser does not work, ask again next time
+		wxLogError(_("Cannot start browser for showing HTML file. Please open %s yourself."), htmlFile.c_str()); 
+		StoreString(wxT(""), wxT("/BrowserCmd")); // browser does not work, ask again next time
 	}
-	delete ftHtml; 
 }
 
 wxString Wx::ReadString(const wxString& def, const wxString& key)
@@ -194,3 +204,8 @@ void Wx::StoreString(const wxString& val, const wxString& key)
 	wxConfigBase* cfg = wxConfig::Get();
 	cfg->Write(key, val);
 }
+
+
+#endif // wxUSE_GUI
+#endif // __WXWIN__
+
