@@ -1,7 +1,7 @@
 /*
  * robwxvis.cpp
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -45,6 +45,7 @@ using namespace rt;
 #include "bitmaps/fieldno.xpm"
 #include "bitmaps/field2d.xpm"
 #include "bitmaps/field3d.xpm"
+#include "bitmaps/sound.xpm"
 #ifndef __WXMSW__
 #  include "bitmaps/robotour.xpm"
 #endif
@@ -72,15 +73,17 @@ RoboTourEvent::RoboTourEvent(int eventType)
 { 
 	SetId(-1); 
 	SetEventType(eventType);
-}
 
+	timeStamp = lrt::Time::getCurrentTime(); 
+}
+/*
 RoboTourEvent::RoboTourEvent(const RoboTourEvent& evt)
     : wxEvent(evt), botData(evt.botData), simData(evt.simData), 
 	  tourData(evt.tourData), tourInitData(evt.tourInitData), playerData(evt.playerData), 
-	  retData(evt.retData), msgData(evt.msgData)
+	  retData(evt.retData), msgData(evt.msgData), timeStamp(evt.timeStamp)
 {
 }
-
+*/
 void RoboTourEvent::LoadBotData(Simulation* sim)
 {
 	botData.clear();
@@ -160,28 +163,292 @@ wxEvent* DebugEvent::Clone() const
     return new DebugEvent(*this);
 }
 
+//////////////////////////// RobEventHandler ////
+BEGIN_EVENT_TABLE(RobEventHandler, wxEvtHandler) 
+	EVT_RT_SHOW(RobEventHandler::OnShow)
+	EVT_RT_INITSIM(RobEventHandler::OnInitSim)
+	EVT_RT_STEPSIM(RobEventHandler::OnStepSim)
+	EVT_RT_EXITSIM(RobEventHandler::OnExitSim)
+	EVT_RT_STEPTOUR(RobEventHandler::OnStepTour)
+	EVT_RT_PLAYER(RobEventHandler::OnPlayerInfo)
+	EVT_RT_SETUPDLG(RobEventHandler::OnSetupDlg)
+	EVT_RT_MSGINFO(RobEventHandler::OnMsgInfo)
+	EVT_RT_MSGWARN(RobEventHandler::OnMsgWarn)
+	EVT_RT_MSGERROR(RobEventHandler::OnMsgError)
+	EVT_RT_MSGROBERR(RobEventHandler::OnMsgRobErr)
+	EVT_DEBUG_UPDATE(RobEventHandler::OnDebugUpdate)
+	EVT_DEBUG_CLOSE(RobEventHandler::OnDebugClose)
+END_EVENT_TABLE()
+
+RobEventHandler::RobEventHandler(RobVisFrame* parent)
+: wxEvtHandler(), parent(parent), lastTime(/*init to 1970*/)
+{
+}
+
+// just like wxwidgets/src/common/event.cpp
+void RobEventHandler::AddPendingEvent(wxEvent& event) 
+{
+    // 1) Add event to list of pending events of this event handler
+    wxEvent* eventCopy = event.Clone();
+
+    // we must be able to copy the events here so the event class must
+    // implement Clone() properly instead of just providing a NULL stab for it
+    wxCHECK_RET( eventCopy,
+                 wxT("events of this type aren't supposed to be posted") );
+
+#if defined(__VISAGECPP__)
+    wxENTER_CRIT_SECT( m_eventsLocker);
+#else
+    wxENTER_CRIT_SECT( *m_eventsLocker);
+#endif
+
+    if ( !m_pendingEvents )
+      m_pendingEvents = new wxList;
+
+    m_pendingEvents->Append(eventCopy);
+
+#if defined(__VISAGECPP__)
+    wxLEAVE_CRIT_SECT( m_eventsLocker);
+#else
+    wxLEAVE_CRIT_SECT( *m_eventsLocker);
+#endif
+
+    // 2) Don't (!) add this event handler to list of event handlers that
+    //    have pending events.
+	//    wxWidgets' ProcessPendingEvents in wxApp::OnIdle
+	//    processes all pending events at once. This is too much for
+	//    our case and will make the application seem unreactive. 
+
+    // 3) Inform the system that new pending events are somwehere,
+    //    and that these should be processed in idle time.
+    wxWakeUpIdle();
+}
+
+// just like wxEvtHandler::ProcessPendingEvents,
+// but only processes a single event
+bool RobEventHandler::HandleSingleEvent()
+{
+#if defined(__VISAGECPP__)
+    wxENTER_CRIT_SECT( m_eventsLocker);
+#else
+    wxENTER_CRIT_SECT( *m_eventsLocker);
+#endif
+
+	if(m_pendingEvents && m_pendingEvents->First()) // there is a pending event
+	{
+		wxNode* node = m_pendingEvents->First();
+		wxEvent* event = (wxEvent*) node->Data();
+		delete node;
+
+		// In ProcessEvent, new events might get added and
+		// we can safely leave the crtical section here.
+#if defined(__VISAGECPP__)
+		wxLEAVE_CRIT_SECT( m_eventsLocker);
+#else
+		wxLEAVE_CRIT_SECT( *m_eventsLocker);
+#endif
+
+		RoboTourEvent* rtEvt = wxDynamicCast(event, RoboTourEvent);
+		if(rtEvt)
+			lastTime = rtEvt->timeStamp; 
+		
+		ProcessEvent(*event);
+		delete event;
+
+		return true; 
+	}
+	else // no more events to do 
+	{
+#if defined(__VISAGECPP__)
+        wxLEAVE_CRIT_SECT( m_eventsLocker);
+#else
+        wxLEAVE_CRIT_SECT( *m_eventsLocker);
+#endif
+		return false; 
+	}
+}
+
+
+
+void RobEventHandler::OnShow(RoboTourEvent&)
+{
+	parent->Show();
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnInitSim(RoboTourEvent& event)
+{
+/*DBG*/
+/*	wxSize sz = field->GetSize();
+	System::println(String("fieldsz: ") + sz.x + "," + sz.y);
+*/
+	parent->haveSim = true;
+
+	parent->simInfo = event.simData;
+	for(int f = 0; f < parent->field.length(); f++)
+		parent->field[f]->EnterSim(parent->simInfo);
+	if(event.tourData.length()) parent->players->Update(event.tourData);
+	parent->curCycle = 0; 
+	parent->tSimCount->SetLabel(wxString::Format(wxT("%d/%d"), (int) parent->simInfo.simNum, (int) event.tourInitData.numSimulations));
+	parent->tCycleCount->SetLabel(wxString::Format(wxT("%d/%d"), 0, (int) event.simData.timeout));
+
+	parent->history->SetMaximum(parent->simInfo.maxBots);
+	parent->history->ClearHistory();
+
+	parent->ignoreDebugIDs.clear();
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnStepSim(RoboTourEvent& event)
+{
+	parent->activeField->StepSim(event.botData);
+	if(event.tourData.length()) {
+		parent->players->Update(event.tourData);
+		parent->history->UpdateFrom(event);
+	}
+	parent->curCycle = event.simData.cycle;
+	parent->tCycleCount->SetLabel(wxString::Format(wxT("%d/%d"), (int) parent->curCycle, (int) event.simData.timeout));
+
+	parent->numFramesSince++;
+	if(parent->numFramesSince >= 20)
+	{
+		lrt::Time cur = lrt::Time::getCurrentTime();
+		lrt::Time diff = cur - parent->framesStart;
+		float msPerFrame = ((float) diff.toInt()) / parent->numFramesSince;
+		float framesPerSecond = 1000.f / msPerFrame;
+		parent->SetStatusText(wxString::Format(_("%.2f Updates per second"), framesPerSecond));
+		parent->numFramesSince = 0;
+		parent->framesStart = cur;
+	}
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnStepTour(RoboTourEvent& event)
+{
+	parent->players->Update(event.tourData);
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnExitSim(RoboTourEvent& event)
+{
+	for(int f = 0; f < parent->field.length(); f++)
+		parent->field[f]->ExitSim();
+
+	if(event.simData.winner != -1)
+	{
+		if(event.simData.winner == -2) // tie
+		{
+			parent->AddMessage(_("The bots tied."), 0);
+		}
+		else 
+		{
+			parent->AddMessage(wxString::Format(_("The winner is '%s'."), Wx::Conv(event.simData.winnerName).c_str()), event.simData.winner+1);
+		}
+	}
+
+	parent->haveSim = false; 
+
+	// reset some guiInfo stuff for the next simulation
+	RobVisFrame::guiInfo.startPressed = false; 
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnPlayerInfo(RoboTourEvent& event)
+{
+	PlayerInfoDialog* pid = new PlayerInfoDialog(parent, event.playerData);
+	pid->Show();
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnSetupDlg(RoboTourEvent& event)
+{
+	if(!event.retData) {
+		wxLogError(_("RobEventHandler::OnSetupDlg: event.retData is 0, cannot popup dialog"));
+		return;
+	}
+	TourSetupInfo* info = (TourSetupInfo*) event.retData; 
+	TourSetupDialog tsd(info);
+	tsd.ShowModal();
+	RobVisFrame::guiInfo.startPressed = false; // but don't start the first sim immediately
+
+	// process the Sound setting
+	wxToolBarBase* tb = parent->GetToolBar(); 
+	tb->EnableTool(RVF_Sound, info->haveSound); 
+	tb->ToggleTool(RVF_Sound, info->sound); 
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnMsgInfo(RoboTourEvent& event)
+{
+	parent->AddMessage(Wx::Conv(event.msgData.msg), parent->numBotColours + 1 /*INFO*/);
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnMsgWarn(RoboTourEvent& event)
+{
+	parent->AddMessage(Wx::Conv(event.msgData.msg), parent->numBotColours + 2 /*WARN*/);
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnMsgError(RoboTourEvent& event)
+{
+	parent->AddMessage(Wx::Conv(event.msgData.msg), parent->numBotColours + 3 /*ERRO*/);
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnMsgRobErr(RoboTourEvent& event)
+{
+	parent->curCycle = event.simData.cycle;
+	if(parent->Filter(event.msgData.id))
+		parent->AddMessage(Wx::Conv(event.msgData.msg), (event.msgData.program % parent->numBotColours) + 1 /*RERR*/);
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnDebugUpdate(DebugEvent& event)
+{
+	if(parent->ignoreDebugIDs.indexOf(event.data.debugID) >= 0) // is ignored
+	{
+		RobVisFrame::guiInfo.numEvents++;
+		return; 
+	}
+
+	if(!parent->debugDialogs.isSet(event.data.debugID))
+		parent->debugDialogs[event.data.debugID] = new DebugDialog(event.data);
+	else
+		parent->debugDialogs[event.data.debugID]->HandleUpdate(event.data);
+
+	RobVisFrame::guiInfo.numEvents++;
+}
+
+void RobEventHandler::OnDebugClose(DebugEvent& event)
+{
+	if(parent->debugDialogs.isSet(event.data.debugID))
+	{
+		DebugDialog* ddlg = parent->debugDialogs[event.data.debugID];
+		ddlg->Destroy();
+		parent->debugDialogs.remove(event.data.debugID);
+		parent->ignoreDebugIDs += event.data.debugID;
+	}
+
+	RobVisFrame::guiInfo.numEvents++;
+}
 
 
 //////////////////////////// RobVIsFrame
 RobVisFrame* RobVisFrame::theVisFrame = 0;
+wxCriticalSection RobVisFrame::visLocker; 
 GuiInfo RobVisFrame::guiInfo;
 
 BEGIN_EVENT_TABLE(RobVisFrame, wxFrame)
 //  EVT_PAINT(RobVisFrame::OnPaint)
 //	EVT_SIZE(RobVisFrame::OnSize)
-	EVT_RT_SHOW(RobVisFrame::OnShow)
-	EVT_RT_INITSIM(RobVisFrame::OnInitSim)
-	EVT_RT_STEPSIM(RobVisFrame::OnStepSim)
-	EVT_RT_EXITSIM(RobVisFrame::OnExitSim)
-	EVT_RT_STEPTOUR(RobVisFrame::OnStepTour)
-	EVT_RT_PLAYER(RobVisFrame::OnPlayerInfo)
-	EVT_RT_SETUPDLG(RobVisFrame::OnSetupDlg)
-	EVT_RT_MSGINFO(RobVisFrame::OnMsgInfo)
-	EVT_RT_MSGWARN(RobVisFrame::OnMsgWarn)
-	EVT_RT_MSGERROR(RobVisFrame::OnMsgError)
-	EVT_RT_MSGROBERR(RobVisFrame::OnMsgRobErr)
-	EVT_DEBUG_UPDATE(RobVisFrame::OnDebugUpdate)
-	EVT_DEBUG_CLOSE(RobVisFrame::OnDebugClose)
 	EVT_MENU(RVF_NewTour, RobVisFrame::OnNewTourMenu)
 	EVT_MENU(RVF_AbortTour, RobVisFrame::OnAbortTourMenu)
 	EVT_MENU(wxID_EXIT, RobVisFrame::OnExitMenu)
@@ -195,6 +462,7 @@ BEGIN_EVENT_TABLE(RobVisFrame, wxFrame)
 	EVT_MENU(RVF_Slow, RobVisFrame::OnSlowMode)
 	EVT_MENU(RVF_Pause, RobVisFrame::OnPause)
 	EVT_MENU(RVF_Abort, RobVisFrame::OnAbort)
+	EVT_MENU(RVF_Sound, RobVisFrame::OnToggleSound) 
 	EVT_MENU(RVF_NoField, RobVisFrame::OnNoField)
 	EVT_MENU(RVF_2DField, RobVisFrame::On2DField)
 	EVT_MENU(RVF_3DField, RobVisFrame::On3DField)
@@ -202,35 +470,37 @@ BEGIN_EVENT_TABLE(RobVisFrame, wxFrame)
 	EVT_MENU(RVF_About, RobVisFrame::OnAbout)
 	EVT_CLOSE(RobVisFrame::OnClose)
 	EVT_COMMAND_SCROLL(RVF_Speed, RobVisFrame::OnSpeed)
+	EVT_IDLE(RobVisFrame::OnIdle)
 END_EVENT_TABLE()
 
 RobVisFrame::RobVisFrame() 
-	: wxFrame(0, -1, "RoboTour Visualization", wxDefaultPosition, wxSize(640, 480)),
+	: wxFrame(0, -1, _("RoboTour Visualization"), wxDefaultPosition, wxSize(640, 480)),
 	  simInfo(), errFilter(0), activeField(0), activeFieldNum(0),
-	  framesStart(lrt::Time::getCurrentTime()), numFramesSince(0), haveSim(false)
+	  framesStart(lrt::Time::getCurrentTime()), numFramesSince(0), haveSim(false), 
+	  evtHandler(this) 
 {
 	SetIcon(wxICON(robotour));
 
 	wxMenu* mf = new wxMenu; 
-	mf->Append(RVF_NewTour, "&New...\tCtrl-N", "Start a new tournament instead of the currently running one (if any).");
-	mf->Append(RVF_AbortTour, "&Abort\tCtrl-A", "Abort the currently running tournament.");
+	mf->Append(RVF_NewTour, _("&New...\tCtrl-N"), _("Start a new tournament instead of the currently running one (if any)."));
+	mf->Append(RVF_AbortTour, _("&Abort\tCtrl-A"), _("Abort the currently running tournament."));
 	mf->AppendSeparator();
-	mf->Append(RVF_HideWin, "&Hide\tAlt-H", "Hide the visualization. RoboTour will continue running.");
-	mf->Append(wxID_EXIT, "&Exit\tAlt-X", "Exit RoboTour.");
+	mf->Append(RVF_HideWin, _("&Hide\tAlt-H"), _("Hide the visualization. RoboTour will continue running."));
+	mf->Append(wxID_EXIT, _("&Exit\tAlt-X"), _("Exit RoboTour."));
 	wxMenu* ms = new wxMenu; 
-	ms->Append(RVF_Colours, "&Program colours...", "Select the robot colours for the different programs.");
-	ms->Append(RVF_Filter, "&Robot errors...", "Select the robot errors which are displayed.");
+	ms->Append(RVF_Colours, _("&Program colours..."), _("Select the robot colours for the different programs."));
+	ms->Append(RVF_Filter, _("&Robot errors..."), _("Select the robot errors which are displayed."));
 #ifdef __RT_OPENGL__
-	ms->Append(RVF_UseHQ, "&High 3D Quality", "Draw the 3D board in high quality (but slower).", wxITEM_CHECK);
+	ms->Append(RVF_UseHQ, _("&High 3D Quality"), _("Draw the 3D board in high quality (but slower)."), wxITEM_CHECK);
 #endif
-	ms->Append(RVF_ShowMsg, "&Show messages", "Redisplay the message list if it has been closed.");
+	ms->Append(RVF_ShowMsg, _("&Show messages"), _("Redisplay the message list if it has been closed."));
 	wxMenu* mh = new wxMenu;
-	mh->Append(RVF_HelpIndex, "&Index\tF1", "Lists online help documents for RoboTour."); 
-	mh->Append(RVF_About, "&About RoboTour...", "Show information about RoboTour."); 
+	mh->Append(RVF_HelpIndex, _("&Index\tF1"), _("Lists online help documents for RoboTour.")); 
+	mh->Append(RVF_About, _("&About RoboTour..."), _("Show information about RoboTour.")); 
 	wxMenuBar* mb = new wxMenuBar();
-	mb->Append(mf, "&Tournament");
-	mb->Append(ms, "&Options");
-	mb->Append(mh, "&Help"); 
+	mb->Append(mf, _("&Tournament"));
+	mb->Append(ms, _("&Options"));
+	mb->Append(mh, _("&Help")); 
 	SetMenuBar(mb); 
 
 
@@ -239,26 +509,31 @@ RobVisFrame::RobVisFrame()
 	wxBitmap slowXPM(slow_xpm);
 	wxBitmap pauseXPM(pause_xpm);
 	wxBitmap abortXPM(abort_xpm);
+	wxBitmap soundXPM(sound_xpm); 
 	wxBitmap fieldNoXPM(fieldno_xpm);
 	wxBitmap field2DXPM(field2d_xpm);
 	wxBitmap field3DXPM(field3d_xpm);
 
 	wxToolBarBase* tb = CreateToolBar();
-	tb->AddTool(RVF_Start, "Start", startXPM, "Start next simulation");
-	tb->AddTool(RVF_StartLock, "StartLock", startLockXPM, "Start simulations automatically", wxITEM_CHECK);
-	tb->AddTool(RVF_Slow, "Slow", slowXPM, "Slow simulation mode", wxITEM_CHECK);
+	tb->AddTool(RVF_Start, _("Start"), startXPM, _("Start next simulation"));
+	tb->AddTool(RVF_StartLock, _("StartLock"), startLockXPM, _("Start simulations automatically"), wxITEM_CHECK);
+	tb->AddTool(RVF_Slow, _("Slow"), slowXPM, _("Slow simulation mode"), wxITEM_CHECK);
 	wxSlider* speedSlider = new wxSlider(tb, RVF_Speed, 10, 1, 100, wxDefaultPosition, wxSize(80, 16));
-	speedSlider->SetToolTip("Simulation speed");
+	speedSlider->SetToolTip(_("Simulation speed"));
 	tb->AddControl(speedSlider);
-	tb->AddTool(RVF_Pause, "Pause", pauseXPM, "Pause simulation", wxITEM_CHECK);
-	tb->AddTool(RVF_Abort, "Abort", abortXPM, "Abort current simulation");
+	tb->AddTool(RVF_Pause, _("Pause"), pauseXPM, _("Pause simulation"), wxITEM_CHECK);
+	tb->AddTool(RVF_Abort, _("Abort"), abortXPM, _("Abort current simulation"));
+	tb->AddTool(RVF_Sound, _("Sound"), soundXPM, _("Toggle sound playback"), wxITEM_CHECK); 
 	tb->AddSeparator();
-	tb->AddRadioTool(RVF_NoField, "No field", fieldNoXPM, wxNullBitmap, "Don't display the field");
-	tb->AddRadioTool(RVF_2DField, "2D field", field2DXPM, wxNullBitmap, "Display field from the top (2D)");
+	tb->AddRadioTool(RVF_NoField, _("No field"), fieldNoXPM, wxNullBitmap, _("Don't display the field"));
+	tb->AddRadioTool(RVF_2DField, _("2D field"), field2DXPM, wxNullBitmap, _("Display field from the top (2D)"));
 #ifdef __RT_OPENGL__
-	tb->AddRadioTool(RVF_3DField, "3D field", field3DXPM, wxNullBitmap, "Display field three-dimensionally"); 
+	tb->AddRadioTool(RVF_3DField, _("3D field"), field3DXPM, wxNullBitmap, _("Display field three-dimensionally")); 
 #endif
 	tb->Realize();
+	// now that the toolbar has been realized, enable/disable some tools
+	tb->EnableTool(RVF_Sound, false); 
+
 
 	CreateStatusBar();
 
@@ -276,11 +551,11 @@ RobVisFrame::RobVisFrame()
 	      wxFlexGridSizer* infoGrid = new wxFlexGridSizer(2, 2, 10);
 	        infoGrid->AddGrowableCol(0);
 	        infoGrid->AddGrowableCol(1);
-	        infoGrid->Add(new wxStaticText(textPanel, -1, "Simulation:"), 0, wxALIGN_RIGHT, 0); 
-	        tSimCount = new wxStaticText(textPanel, -1, "0/0       ");
+	        infoGrid->Add(new wxStaticText(textPanel, -1, _("Simulation:")), 0, wxALIGN_RIGHT, 0); 
+	        tSimCount = new wxStaticText(textPanel, -1, wxT("0/0       "));
 	        infoGrid->Add(tSimCount, 0, wxALIGN_LEFT, 0);
-	        infoGrid->Add(new wxStaticText(textPanel, -1, "Cycle:"), 0, wxALIGN_RIGHT, 0); 
-	        tCycleCount = new wxStaticText(textPanel, -1, "0/0       ");
+	        infoGrid->Add(new wxStaticText(textPanel, -1, _("Cycle:")), 0, wxALIGN_RIGHT, 0); 
+	        tCycleCount = new wxStaticText(textPanel, -1, wxT("0/0       "));
 	        infoGrid->Add(tCycleCount, 0, wxALIGN_LEFT, 0);
 	      textPanel->SetSizerAndFit(infoGrid);
 		infoSizer->Add(textPanel, 0, wxEXPAND, 0);
@@ -304,10 +579,10 @@ RobVisFrame::RobVisFrame()
 	  hSplitter->SetMinimumPaneSize(100);
 
 	  messages = new ImprovedListCtrl(vSplitter, -1, wxDefaultPosition, wxDefaultSize, wxLC_REPORT | wxLC_SINGLE_SEL);
-		messages->InsertColumn(0, "Message");
+		messages->InsertColumn(0, _("Message"));
 		messages->SetGrowableCol(0);
-	    messages->InsertColumn(1, "Sim", wxLIST_FORMAT_RIGHT, 40);
-		messages->InsertColumn(2, "Cycle", wxLIST_FORMAT_RIGHT, 60);
+	    messages->InsertColumn(1, _("Sim"), wxLIST_FORMAT_RIGHT, 40);
+		messages->InsertColumn(2, _("Cycle"), wxLIST_FORMAT_RIGHT, 60);
    
 	vSplitter->SplitHorizontally(hSplitter, messages, -150);
 	vSplitter->SetMinimumPaneSize(100);
@@ -339,7 +614,7 @@ void RobVisFrame::HandleFieldClick(int fieldX, int fieldY)
 {
 	if(!haveSim)
 	{
-		wxMessageBox("Cannot debug robots because the simulation has ended.", "Cannot debug", wxOK | wxICON_INFORMATION);
+		wxMessageBox(_("Cannot debug robots because the simulation has ended."), _("Cannot debug"), wxOK | wxICON_INFORMATION);
 		return;
 	}
 	// REQUEST: send a debug request to the simulation thread here...
@@ -388,14 +663,14 @@ bool RobVisFrame::Filter(int errid)
 void RobVisFrame::LoadSettings()
 {
 	wxConfigBase* cfg = wxConfig::Get(); long iTmp;
-	Wx::RestoreRect(this, "/GUI/VisWindowRect");
-	Wx::RestoreColumns(players, "/GUI/VisPlayerColumns");
-	Wx::RestoreColumns(messages, "/GUI/VisMsgColumns");
-	if(cfg->Read("/GUI/VisWhichField", &iTmp)) SetActiveFieldDisplay(iTmp, true /* toggleTools */);
-	if(cfg->Read("/GUI/VisHSplitPoint", &iTmp)) hSplitter->SetSashPosition(iTmp);
-	if(cfg->Read("/GUI/VisVSplitPoint", &iTmp)) vSplitter->SetSashPosition(iTmp);
+	Wx::RestoreRect(this, wxT("/GUI/VisWindowRect"));
+	Wx::RestoreColumns(players, wxT("/GUI/VisPlayerColumns"));
+	Wx::RestoreColumns(messages, wxT("/GUI/VisMsgColumns"));
+	if(cfg->Read(wxT("/GUI/VisWhichField"), &iTmp)) SetActiveFieldDisplay(iTmp, true /* toggleTools */);
+	if(cfg->Read(wxT("/GUI/VisHSplitPoint"), &iTmp)) hSplitter->SetSashPosition(iTmp);
+	if(cfg->Read(wxT("/GUI/VisVSplitPoint"), &iTmp)) vSplitter->SetSashPosition(iTmp);
 #ifdef __RT_OPENGL__
-	if(cfg->Read("/GUI/High3DQuality", &iTmp)) {
+	if(cfg->Read(wxT("/GUI/High3DQuality"), &iTmp)) {
 		GetMenuBar()->FindItem(RVF_UseHQ)->Check(iTmp);
 		((GLFieldPanel*) field[2])->SetUseHQ(iTmp);
 	}
@@ -406,26 +681,26 @@ void RobVisFrame::StoreSettings()
 {
 	painter.StoreSettings();
 	wxConfigBase* cfg = wxConfig::Get();
-	Wx::StoreRect(this, "/GUI/VisWindowRect");
-	Wx::StoreColumns(players, "/GUI/VisPlayerColumns");
-	Wx::StoreColumns(messages, "/GUI/VisMsgColumns");
-	cfg->Write("/GUI/VisHSplitPoint", hSplitter->GetSashPosition());
-	cfg->Write("/GUI/VisVSplitPoint", vSplitter->GetSashPosition());
-	cfg->Write("/GUI/VisWhichField", activeFieldNum);
+	Wx::StoreRect(this, wxT("/GUI/VisWindowRect"));
+	Wx::StoreColumns(players, wxT("/GUI/VisPlayerColumns"));
+	Wx::StoreColumns(messages, wxT("/GUI/VisMsgColumns"));
+	cfg->Write(wxT("/GUI/VisHSplitPoint"), hSplitter->GetSashPosition());
+	cfg->Write(wxT("/GUI/VisVSplitPoint"), vSplitter->GetSashPosition());
+	cfg->Write(wxT("/GUI/VisWhichField"), activeFieldNum);
 #ifdef __RT_OPENGL__
-	cfg->Write("/GUI/High3DQuality", ((GLFieldPanel*) field[2])->GetUseHQ());
+	cfg->Write(wxT("/GUI/High3DQuality"), ((GLFieldPanel*) field[2])->GetUseHQ());
 #endif
 	cfg->Flush();
 }
 
 void RobVisFrame::SetActiveFieldDisplay(int num, bool toggleTools)
 {
-	//// ATTENTION! here are field tool ids! they have to be changed if more field displas are invented!
+	//// ATTENTION! here are field tool ids! they have to be changed if more field displays are invented!
 	static int toolIDs[] = { RVF_NoField, RVF_2DField, RVF_3DField }; 
 
 	if(num < 0 || num >= field.length())
 	{
-		wxLogDebug("error: SetActiveFieldDisplay(invalid field num %d)", num);
+		wxLogDebug(wxT("error: SetActiveFieldDisplay(invalid field num %d)"), num);
 		return;
 	}
 
@@ -451,6 +726,7 @@ void RobVisFrame::SetActiveFieldDisplay(int num, bool toggleTools)
 		if(f != num)
 			field[f]->Show(false);
 	activeField->Show(true);
+	activeField->Update(true); 
 }
 
 bool RobVisFrame::Destroy()
@@ -463,14 +739,26 @@ bool RobVisFrame::Destroy()
 		errFilter = 0;
 	}
 
-	guiInfo.isDestroyed = true; 
+	if(!guiInfo.haveSimThread) {
+		// now RoboTour is done, so that, if the user closes the app, we'll leave.
+		wxTheApp->SetExitOnFrameDelete(true);
+	}
+	wxTheApp->SetTopWindow(0); 
+
+	visLocker.Enter(); 
+	{
+		guiInfo.isDestroyed = true; 
+		if(this == theVisFrame)
+			theVisFrame = 0; 
+	}
+	visLocker.Leave(); 
+
+
 	return wxFrame::Destroy();
 }
 
 RobVisFrame::~RobVisFrame()
 {
-	if(this == theVisFrame)
-		theVisFrame = 0; 
 }
 
 void RobVisFrame::OnProgramColourMenu(wxCommandEvent&)
@@ -563,7 +851,8 @@ void RobVisFrame::OnSlowMode(wxCommandEvent& evt)
 {
 	guiInfo.slowMode = GetToolBar()->GetToolState(RVF_Slow);
 	// update speed setting
-	OnSpeed(evt);
+	wxScrollEvent dummy;
+	OnSpeed(dummy);
 }
 
 void RobVisFrame::OnPause(wxCommandEvent&)
@@ -578,6 +867,18 @@ void RobVisFrame::OnAbort(wxCommandEvent&)
 	guiInfo.abortPressed = true; 
 }
 
+void RobVisFrame::OnToggleSound(wxCommandEvent&) 
+{
+	wxToolBarBase* tb = GetToolBar(); 
+	bool newState = tb->GetToolState(RVF_Sound); 
+	// note that the already toggled state is returned!
+	SoundRequest req; 
+	req.type = (newState ? SoundRequest::TurnOn : SoundRequest::TurnOff); 
+	guiInfo.reqDebug.append(req); 
+
+	tb->ToggleTool(RVF_Sound, newState); 
+}
+
 void RobVisFrame::OnNoField(wxCommandEvent&)
 {
 	SetActiveFieldDisplay(0);
@@ -597,218 +898,71 @@ void RobVisFrame::On3DField(wxCommandEvent&)
 
 void RobVisFrame::OnAbout(wxCommandEvent&)
 {
-	wxMessageBox(wxString("RoboTour, the fast and portable RoboCom interpreter.\n") + rt::aboutText, 
-		"About RoboTour", wxICON_INFORMATION | wxOK); 
+	wxString msg; 
+	msg.Printf(_("RoboTour, the fast and portable RoboCom interpreter.\nVersion %s\n%s"), 
+		Wx::Conv(rt::getUserVersion()).c_str(), 
+		Wx::Conv(rt::getAboutText()).c_str());
+
+	wxMessageBox(msg, 
+		_("About RoboTour"), wxICON_INFORMATION | wxOK); 
 }
 
 void RobVisFrame::OnHelp(wxCommandEvent&)
 {
 	lrt::String helpFile = findHelpFile("index.html"); 
 	if(!helpFile.length()) // NOT FOUND
-		wxMessageBox("The RoboTour help was not found!", "RoboTour Help", wxICON_ERROR); 
+		wxMessageBox(_("The RoboTour help was not found!"), _("RoboTour Help"), wxICON_ERROR); 
 	else
 		Wx::ShowInBrowser(Wx::Conv(helpFile)); 
 }
 
-void RobVisFrame::OnSpeed(wxCommandEvent&)
+void RobVisFrame::OnSpeed(wxScrollEvent&)
 {
 	wxSlider* slider = (wxSlider*)FindWindowById(RVF_Speed);
 	int sliderSpeed = slider->GetValue(); // range 0..100
 	if(guiInfo.slowMode) {
 		guiInfo.speed = (100-sliderSpeed) * (100-sliderSpeed) / 10 + 10;
-		slider->SetToolTip(wxString::Format("Every cycle takes %d ms", guiInfo.speed));
+		slider->SetToolTip(wxString::Format(_("Every cycle takes %d ms"), (int) guiInfo.speed));
 	}
 	else {
 		guiInfo.speed = (sliderSpeed * sliderSpeed) / 30 + 1;
-		slider->SetToolTip(wxString::Format("Display every %d'th cycle", guiInfo.speed));
+		slider->SetToolTip(wxString::Format(_("Display every %d'th cycle"), (int) guiInfo.speed));
 	}
 }
 
-void RobVisFrame::OnShow(RoboTourEvent&)
-{
-	Show();
-
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnInitSim(RoboTourEvent& event)
-{
-/*DBG*/
-/*	wxSize sz = field->GetSize();
-	System::println(String("fieldsz: ") + sz.x + "," + sz.y);
-*/
-	haveSim = true;
-
-	simInfo = event.simData;
-	for(int f = 0; f < field.length(); f++)
-		field[f]->EnterSim(simInfo);
-	if(event.tourData.length()) players->Update(event.tourData);
-	curCycle = 0; 
-	tSimCount->SetLabel(wxString::Format("%d/%d", simInfo.simNum, event.tourInitData.numSimulations));
-	tCycleCount->SetLabel(wxString::Format("%d/%d", 0, event.simData.timeout));
-
-	history->SetMaximum(simInfo.maxBots);
-	history->ClearHistory();
-
-	ignoreDebugIDs.clear();
-
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnStepSim(RoboTourEvent& event)
-{
-	activeField->StepSim(event.botData);
-	if(event.tourData.length()) {
-		players->Update(event.tourData);
-		history->UpdateFrom(event);
-	}
-	curCycle = event.simData.cycle;
-	tCycleCount->SetLabel(wxString::Format("%d/%d", curCycle, event.simData.timeout));
-
-	numFramesSince++;
-	if(numFramesSince >= 20)
-	{
-		lrt::Time cur = lrt::Time::getCurrentTime();
-		lrt::Time diff = cur - framesStart;
-		float msPerFrame = ((float) diff.toInt()) / numFramesSince;
-		float framesPerSecond = 1000.f / msPerFrame;
-		SetStatusText(wxString::Format("%.2f Updates per second", framesPerSecond));
-		numFramesSince = 0;
-		framesStart = cur;
-	}
-
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnStepTour(RoboTourEvent& event)
-{
-	players->Update(event.tourData);
-
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnExitSim(RoboTourEvent& event)
-{
-	for(int f = 0; f < field.length(); f++)
-		field[f]->ExitSim();
-
-	if(event.simData.winner != -1)
-	{
-		if(event.simData.winner == -2) // tie
-		{
-			AddMessage("The bots tied.", 0);
-		}
-		else 
-		{
-			AddMessage(wxString::Format("The winner is '%s'.", event.simData.winnerName.cStr()), event.simData.winner+1);
-		}
-	}
-
-	haveSim = false; 
-
-	// reset some guiInfo stuff for the next simulation
-	guiInfo.startPressed = false; 
-
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnPlayerInfo(RoboTourEvent& event)
-{
-	PlayerInfoDialog* pid = new PlayerInfoDialog(this, event.playerData);
-	pid->Show();
-
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnSetupDlg(RoboTourEvent& event)
-{
-	if(!event.retData) {
-		wxLogError("RobVisFrame::OnSetupDlg: event.retData is 0, cannot popup dialog");
-		return;
-	}
-	TourSetupDialog tsd((TourSetupInfo*) event.retData);
-	tsd.ShowModal();
-	guiInfo.startPressed = false; // but don't start the first sim immediately
-
-	guiInfo.numEvents++;
-}
-
 void RobVisFrame::AddMessage(const wxString& msg, int icon)
 {
 	long msgPos = messages->GetItemCount();
-	if(msgPos > 500)
-	{
-		messages->DeleteItem(0);
-		msgPos--;
-	}
+
 	messages->InsertItem(msgPos, msg, icon);
-	messages->SetItem(msgPos, 1, wxString::Format("%d", simInfo.simNum));
-	messages->SetItem(msgPos, 2, wxString::Format("%d", curCycle));
+	messages->SetItem(msgPos, 1, wxString::Format(wxT("%d"), (int) simInfo.simNum));
+	messages->SetItem(msgPos, 2, wxString::Format(wxT("%d"), (int) curCycle));
 	if(!vSplitter->IsSplit()) {
 		vSplitter->SplitHorizontally(hSplitter, messages, -150);
 		messages->Show();
 	}
-	messages->EnsureVisible(msgPos);
 	messages->SetItemState(msgPos, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
-}
+	messages->EnsureVisible(msgPos);
 
-void RobVisFrame::OnMsgInfo(RoboTourEvent& event)
-{
-	AddMessage(Wx::Conv(event.msgData.msg), numBotColours + 1 /*INFO*/);
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnMsgWarn(RoboTourEvent& event)
-{
-	AddMessage(Wx::Conv(event.msgData.msg), numBotColours + 2 /*WARN*/);
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnMsgError(RoboTourEvent& event)
-{
-	AddMessage(Wx::Conv(event.msgData.msg), numBotColours + 3 /*ERRO*/);
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnMsgRobErr(RoboTourEvent& event)
-{
-	curCycle = event.simData.cycle;
-	if(Filter(event.msgData.id))
-		AddMessage(Wx::Conv(event.msgData.msg), (event.msgData.program % numBotColours) + 1 /*RERR*/);
-	guiInfo.numEvents++;
-}
-
-void RobVisFrame::OnDebugUpdate(DebugEvent& event)
-{
-	if(ignoreDebugIDs.indexOf(event.data.debugID) >= 0) // is ignored
+	if(msgPos > 500)
 	{
-		guiInfo.numEvents++;
-		return; 
+		messages->DeleteItem(0);
 	}
-
-	if(!debugDialogs.isSet(event.data.debugID))
-		debugDialogs[event.data.debugID] = new DebugDialog(event.data);
-	else
-		debugDialogs[event.data.debugID]->HandleUpdate(event.data);
-
-	guiInfo.numEvents++;
 }
 
-void RobVisFrame::OnDebugClose(DebugEvent& event)
+void RobVisFrame::OnIdle(wxIdleEvent& evt)
 {
-	if(debugDialogs.isSet(event.data.debugID))
-	{
-		DebugDialog* ddlg = debugDialogs[event.data.debugID];
-		ddlg->Destroy();
-		debugDialogs.remove(event.data.debugID);
-		ignoreDebugIDs += event.data.debugID;
+	if(GetRobEventHandler()->HandleSingleEvent()) {
+		// there's more to do here
+		evt.RequestMore(); 
+	}
+	else {
+		// do nothing here; 
+		int i = 1 + 1; 
 	}
-
-	guiInfo.numEvents++;
 }
 
 
-
 ///////////////////////////////// NoFieldPanel
 BEGIN_EVENT_TABLE(NoFieldPanel, wxControl)
   EVT_PAINT(NoFieldPanel::OnPaint)
@@ -846,9 +1000,12 @@ void NoFieldPanel::HandleProgramColourChange()
 void NoFieldPanel::OnPaint(wxPaintEvent& event)
 {
 	wxPaintDC dc(this);
+	dc.SetBrush(wxBrush(GetBackgroundColour(), wxSOLID));
+	dc.Clear();
+
 	wxSize center = GetSize();
 	int tx, ty; 
-	wxString text = "Visualization disabled";
+	wxString text = _("Visualization disabled");
 	GetTextExtent(text, &tx, &ty);
 	center.x -= tx; center.y -= ty; 
 	center.x /= 2; center.y /= 2;
@@ -862,7 +1019,7 @@ bool NoFieldPanel::Show(bool doShow)
 
 wxWindow* NoFieldPanel::GetAsWindow()
 {
-	return (wxWindow*) this; 
+	return (wxWindow*) this;
 }
 
 //////////////////////////////// FieldPanel
@@ -872,8 +1029,17 @@ BEGIN_EVENT_TABLE(FieldPanel, wxControl)
   EVT_LEFT_DOWN(FieldPanel::OnClick)
 END_EVENT_TABLE()
 
+#if wxCHECK_VERSION(2, 5, 0)
+   // full-repaint flag
+#  define RT_FULL_REPAINT wxFULL_REPAINT_ON_RESIZE 
+#else
+   // not needed in 2.4 and before
+#  define RT_FULL_REPAINT 0   
+#endif
+
 FieldPanel::FieldPanel(wxWindow* parent, RobVisFrame* vframe, wxWindowID id)
-	: wxControl(parent, id, wxDefaultPosition, wxSize(640, 480)), FieldDisplay(vframe), inSim(false)
+	: wxControl(parent, id, wxDefaultPosition, wxSize(640, 480), RT_FULL_REPAINT),
+	  FieldDisplay(vframe), inSim(false)
 {
 	// init pixel sizes (all dummy values!) 
 	fieldSize = 16; xOffset = 0; yOffset = 0; 
@@ -920,7 +1086,7 @@ void FieldPanel::OnClick(wxMouseEvent& event)
 	if(x < 0 || x >= simInfo.width || y < 0 || y >= simInfo.width)
 		lrt::System::println("click outside field!"); 
 	else
-		lrt::System::println(Wx::Conv(wxString::Format("click on field: %d,%d", x, y)));
+		lrt::System::println(Wx::Conv(wxString::Format(wxT("click on field: %d,%d"), x, y)));
 	vframe->HandleFieldClick(x, y);
 }
 
@@ -952,9 +1118,11 @@ void FieldPanel::Paint(wxDC& device, bool force)
 
 	device.BeginDrawing();
 		//erase_bkgnd
-//		device.GetBrush().SetColour(GetBackgroundColour());
-//		device.DrawRectangle(0, 0, size.GetWidth(), size.GetHeight());
-		
+		if(force) {
+			device.SetBrush(wxBrush(GetBackgroundColour(), wxSOLID));
+			device.Clear();
+		}
+
 		for(int x = 0; x < simInfo.width; x++)
 		{
 			for(int y = 0; y < simInfo.height; y++)
@@ -981,7 +1149,7 @@ bool FieldPanel::Show(bool doShow)
 
 wxWindow* FieldPanel::GetAsWindow()
 {
-	return (wxWindow*) this; 
+	return (wxWindow*) this;
 }
 
 
@@ -996,15 +1164,15 @@ PlayerListCtrl::PlayerListCtrl(wxWindow* parent, RobVisFrame* vframe, wxWindowID
 	  vframe(vframe), numFieldSize(-1), haveImgList(false), imgListSize(1)
 {
 	int y;
-	GetTextExtent("9999", &numFieldSize, &y); // text which must fit inside the columns
+	GetTextExtent(wxT("9999"), &numFieldSize, &y); // text which must fit inside the columns
 
-	InsertColumn(0, "Program");
+	InsertColumn(0, _("Program"));
 	SetGrowableCol(0);
-	InsertColumn(1, "W", wxLIST_FORMAT_RIGHT, numFieldSize);
-	InsertColumn(2, "L", wxLIST_FORMAT_RIGHT, numFieldSize);
-	InsertColumn(3, "T", wxLIST_FORMAT_RIGHT, numFieldSize);
-	InsertColumn(4, "P", wxLIST_FORMAT_RIGHT, numFieldSize);
-	InsertColumn(5, "Bots", wxLIST_FORMAT_RIGHT, numFieldSize);
+	InsertColumn(1, _("W"), wxLIST_FORMAT_RIGHT, numFieldSize);
+	InsertColumn(2, _("L"), wxLIST_FORMAT_RIGHT, numFieldSize);
+	InsertColumn(3, _("T"), wxLIST_FORMAT_RIGHT, numFieldSize);
+	InsertColumn(4, _("P"), wxLIST_FORMAT_RIGHT, numFieldSize);
+	InsertColumn(5, _("Bots"), wxLIST_FORMAT_RIGHT, numFieldSize);
 }
 
 PlayerListCtrl::~PlayerListCtrl()
@@ -1020,7 +1188,7 @@ void PlayerListCtrl::Update(const Vector<TourInfo>& tourData)
 	// insert (too few items)
 	else if(GetItemCount() < tourData.length())
 		for(int ii = GetItemCount(); ii < tourData.length(); ii++)
-			InsertItem(ii, "");
+			InsertItem(ii, wxT(""));
 
 
 	for(int i = 0; i < tourData.length(); i++)
@@ -1035,7 +1203,7 @@ void PlayerListCtrl::Update(const Vector<TourInfo>& tourData)
 		if(dat.numBots >= 0)
 			SetItemIfNeeded(i, 5, dat.numBots);
 		else
-			SetItemIfNeeded(i, 5, "");
+			SetItemIfNeeded(i, 5, wxT(""));
 	}
 }
 
@@ -1079,17 +1247,17 @@ void PlayerListCtrl::OnClick(wxListEvent& le)
 ///////////////// PlayerInfoDialog /////////////////////
 
 PlayerInfoDialog::PlayerInfoDialog(wxFrame* parent, const Vector< Pair<String, String> >& info)
-	:wxDialog(parent, -1, wxString("Robot Info"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
+	:wxDialog(parent, -1, wxString(_("Robot Info")), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
 {
 	wxSizer* sz = new wxBoxSizer(wxVERTICAL);
 	wxListCtrl* list = new wxListCtrl(this, -1, wxDefaultPosition, wxDefaultSize, wxLC_REPORT);
-	list->InsertColumn(0, "Field", wxLIST_FORMAT_LEFT, -2);
-	list->InsertColumn(1, "Value", wxLIST_FORMAT_LEFT, 250);
+	list->InsertColumn(0, _("Field"), wxLIST_FORMAT_LEFT, -2);
+	list->InsertColumn(1, _("Value"), wxLIST_FORMAT_LEFT, 250);
 
 	for(int i = 0; i < info.length(); i++)
 	{
 		if(!info[i].getKey().compareIgnoreCase("name")) // we're just loading program name
-			SetTitle("Robot Info - " + Wx::Conv(info[i].getValue())); // display it inside title
+			SetTitle(_("Robot Info - ") + Wx::Conv(info[i].getValue())); // display it inside title
 
 		list->InsertItem(i, Wx::Conv(info[i].getKey()));
 		list->SetItem(i, 1, Wx::Conv(info[i].getValue()));
@@ -1097,7 +1265,7 @@ PlayerInfoDialog::PlayerInfoDialog(wxFrame* parent, const Vector< Pair<String, S
 
 	sz->Add(list, 1, wxEXPAND | wxALL, 2);
 
-	wxButton* ok = new wxButton(this, wxID_OK, "OK");
+	wxButton* ok = new wxButton(this, wxID_OK, _("OK"));
 	sz->Add(ok, 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 2);
 
 	SetSizer(sz);
@@ -1166,7 +1334,7 @@ void BotPainter::LoadSettings()
 	programColours += wxColour(49, 89, 132);
 
 	// load stored settings
-	lrt::Array<int> colNums = Wx::ReadArray(-1, "/GUI/ProgramColours");
+	lrt::Array<int> colNums = Wx::ReadArray(-1, wxT("/GUI/ProgramColours"));
 	for(int i = 0; i < colNums.length(); i++)
 	{
 		int num = colNums[i];
@@ -1187,7 +1355,7 @@ void BotPainter::StoreSettings()
 		wxColour& col = GetProgramColour(i);
 		colNums[i] = (col.Red() << 16) | (col.Green() << 8) | col.Blue();
 	}
-	Wx::StoreArray(colNums, "/GUI/ProgramColours");
+	Wx::StoreArray(colNums, wxT("/GUI/ProgramColours"));
 }
 
 void BotPainter::SetProgramColour(int progNum, const wxColour& col)
@@ -1298,7 +1466,7 @@ int BotPainter::GetFrameStyle(int botType)
       case 2:
 		return wxSOLID;
 	  default: // unreachable ?!
-		wxLogError("invalid instruction set: %d", botType);
+		wxLogError(wxT("invalid instruction set: %d"), botType);
 		return wxDOT_DASH;
 	}
 }
@@ -1330,7 +1498,7 @@ void BotPainter::CalcPoints(int dir, int fieldSize, wxPoint* points)
 		points[2] = wxPoint(down, mid);
 		break;
 	  default: // should be unreachable...
-		wxLogError("invalid robot head direction: %d", dir);
+		wxLogError(wxT("invalid robot head direction: %d"), dir);
 		break;
 	}
 }
