@@ -1,7 +1,7 @@
 /*
  * robwxvis.h
  * 
- * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * Copyright (c) 2000-2005 by Florian Fischer (florianfischer@gmx.de)
  * and Martin Trautmann (martintrautmann@gmx.de) 
  * 
  * This file may be distributed and/or modified under the terms of the 
@@ -22,9 +22,6 @@
 #include "robmanage.h"
 #include <rtcollect.h>
 
-//using namespace rt; 
-//using namespace lrt; 
-
 #include <wx/wx.h>
 #include <wx/listctrl.h>
 #include <wx/splitter.h>
@@ -91,7 +88,7 @@ class RoboTourEvent : public wxEvent
     DECLARE_DYNAMIC_CLASS(RoboTourEvent)
 public:
 	RoboTourEvent(int eventType = EVT_RT_SHOW_TYPE);
-	RoboTourEvent(const RoboTourEvent& evt);
+	//RoboTourEvent(const RoboTourEvent& evt);
     wxEvent* Clone() const;
 
 	void LoadSimData(rt::Simulation* sim, int simNum);
@@ -106,6 +103,8 @@ public:
 	PlayerInfo playerData;
 	MsgInfo msgData;
 	void* retData;
+
+	lrt::Time timeStamp; 
 };
 
 // my event class 2
@@ -232,7 +231,7 @@ public:
 	
 	void SetImageIfNeeded(long row, int image);
 	void SetItemIfNeeded(long row, int col, const wxString& text);
-	void SetItemIfNeeded(long row, int col, int num) { SetItemIfNeeded(row, col, wxString::Format("%d", num)); }
+	void SetItemIfNeeded(long row, int col, int num) { SetItemIfNeeded(row, col, wxString::Format(wxT("%d"), num)); }
 
 	void HandleProgramColourChange();
 
@@ -248,11 +247,69 @@ private:
 	void OnClick(wxListEvent&);
 };
 
+/** This class acts as an event handler for the 
+  * RoboTourEvents and DebugEvents that are sent by the
+  * simulation thread. 
+  */
+class RobEventHandler : public wxEvtHandler
+{
+public:
+	RobEventHandler(RobVisFrame* parent); 
+	
+	/// Adds a new event to this handler. 
+	/// This method is thread-safe. 
+	/// Note: please call this method directly, do not
+	/// use wxPostEvent(). This is because wxEvtHandler::AddPendingEvent
+	/// is not virtual. (WHY?) 
+	void AddPendingEvent(wxEvent& event); 
+
+	/// This is called when the visualization is idle 
+	/// and processes the next RoboTourEvent. 
+	/// This method must be called from the main thread, whenever
+	/// the GUI is idle. This will be done by the RobVisFrame. 
+	/// @return true if there are more events to handle
+	bool HandleSingleEvent();
+	
+	/// Gets the time of the last extracted event in the queue. 
+	lrt::Time GetLastTime() { return lastTime; }
+
+
+	DECLARE_EVENT_TABLE()
+private:
+	void OnShow(RoboTourEvent&);
+	void OnInitSim(RoboTourEvent&);
+	void OnStepSim(RoboTourEvent&);
+	void OnExitSim(RoboTourEvent&);
+	void OnStepTour(RoboTourEvent&);
+	void OnPlayerInfo(RoboTourEvent&);
+	void OnSetupDlg(RoboTourEvent&);
+
+	void OnMsgInfo(RoboTourEvent&);
+	void OnMsgWarn(RoboTourEvent&);
+	void OnMsgError(RoboTourEvent&);
+	void OnMsgRobErr(RoboTourEvent&);
+
+	void OnDebugUpdate(DebugEvent&);
+	void OnDebugClose(DebugEvent&);
+
+	RobVisFrame* parent; 
+
+	lrt::Time lastTime; 
+}; 
+
+/** The main visualization frame. 
+  * Note that you cannot have more than one of these open at any time. 
+  */
 class RobVisFrame : public wxFrame
 {
 public:
+	/// The currently open visualization frame. 
 	static RobVisFrame* theVisFrame; 
+	/// Info about the GUI state for the simulation thread. 
 	static GuiInfo guiInfo;
+	/// While this critical section is held, 
+	/// theVisFrame must not be destroyed. 
+	static wxCriticalSection visLocker; 
 
 	RobVisFrame();
 	~RobVisFrame(); 
@@ -265,6 +322,8 @@ public:
 	void HandleFieldClick(int fieldX, int fieldY); // called by the FieldPanels when a field (bot) is clicked
 	bool HandleDebugDialogClose(int debugID); // called by the DebugDialogs when they want to be closed
 	
+	RobEventHandler* GetRobEventHandler() { return &evtHandler; }
+
 	DECLARE_EVENT_TABLE()
 private:
 	// wxConfig support
@@ -288,33 +347,25 @@ private:
 	void OnAbout(wxCommandEvent&); 
 	void OnClose(wxCloseEvent&);
 
-	void OnShow(RoboTourEvent&);
-	void OnInitSim(RoboTourEvent&);
-	void OnStepSim(RoboTourEvent&);
-	void OnExitSim(RoboTourEvent&);
-	void OnStepTour(RoboTourEvent&);
-	void OnPlayerInfo(RoboTourEvent&);
-	void OnSetupDlg(RoboTourEvent&);
-
-	void OnMsgInfo(RoboTourEvent&);
-	void OnMsgWarn(RoboTourEvent&);
-	void OnMsgError(RoboTourEvent&);
-	void OnMsgRobErr(RoboTourEvent&);
-
-	void OnDebugUpdate(DebugEvent&);
-	void OnDebugClose(DebugEvent&);
-
 	void OnStart(wxCommandEvent&);
 	void OnStartLock(wxCommandEvent&);
 	void OnSlowMode(wxCommandEvent&);
 	void OnPause(wxCommandEvent&);
 	void OnAbort(wxCommandEvent&);
-	void OnSpeed(wxCommandEvent&);
+	void OnSpeed(wxScrollEvent&);
+	void OnToggleSound(wxCommandEvent&); 
 	void OnNoField(wxCommandEvent&);
 	void On2DField(wxCommandEvent&);
 	void On3DField(wxCommandEvent&);
 
+	// During IDLE time, we will handle the RoboTour events one at a time
+	// by calling RobEventHandler.HandleSingleEvent. 
+	void OnIdle(wxIdleEvent&); 
+
 //	void OnSize(wxSizeEvent& event);
+	friend class RobEventHandler; 
+	RobEventHandler evtHandler; 
+
 	SimInfo simInfo; 
 	wxPanel* infoPanel;
 	lrt::Vector<FieldDisplay*> field; 
@@ -343,6 +394,7 @@ enum { //IDs
 	RVF_Slow,
 	RVF_Pause,
 	RVF_Abort,
+	RVF_Sound, 
 	RVF_NoField,
 	RVF_2DField,
 	RVF_3DField,
